// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/api"
	model "LAPP_LF_MOM_BACKEND/models/api"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ACCUNITIDDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ACCUNITID的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 10:08:28
 *
 ******************************************************************************/
type ACCUNITIDDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewACCUNITIDDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ACCUNITIDDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : ACCUNITIDDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 10:08:28
 *
 ******************************************************************************/
func NewACCUNITIDDAOImplement(session *xorm.Session, userid string) *ACCUNITIDDAOImplement {
	return &ACCUNITIDDAOImplement{session, &meta.ACCUNITID, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) InsertOne(entity *model.ACCUNITID) error {

	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) DeleteOne(rECID int64) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{rECID}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) SelectOne(rECID int64) (*model.ACCUNITID, error) {
	var data model.ACCUNITID
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{rECID}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}


/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.SelectInfo
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) SelectInfo(reclinerNr string) (*model.ACCUNITID, error) {
	var data model.ACCUNITID
	ok, err := impl.session.Table(impl.meta.TableName).Where("LINE = ? and ID_NAME = ? and ID_VALUE = ?","LaserWelding","Adjuster",reclinerNr).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) UpdateOne(entity *model.ACCUNITID) error {

	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.Insert
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) Insert(entities *[]model.ACCUNITID) error {
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.Delete
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) Delete(entities *[]model.ACCUNITID) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.Select
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ACCUNITID, error) {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ACCUNITID, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 + 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by "
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ACCUNITID, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.Update
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) Update(entities *[]model.ACCUNITID) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/ACCUNITIDDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ACCUNITIDDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ACCUNITID, columns ...string) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ACCUNITID_LastUser.ColumnName)
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
