// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/api"
	model "LAPP_LF_MOM_BACKEND/models/api"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : PortalWorkOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : PortalWorkOrder的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-14 10:40:07
 *
 ******************************************************************************/
type PortalWorkOrderDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewPortalWorkOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PortalWorkOrderDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : PortalWorkOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-14 10:40:07
 *
 ******************************************************************************/
func NewPortalWorkOrderDAOImplement(session *xorm.Session, userid string) *PortalWorkOrderDAOImplement {
	return &PortalWorkOrderDAOImplement{session, &meta.PortalWorkOrder, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.InsertOne
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) InsertOne(entity *model.PortalWorkOrder) error {

	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) DeleteOne(barcode string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{barcode}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.SelectOne
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) SelectOne(barcode string) (*model.PortalWorkOrder, error) {
	var data model.PortalWorkOrder
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{barcode}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) UpdateOne(entity *model.PortalWorkOrder) error {

	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.Insert
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) Insert(entities *[]model.PortalWorkOrder) error {
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.Delete
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) Delete(entities *[]model.PortalWorkOrder) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.Select
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PortalWorkOrder, error) {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.PortalWorkOrder, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by "
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PortalWorkOrder, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.Update
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) Update(entities *[]model.PortalWorkOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/PortalWorkOrderDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.PortalWorkOrder, columns ...string) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/api/MESWorkOrderDAO.SelectNeedParseData
 *
 ******************************************************************************/
func (impl *PortalWorkOrderDAOImplement) SelectNeedParseData(datetime string) ([]model.PortalWorkOrder, error) {
	data := make([]model.PortalWorkOrder, 0)
	session := impl.session.Table(impl.meta.TableName)
	where := fmt.Sprintf("%s >= ?", meta.PortalWorkOrder_PlanDttm.ColumnName)
	err := session.Where(where, datetime).OrderBy(meta.PortalWorkOrder_AutoId.ColumnName).Find(&data)
	return data, err
}