// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_LF_MOM_BACKEND/dao/base/implments"
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"github.com/go-xorm/xorm"
)

/******************************************************************************
*
* @Interface Name           : AttributeDAO
*-----------------------------------------------------------------------------
*
* @Description              : Attribute的数据访问对象接口
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-24 09:53:49
*
******************************************************************************/
type AttributeDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Attribute
	 *
	 * @Function Parameters      : 需要插入的Attribute
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	InsertOne(*model.Attribute) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Attribute
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	DeleteOne(int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Attribute
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Attribute
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	SelectOne(int) (*model.Attribute, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改Attribute
	 *
	 * @Function Parameters      : 需要修改的Attribute
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	UpdateOne(*model.Attribute) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Attribute
	 *
	 * @Function Parameters      : 需要插入的Attribute列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	Insert(*[]model.Attribute) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Attribute
	 *
	 * @Function Parameters      : 需要删除的Attribute列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	Delete(*[]model.Attribute) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除Attribute
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Attribute
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.Attribute, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Attribute并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Attribute
	 *
	 * @Function Parameters      : 需要修改的Attribute列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	Update(*[]model.Attribute) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改Attribute
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.Attribute, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewAttributeDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个AttributeDAO实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : AttributeDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-24 09:53:49
 *
 ******************************************************************************/
func NewAttributeDAO(session *xorm.Session, plantNr int, userid string) AttributeDAO {
	return implments.NewAttributeDAOImplement(session, plantNr, userid)
}
