// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_LF_MOM_BACKEND/dao/base/implments"
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"github.com/go-xorm/xorm"
)

/******************************************************************************
 *
 * @Interface Name           : MenuDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : Menu的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
type MenuDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Menu
	 *
	 * @Function Parameters      : 需要插入的Menu
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	InsertOne(*model.Menu) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Menu
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	DeleteOne(int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Menu
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Menu
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	SelectOne(int) (*model.Menu, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改Menu
	 *
	 * @Function Parameters      : 需要修改的Menu
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	UpdateOne(*model.Menu) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Menu
	 *
	 * @Function Parameters      : 需要插入的Menu列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	Insert(*[]model.Menu) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Menu
	 *
	 * @Function Parameters      : 需要删除的Menu列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	Delete(*[]model.Menu) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除Menu
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Menu
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.Menu, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Menu并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Menu
	 *
	 * @Function Parameters      : 需要修改的Menu列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	Update(*[]model.Menu) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改Menu
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 15:04:54
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.Menu, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewMenuDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个MenuDAO实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : MenuDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func NewMenuDAO(session *xorm.Session, userid string) MenuDAO {
	return implments.NewMenuDAOImplement(session, userid)
}
