// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_LF_MOM_BACKEND/dao/base/implments"
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"github.com/go-xorm/xorm"
)

/******************************************************************************
 *
 * @Interface Name           : UserDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : User的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 13:08:46
 *
 ******************************************************************************/
type UserDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条User
	 *
	 * @Function Parameters      : 需要插入的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	InsertOne(*model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的User
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	DeleteOne(string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的User
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	SelectOne(string) (*model.User, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改User
	 *
	 * @Function Parameters      : 需要修改的User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	UpdateOne(*model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条User
	 *
	 * @Function Parameters      : 需要插入的User列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	Insert(*[]model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条User
	 *
	 * @Function Parameters      : 需要删除的User列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	Delete(*[]model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询User
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.User, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询User并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条User
	 *
	 * @Function Parameters      : 需要修改的User列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	Update(*[]model.User) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改User
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 13:08:46
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.User, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewUserDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个UserDAO实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : UserDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 13:08:46
 *
 ******************************************************************************/
func NewUserDAO(session *xorm.Session, plantNr int, userid string) UserDAO {
	return implments.NewUserDAOImplement(session, plantNr, userid)
}
