// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_LF_MOM_BACKEND/dao/base/implments"
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"github.com/go-xorm/xorm"
)

/******************************************************************************
 *
 * @Interface Name           : WorkPlaceDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkPlace的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-21 10:27:00
 *
 ******************************************************************************/
type WorkPlaceDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条WorkPlace
	 *
	 * @Function Parameters      : 需要插入的WorkPlace
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	InsertOne(*model.WorkPlace) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的WorkPlace
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	DeleteOne(int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkPlace
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkPlace
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	SelectOne(int) (*model.WorkPlace, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectById
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkPlace
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkPlace
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	SelectById(workPlaceId string) (*model.WorkPlace, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改WorkPlace
	 *
	 * @Function Parameters      : 需要修改的WorkPlace
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	UpdateOne(*model.WorkPlace) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条WorkPlace
	 *
	 * @Function Parameters      : 需要插入的WorkPlace列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	Insert(*[]model.WorkPlace) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条WorkPlace
	 *
	 * @Function Parameters      : 需要删除的WorkPlace列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	Delete(*[]model.WorkPlace) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除WorkPlace
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询WorkPlace
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.WorkPlace, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询WorkPlace并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条WorkPlace
	 *
	 * @Function Parameters      : 需要修改的WorkPlace列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	Update(*[]model.WorkPlace) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改WorkPlace
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-21 10:27:00
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.WorkPlace, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewWorkPlaceDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkPlaceDAO实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkPlaceDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-21 10:27:00
 *
 ******************************************************************************/
func NewWorkPlaceDAO(session *xorm.Session, plantNr int, userid string) WorkPlaceDAO {
	return implments.NewWorkPlaceDAOImplement(session, plantNr, userid)
}
