// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ArticleAtcodLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArticleAtcodLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type ArticleAtcodLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArticleAtcodLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArticleAtcodLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ArticleAtcodLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewArticleAtcodLstDAOImplement(session *xorm.Session, plantNr int, userid string) *ArticleAtcodLstDAOImplement {
	return &ArticleAtcodLstDAOImplement{session, &meta.ArticleAtcodLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) InsertOne(entity *model.ArticleAtcodLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) DeleteOne(artId string, version int, projectId string, attrCode int, attrValue string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, artId, version, projectId, attrCode, attrValue}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) SelectOne(artId string, version int, projectId string, attrCode int, attrValue string) (*model.ArticleAtcodLst, error) {
	var data model.ArticleAtcodLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, artId, version, projectId, attrCode, attrValue}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) UpdateOne(entity *model.ArticleAtcodLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.Insert
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) Insert(entities *[]model.ArticleAtcodLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.Delete
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) Delete(entities *[]model.ArticleAtcodLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArticleAtcodLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.Select
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArticleAtcodLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArticleAtcodLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ArticleAtcodLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ArticleAtcodLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArticleAtcodLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ArticleAtcodLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArticleAtcodLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.Update
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) Update(entities *[]model.ArticleAtcodLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ArticleAtcodLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArticleAtcodLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ArticleAtcodLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.SelectAllot
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) SelectAllot(artId string) ([]model.Attribute, error) {

	data := make([]model.ArtData, 0)
	datalist := make([]model.Attribute, 0)
	session := impl.session.Table(meta.Attribute.TableName).Join("LEFT",meta.ArticleAtcodLst.TableName,"ArticleAtcodLst.PlantNr = Attribute.PlantNr and ArticleAtcodLst.AttrCode = Attribute.AttrCode").Where("ArticleAtcodLst.PlantNr = ? and ArticleAtcodLst.ArtId = ?", impl.plantNr, artId)

	err := session.Find(&data)
	for _,v := range data{
		one := model.Attribute{}
		one = v.Attribute
		one.AttrValue = v.ArticleAtcodLst.AttrValue
		datalist = append(datalist,one)
	}
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return datalist, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAO.SelectUnAllot
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) SelectUnAllot(attrCodes []int) ([]model.Attribute, error) {

	data := make([]model.Attribute, 0)
	session := impl.session.Table(meta.Attribute.TableName).Where("PlantNr = ?", impl.plantNr).NotIn("AttrCode",attrCodes)

	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/ArticleAtcodLstDAOImplement.SelectAllAttributeWithValue
 *
 ******************************************************************************/
func (impl *ArticleAtcodLstDAOImplement) SelectAllWithAttrValue() ([]model.ArticleWithAttrValue, error) {
	var err error
	result := make([]model.ArticleWithAttrValue, 0)
	condition := fmt.Sprintf("%s = %s and %s = %s and %s = %s",
		meta.ArticleAtcodLst_PlantNr.ColumnName,
		meta.AttributeValst_PlantNr.ColumnName,
		meta.ArticleAtcodLst_AttrCode.ColumnName,
		meta.AttributeValst_AttrCode.ColumnName,
		meta.ArticleAtcodLst_AttrValue.ColumnName,
		meta.AttributeValst_AttrValue.ColumnName,
	)
	err = impl.session.Table(impl.meta.TableName).Join("LEFT", meta.AttributeValst.TableName, condition).Find(&result)
	if err != nil {
		return nil, err
	}
	return result, err
}