// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : OPCComRuleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : OPCComRule的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
type OPCComRuleDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewOPCComRuleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个OPCComRuleDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : OPCComRuleDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func NewOPCComRuleDAOImplement(session *xorm.Session, plantNr int, userid string) *OPCComRuleDAOImplement {
	return &OPCComRuleDAOImplement{session, &meta.OPCComRule, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.InsertOne
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) InsertOne(entity *model.OPCComRule) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) DeleteOne(operationId int, ruleId int, workPlaceNr int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, operationId, ruleId, workPlaceNr}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.SelectOne
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) SelectOne(operationId int, ruleId int, workPlaceNr int) (*model.OPCComRule, error) {
	var data model.OPCComRule
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, operationId, ruleId, workPlaceNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) UpdateOne(entity *model.OPCComRule) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.Insert
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) Insert(entities *[]model.OPCComRule) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.Delete
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) Delete(entities *[]model.OPCComRule) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.OPCComRule_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.Select
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.OPCComRule, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.OPCComRule_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.OPCComRule_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.OPCComRule, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.OPCComRule_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.OPCComRule_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.OPCComRule, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.Update
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) Update(entities *[]model.OPCComRule) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.OPCComRule, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.OPCComRule_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.OPCComRule_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OPCComRuleDAO.SelectOPCJoinData
 *
 ******************************************************************************/
func (impl *OPCComRuleDAOImplement) SelectOPCJoinData(PO int, stepNo int) (data []model.OPCCommunicateData, err error) {
	data = make([]model.OPCCommunicateData, 0)
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ?", meta.OPCComRule_PlantNr.ColumnName, meta.OPCComRule_PO.ColumnName, meta.OPCComRule_StepNo.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s and %s = %s", meta.OPCComRule_PlantNr.ColumnName, meta.OPCBasicComInfo_PlantNr.ColumnName, meta.OPCComRule_PO.ColumnName, meta.OPCBasicComInfo_PO.ColumnName, meta.OPCComRule_StepNo.ColumnName, meta.OPCBasicComInfo_StepNo.ColumnName)
	err = session.Join("LEFT", meta.OPCBasicComInfo.TableName, condition).Where(where, impl.plantNr, PO, stepNo).Find(&data)
	return data, err

}