// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : OperationDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Operation的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
type OperationDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewOperationDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个OperationDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : OperationDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func NewOperationDAOImplement(session *xorm.Session, plantNr int, userid string) *OperationDAOImplement {
	return &OperationDAOImplement{session, &meta.Operation, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.InsertOne
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) InsertOne(entity *model.Operation) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) DeleteOne(operationId int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, operationId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.SelectOne
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) SelectOne(operationId int) (*model.Operation, error) {
	var data model.Operation
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, operationId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) UpdateOne(entity *model.Operation) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.Insert
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) Insert(entities *[]model.Operation) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.Delete
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) Delete(entities *[]model.Operation) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Operation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.Select
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Operation, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Operation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.Operation_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.Operation, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Operation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.Operation_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Operation, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.Update
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) Update(entities *[]model.Operation) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.Operation, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.Operation_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.Operation_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/OperationDAO.GetOperationRelData
 *
 ******************************************************************************/
func (impl *OperationDAOImplement) GetOperationRelData(artIdLi []string, workLineId string) ([]model.OperationRelData, error) {
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ? and %s = ?", meta.Operation_PlantNr.ColumnName, meta.Operation_WorkLineId.ColumnName, meta.Process_WorkLineId.ColumnName, meta.Operation_ActivateInStation.ColumnName)
	data := make([]model.OperationRelData, 0)
	POCondition := fmt.Sprintf("%s = %s and %s = %s", meta.Operation_PlantNr.ColumnName, meta.Process_PlantNr.ColumnName, meta.Operation_PO.ColumnName, meta.Process_PO.ColumnName)
	artCondition := fmt.Sprintf("%s = %s and %s = %s and %s = %s", meta.Operation_PlantNr.ColumnName, meta.ArticleAtcodLst_PlantNr.ColumnName, meta.Operation_AttrCode.ColumnName, meta.ArticleAtcodLst_AttrCode.ColumnName, meta.Operation_AttrValue.ColumnName, meta.ArticleAtcodLst_AttrValue.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.Process.TableName, POCondition).Join("LEFT", meta.ArticleAtcodLst.TableName, artCondition)
	artIdStr := ""
	for index, artId := range artIdLi {
		if index != 0 {
			artIdStr += ", "
		}
		artIdStr += artId
	}
	where += fmt.Sprintf(" and ( %s in (%s) or %s = ?) ", meta.ArticleAtcodLst_ArtId.ColumnName, artIdStr, meta.Operation_AttrCode.ColumnName)
	//err := session.Where(where, impl.plantNr, workLineId, 1).In(meta.ArticleAtcodLst_ArtId.ColumnName, artIdLi).OrderBy(meta.Process_PO.ColumnName).OrderBy(meta.Operation_StepNo.ColumnName).Find(&data)
	err := session.Where(where, impl.plantNr, workLineId, workLineId, 1, -1).OrderBy(meta.Process_PO.ColumnName).OrderBy(meta.Operation_StepNo.ColumnName).Find(&data)
	return data, err
}
