// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WeekModelLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WeekModelLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type WeekModelLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWeekModelLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WeekModelLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WeekModelLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewWeekModelLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WeekModelLstDAOImplement {
	return &WeekModelLstDAOImplement{session, &meta.WeekModelLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) InsertOne(entity *model.WeekModelLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) DeleteOne(weekModelNr int, workDate grmi.Date) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, weekModelNr, workDate.ToString()}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) SelectOne(weekModelNr int, workDate grmi.Date) (*model.WeekModelLst, error) {
	var data model.WeekModelLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, weekModelNr, workDate.ToString()}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) UpdateOne(entity *model.WeekModelLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.Insert
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) Insert(entities *[]model.WeekModelLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.Delete
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) Delete(entities *[]model.WeekModelLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WeekModelLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.Select
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WeekModelLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WeekModelLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WeekModelLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WeekModelLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WeekModelLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WeekModelLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WeekModelLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.Update
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) Update(entities *[]model.WeekModelLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WeekModelLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WeekModelLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WeekModelLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

///******************************************************************************
// *
// * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.SelectJoinDayModel
// *
// ******************************************************************************/
//func (impl *WeekModelLstDAOImplement) SelectJoinDayModel(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WeekModelLstAndDay, error) {
//
//	parameters := []interface{}{impl.plantNr}
//	where := "PlantNr = ?"
//
//	session := impl.session.Table(meta.WeekModelLst.TableName)
//	if predicates != nil {
//		for _, predicate := range predicates {
//			where += predicate.Build()
//			parameters = append(parameters, predicate.Values...)
//		}
//		session = session.Where(where, parameters...)
//	} else {
//		session = session.Where(where, parameters...)
//	}
//
//	condition := fmt.Sprintf("%s.PlantNr = %s.PlantNr and %s.%s = %s.%s",
//		meta.WeekModelLst.TableName,
//		meta.DayModel.TableName,
//		meta.WeekModelLst.TableName,
//		meta.WeekModelLst_DayModelNr.ColumnName,
//		meta.DayModel.TableName,
//		meta.WeekModelLst_DayModelNr.ColumnName)
//	session.Join("LEFT", meta.DayModel.TableName, condition)
//	session = session.OrderBy("PlantNr")
//	if orderByFields != nil {
//		for _, field := range orderByFields {
//			session = session.OrderBy(field.ColumnName)
//		}
//	}
//	data := make([]model.WeekModelLstAndDay, 0, 10)
//	err := session.Find(&data)
//	if err != nil {
//		return nil, grmi.NewDataBaseError(err)
//	}
//	return data, nil
//}
/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WeekModelLstDAO.SelectJoinDayModel
 *
 ******************************************************************************/
func (impl *WeekModelLstDAOImplement) SelectJoinDayModel(weekModelNr int) ([]model.WeekModelLstAndDay, error) {

	//parameters := []interface{}{impl.plantNr}
	//where := "PlantNr = ?"

	session := impl.session.Table(meta.WeekModelLst.TableName)
	//if predicates != nil {
	//	for _, predicate := range predicates {
	//		where += predicate.Build()
	//		parameters = append(parameters, predicate.Values...)
	//	}
	//	session = session.Where(where, parameters...)
	//} else {
	//	session = session.Where(where, parameters...)
	//}
	session.Where("WeekModelLst.PlantNr = ? and WeekModelLst.WeekModelNr = ?", impl.plantNr, weekModelNr)
	condition := fmt.Sprintf("%s.PlantNr = %s.PlantNr and %s = %s",
		meta.WeekModelLst.TableName,
		meta.DayModel.TableName,
		meta.WeekModelLst_DayModelNr.ColumnName,
		meta.DayModel_DayModelNr.ColumnName)
	session.Join("LEFT", meta.DayModel.TableName, condition)
	session = session.OrderBy("WeekModelLst.PlantNr")
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}
	data := make([]model.WeekModelLstAndDay, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}
