// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WorkCalendarLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkCalendarLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type WorkCalendarLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkCalendarLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkCalendarLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkCalendarLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewWorkCalendarLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkCalendarLstDAOImplement {
	return &WorkCalendarLstDAOImplement{session, &meta.WorkCalendarLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) InsertOne(entity *model.WorkCalendarLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) DeleteOne(workCalendarNr int, workDate grmi.Date) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workCalendarNr, workDate.ToString()}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) SelectOne(workCalendarNr int, workDate grmi.Date) (*model.WorkCalendarLst, error) {
	var data model.WorkCalendarLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workCalendarNr, workDate.ToString()}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.IsWorkDate
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) IsWorkDate(workDate string) bool {
	var data model.WorkCalendarLst
	ok, err := impl.session.Table(impl.meta.TableName).Where("WorkDate = ?", workDate).Get(&data)
	if err != nil {
		return false
	}
	if !ok {
		return false
	}
	return true
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.SelectNearWorkDate
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) SelectNearWorkDate(workDate string) (*model.WorkCalendarLst, error) {
	var data model.WorkCalendarLst
	ok, err := impl.session.Table(impl.meta.TableName).Where("WorkDate > ?", workDate).Asc("WorkDate").Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) UpdateOne(entity *model.WorkCalendarLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) Insert(entities *[]model.WorkCalendarLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) Delete(entities *[]model.WorkCalendarLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkCalendarLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.Select
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkCalendarLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkCalendarLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WorkCalendarLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkCalendarLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkCalendarLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WorkCalendarLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkCalendarLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.Update
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) Update(entities *[]model.WorkCalendarLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkCalendarLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkCalendarLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkCalendarLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkCalendarDAO.SelectJoinDayModel
 *
 ******************************************************************************/
func (impl *WorkCalendarLstDAOImplement) SelectJoinDayModel(workCalendarNr int) ([]model.WorkCalendarLstAndDay, error) {

	//parameters := []interface{}{impl.plantNr}
	//where := "PlantNr = ?"

	session := impl.session.Table(meta.WorkCalendarLst.TableName)
	//if predicates != nil {
	//	for _, predicate := range predicates {
	//		where += predicate.Build()
	//		parameters = append(parameters, predicate.Values...)
	//	}
	//	session = session.Where(where, parameters...)
	//} else {
	//	session = session.Where(where, parameters...)
	//}
	session.Where("WorkCalendarLst.PlantNr = ? and WorkCalendarLst.WorkCalendarNr = ?", impl.plantNr, workCalendarNr)
	condition := fmt.Sprintf("%s.PlantNr = %s.PlantNr and %s = %s",
		meta.WorkCalendarLst.TableName,
		meta.DayModel.TableName,
		meta.WorkCalendarLst_DayModelNr.ColumnName,
		meta.DayModel_DayModelNr.ColumnName)
	session.Join("LEFT", meta.DayModel.TableName, condition)
	session = session.OrderBy("WorkCalendarLst.PlantNr")
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}

	data := make([]model.WorkCalendarLstAndDay, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}
