// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WorkLineDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkLine的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type WorkLineDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkLineDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkLineDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkLineDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewWorkLineDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkLineDAOImplement {
	return &WorkLineDAOImplement{session, &meta.WorkLine, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) InsertOne(entity *model.WorkLine) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) DeleteOne(workLineid string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workLineid}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) SelectOne(workLineid string) (*model.WorkLine, error) {
	var data model.WorkLine
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workLineid}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) UpdateOne(entity *model.WorkLine) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Insert(entities *[]model.WorkLine) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Delete(entities *[]model.WorkLine) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLine_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.Select
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkLine, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLine_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WorkLine_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkLine, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLine_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WorkLine_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkLine, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.Update
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) Update(entities *[]model.WorkLine) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkLine, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkLine_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkLine_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.SelectByType
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) SelectByType(worklineid string) ([]model.WorkLine, error) {
	datalst := make([]model.WorkLine, 0)
	session := impl.session.Table(impl.meta.TableName)
	if err := session.Where("Plantnr = ? and WorkLineId = ?", impl.plantNr, worklineid).OrderBy("WorkLineId").Find(&datalst); err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return datalst, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/base/WorkLineDAO.SelectAll
 *
 ******************************************************************************/
func (impl *WorkLineDAOImplement) SelectAll() ([]model.WorkLine, error) {
	datalst := make([]model.WorkLine, 0)
	session := impl.session.Table(impl.meta.TableName)
	if err := session.Where("Plantnr = ?", impl.plantNr).OrderBy("WorkLineId").Find(&datalst); err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return datalst, nil
}
