// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/db"
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/log"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"fmt"
	"github.com/go-xorm/xorm"
	"time"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ArtDemandHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArtDemandHead的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type ArtDemandHeadDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArtDemandHeadDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArtDemandHeadDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ArtDemandHeadDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewArtDemandHeadDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtDemandHeadDAOImplement {
	return &ArtDemandHeadDAOImplement{session, &meta.ArtDemandHead, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) InsertOne(entity *model.ArtDemandHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	entity.LastModify = grmi.DateTime(time.Now())
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SyncInsertOne(entity *model.SyncArtDemandHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) DeleteOne(artId string, demandId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, artId, demandId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectOne(artId string, demandId string) (*model.ArtDemandHead, error) {
	var data model.ArtDemandHead
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, artId, demandId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) UpdateOne(entity *model.ArtDemandHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	entity.LastModify = grmi.DateTime(time.Now())
	colLi := impl.meta.UpdatingMembers
	colLi = append(colLi, "LastModify")
	_, err := impl.session.Table(impl.meta.TableName).Cols(colLi...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.SyncUpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SyncUpdateOne(entity *model.SyncArtDemandHead) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(core.PK{entity.PlantNr,entity.ArtId,entity.DemandId}).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}


/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.Insert
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Insert(entities *[]model.ArtDemandHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		entity.LastModify = grmi.DateTime(time.Now())
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.Delete
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Delete(entities *[]model.ArtDemandHead) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.Select
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandHead, error) {
	vendorSession := db.Eloquent.Master().NewSession()
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHead_PlantNr.ColumnName)
	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	if impl.userid != "admin" {
		// 检查是否做了供应商关联
		vendorLi := make([]string, 0)
		err := vendorSession.Table("LOG_VendorUserLst").Where("PlantNr = ? and UserId = ?", impl.plantNr, impl.userid).Cols("VendorId").Find(&vendorLi)
		if err != nil {
			return nil, err
		}
		if len(vendorLi) != 0 {
			session = session.Where("ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?))", impl.userid)
		}
	}
	//session = session.Where("(( LOG_ArtDemandHead.Source in (?, ?) and LOG_ArtDemandHead.OrderStatus <= ? ) or ( LOG_ArtDemandHead.Source = ? and LOG_ArtDemandHead.OrderStatus <= ? ))", baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	//session = session.OrderBy(meta.ArtDemandHead_PlantNr.ColumnName)
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}
	session = session.OrderBy(meta.ArtDemandHead_WorkOrderId.ColumnName)
	data := make([]model.ArtDemandHead, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.Select
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectUnByUser(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandHead, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	//if impl.userid != "admin" {
	//	session = session.Where("ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?))", impl.userid)
	//}
	//session = session.Where("(( LOG_ArtDemandHead.Source in (?, ?) and LOG_ArtDemandHead.OrderStatus <= ? ) or ( LOG_ArtDemandHead.Source = ? and LOG_ArtDemandHead.OrderStatus <= ? ))", baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	//session = session.OrderBy(meta.ArtDemandHead_PlantNr.ColumnName)
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}
	session = session.OrderBy(meta.ArtDemandHead_WorkOrderId.ColumnName)
	data := make([]model.ArtDemandHead, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	vendorSession := db.Eloquent.Master().NewSession()
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	if impl.userid != "admin" {
		// 检查是否做了供应商关联
		vendorLi := make([]string, 0)
		err := vendorSession.Table("LOG_VendorUserLst").Where("PlantNr = ? and UserId = ?", impl.plantNr, impl.userid).Cols("VendorId").Find(&vendorLi)
		if err != nil {
			return grmi.EmptyPagingResult, err
		}
		if len(vendorLi) != 0 {
			where += " and ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?)) "
			parameters = append(parameters, impl.userid)
			session = session.Where("ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?))", impl.userid)
		}
	}
	//where += fmt.Sprintf(" and (( LOG_ArtDemandHead.Source in (?, ?) and LOG_ArtDemandHead.OrderStatus <= ? ) or ( LOG_ArtDemandHead.Source = ? and LOG_ArtDemandHead.OrderStatus <= ? )) ")
	//parameters = append(parameters, baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	//session = session.Where("(( LOG_ArtDemandHead.Source in (?, ?) and LOG_ArtDemandHead.OrderStatus <= ? ) or ( LOG_ArtDemandHead.Source = ? and LOG_ArtDemandHead.OrderStatus <= ? ))", baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ArtDemandHead_WorkOrderId.ColumnName

	//orderBy := " order by " + meta.ArtDemandHead_PlantNr.ColumnName
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		orderBy += ", " + field.ColumnName
	//	}
	//}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtDemandHead, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.Update
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) Update(entities *[]model.ArtDemandHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		entity.LastModify = grmi.DateTime(time.Now())
		colLi := impl.meta.UpdatingMembers
		colLi = append(colLi, "LastModify")
		_, err := impl.session.Table(impl.meta.TableName).Cols(colLi...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ArtDemandHead, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ArtDemandHead_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.SelectByEndDate
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectByEndDate(artId string, endDate string) ([]model.ArtDemandHead, error) {
	data := make([]model.ArtDemandHead, 0, 1)
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHead_PlantNr.ColumnName)
	where += fmt.Sprintf(" and %s = ? and %s = ? ", meta.ArtDemandHead_ArtId.ColumnName, meta.ArtDemandHead_DemandDate.ColumnName)
	parameters = append(parameters, artId, endDate)

	err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.SelectByLastModifyTime
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectByLastModifyTime(lastTime string) ([]model.ArtDemandHead, error) {
	data := make([]model.ArtDemandHead, 0)
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ? and %s > ?", meta.ArtDemandHead_PlantNr.ColumnName, meta.ArtDemandHead_LastModify.ColumnName)
	parameters = append(parameters, lastTime)
	err := impl.session.Table(impl.meta.TableName).Where(where, parameters...).Asc(meta.ArtDemandHead_LastModify.ColumnName).Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.UpdateWithoutModifyTime
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) UpdateWithoutModifyTime(entities *[]model.ArtDemandHead) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		colLi := impl.meta.UpdatingMembers
		colLi = append(colLi, "LastModify")
		_, err := impl.session.Table(impl.meta.TableName).Cols(colLi...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.SelectWithoutAuthority
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectWithoutAuthority (predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandHead, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHead_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	session = session.OrderBy(meta.ArtDemandHead_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ArtDemandHead, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}
/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.SelectLastModify
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) SelectLastModify() (data model.ArtDemandHead, err error) {
	ok, err := impl.session.Table(impl.meta.TableName).Where("PlantNr = ? ", impl.plantNr).Desc("LastModify").Limit(1).Get(&data)
	if err != nil {
		return data, grmi.NewDataBaseError(err)
	}
	if !ok {
		return data, grmi.NewBusinessError("数据不存在!")
	}
	return data, nil
}


/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadDAO.ClearOldData
 *
 ******************************************************************************/
func (impl *ArtDemandHeadDAOImplement) ClearOldData(end string) error {

	session := impl.session.Table(impl.meta.TableName)
	where := fmt.Sprintf("%s < ?", meta.ArtDemandHead_CreateTime.ColumnName)
	session = session.Where(where, end)
	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}