// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/log"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ArtDemandHeadCacheDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArtDemandHeadCache的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
type ArtDemandHeadCacheDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArtDemandHeadCacheDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArtDemandHeadCacheDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ArtDemandHeadCacheDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func NewArtDemandHeadCacheDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtDemandHeadCacheDAOImplement {
	return &ArtDemandHeadCacheDAOImplement{session, &meta.ArtDemandHeadCache, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) InsertOne(entity *model.ArtDemandHeadCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.SyncInsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) SyncInsertOne(entity *model.SyncArtDemandHeadCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) DeleteOne(artId string, demandId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, artId, demandId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) SelectOne(artId string, demandId string) (*model.ArtDemandHeadCache, error) {
	var data model.ArtDemandHeadCache
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, artId, demandId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) UpdateOne(entity *model.ArtDemandHeadCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.SyncUpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) SyncUpdateOne(entity *model.SyncArtDemandHeadCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(core.PK{entity.PlantNr,entity.ArtId,entity.DemandId}).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.Insert
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) Insert(entities *[]model.ArtDemandHeadCache) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.Delete
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) Delete(entities *[]model.ArtDemandHeadCache) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHeadCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.Select
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandHeadCache, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHeadCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ArtDemandHeadCache_PlantNr.ColumnName)
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}
	session.OrderBy(meta.ArtDemandHeadCache_WorkOrderId.ColumnName)
	data := make([]model.ArtDemandHeadCache, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHeadCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ArtDemandHeadCache_WorkOrderId.ColumnName
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		orderBy += ", " + field.ColumnName
	//	}
	//}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtDemandHeadCache, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.Update
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) Update(entities *[]model.ArtDemandHeadCache) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandHeadCacheDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArtDemandHeadCacheDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ArtDemandHeadCache, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandHeadCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ArtDemandHeadCache_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
