// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/db"
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/log"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"fmt"
	"github.com/go-xorm/xorm"
	"time"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ArtDemandLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArtDemandLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
type ArtDemandLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArtDemandLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArtDemandLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ArtDemandLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 11:27:55
 *
 ******************************************************************************/
func NewArtDemandLstDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtDemandLstDAOImplement {
	return &ArtDemandLstDAOImplement{session, &meta.ArtDemandLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) InsertOne(entity *model.ArtDemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	entity.LastModify = grmi.DateTime(time.Now())
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.SyncInsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SyncInsertOne(entity *model.SyncArtDemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) DeleteOne(demandId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, demandId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SelectOne(demandId string, pos int) (*model.ArtDemandLst, error) {
	var data model.ArtDemandLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, demandId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) UpdateOne(entity *model.ArtDemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	entity.LastModify = grmi.DateTime(time.Now())
	colLi := impl.meta.UpdatingMembers
	colLi = append(colLi, "LastModify")
	_, err := impl.session.Table(impl.meta.TableName).Cols(colLi...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SyncUpdateOne(entity *model.SyncArtDemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(core.PK{entity.PlantNr,entity.DemandId,entity.Pos}).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.Insert
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Insert(entities *[]model.ArtDemandLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		entity.LastModify = grmi.DateTime(time.Now())
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.Delete
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Delete(entities *[]model.ArtDemandLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.Select
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandLst, error) {
	vendorSession := db.Eloquent.Master().NewSession()
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	if impl.userid != "admin" {
		// 检查是否做了供应商关联
		vendorLi := make([]string, 0)
		err := vendorSession.Table("LOG_VendorUserLst").Where("PlantNr = ? and UserId = ?", impl.plantNr, impl.userid).Cols("VendorId").Find(&vendorLi)
		if err != nil {
			return nil, err
		}
		if len(vendorLi) != 0 {
			session = session.Where("ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?))", impl.userid)
		}
	}
	//session = session.Where("(( LOG_ArtDemandLst.Source in (?, ?) and LOG_ArtDemandLst.OrderStatus <= ? ) or ( LOG_ArtDemandLst.Source = ? and LOG_ArtDemandLst.OrderStatus <= ? ))", baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	session = session.OrderBy(meta.ArtDemandLst_DemandCtrlPara1.ColumnName).OrderBy(meta.ArtDemandLst_DemandCtrlPara2.ColumnName)
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}

	data := make([]model.ArtDemandLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.SelectUnByUser
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SelectUnByUser(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	//if impl.userid != "admin" {
	//	session = session.Where("ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?))", impl.userid)
	//}
	//session = session.Where("(( LOG_ArtDemandLst.Source in (?, ?) and LOG_ArtDemandLst.OrderStatus <= ? ) or ( LOG_ArtDemandLst.Source = ? and LOG_ArtDemandLst.OrderStatus <= ? ))", baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	//session = session.OrderBy(meta.ArtDemandLst_PlantNr.ColumnName)
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}
	session = session.OrderBy(meta.ArtDemandLst_DemandCtrlPara1.ColumnName).OrderBy(meta.ArtDemandLst_DemandCtrlPara2.ColumnName)
	data := make([]model.ArtDemandLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {
	vendorSession := db.Eloquent.Master().NewSession()
	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}
	if impl.userid != "admin" {
		// 检查是否做了供应商关联
		vendorLi := make([]string, 0)
		err := vendorSession.Table("LOG_VendorUserLst").Where("PlantNr = ? and UserId = ?", impl.plantNr, impl.userid).Cols("VendorId").Find(&vendorLi)
		if err != nil {
			return grmi.EmptyPagingResult, err
		}
		if len(vendorLi) != 0 {
			where += " and ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?)) "
			parameters = append(parameters, impl.userid)
			session = session.Where("ArtId in (select ArtId from LOG_VendorArtLst where VendorId in (select VendorId from LOG_VendorUserLst where UserId = ?))", impl.userid)
		}

	}
	//where += fmt.Sprintf(" and (( LOG_ArtDemandLst.Source in (?, ?) and LOG_ArtDemandLst.OrderStatus <= ? ) or ( LOG_ArtDemandLst.Source = ? and LOG_ArtDemandLst.OrderStatus <= ? )) ")
	//parameters = append(parameters, baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	//session = session.Where("(( LOG_ArtDemandLst.Source in (?, ?) and LOG_ArtDemandLst.OrderStatus <= ? ) or ( LOG_ArtDemandLst.Source = ? and LOG_ArtDemandLst.OrderStatus <= ? ))", baseModel.ODER_TYPE_INTERVAL, baseModel.ODER_TYPE_REODER, baseModel.WO_STATUS_RUNNING, baseModel.ODER_TYPE_SEQ, baseModel.WO_STATUS_RELEASED)
	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ArtDemandLst_DemandCtrlPara1.ColumnName + "," + meta.ArtDemandLst_DemandCtrlPara2.ColumnName
	//orderBy := " order by " + meta.ArtDemandLst_PlantNr.ColumnName
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		orderBy += ", " + field.ColumnName
	//	}
	//}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtDemandLst, 0, 10)
	if where != "" {
		where = " where " + where
	}

	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.Update
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) Update(entities *[]model.ArtDemandLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		colLi := impl.meta.UpdatingMembers
		colLi = append(colLi, "LastModify")
		_, err := impl.session.Table(impl.meta.TableName).Cols(colLi...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ArtDemandLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ArtDemandLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.DeleteByHead
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) DeleteByHead(records *[]model.ArtDemandItem) error {
	for _, item := range *records {
		_, err := impl.session.Table(meta.ArtDemandLst.TableName).Where("PlantNr = ? and ArtId = ? and DemandId = ?", impl.plantNr, item.ArtId, item.DemandId).Delete(impl)
		if err != nil {
			return err
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.UpdateWithoutModifyTime
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) UpdateWithoutModifyTime(entities *[]model.ArtDemandLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		colLi := impl.meta.UpdatingMembers
		colLi = append(colLi, "LastModify")
		_, err := impl.session.Table(impl.meta.TableName).Cols(colLi...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}


/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAO.SelectWithoutAuthority
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) SelectWithoutAuthority (predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.ArtDemandLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ArtDemandLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstDAOImplement.ClearOldData
 *
 ******************************************************************************/
func (impl *ArtDemandLstDAOImplement) ClearOldData(end string) error {

	session := impl.session.Table(impl.meta.TableName)
	where := fmt.Sprintf("%s < ?", meta.ArtDemandLst_CreateTime.ColumnName)
	session = session.Where(where, end)
	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}