// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/log"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ArtDemandLstCacheDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArtDemandLstCache的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
type ArtDemandLstCacheDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArtDemandLstCacheDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArtDemandLstCacheDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : ArtDemandLstCacheDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func NewArtDemandLstCacheDAOImplement(session *xorm.Session, plantNr int, userid string) *ArtDemandLstCacheDAOImplement {
	return &ArtDemandLstCacheDAOImplement{session, &meta.ArtDemandLstCache, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) InsertOne(entity *model.ArtDemandLstCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.SyncInsertOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) SyncInsertOne(entity *model.SyncArtDemandLstCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) DeleteOne(demandId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, demandId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) SelectOne(demandId string, pos int) (*model.ArtDemandLstCache, error) {
	var data model.ArtDemandLstCache
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, demandId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) UpdateOne(entity *model.ArtDemandLstCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.SyncUpdateOne
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) SyncUpdateOne(entity *model.SyncArtDemandLstCache) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(core.PK{entity.PlantNr,entity.DemandId,entity.Pos}).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.Insert
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) Insert(entities *[]model.ArtDemandLstCache) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.Delete
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) Delete(entities *[]model.ArtDemandLstCache) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLstCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.Select
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.ArtDemandLstCache, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLstCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	//session = session.OrderBy(meta.ArtDemandLstCache_PlantNr.ColumnName)
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		session = session.OrderBy(field.ColumnName)
	//	}
	//}
	session = session.OrderBy(meta.ArtDemandLstCache_DemandCtrlPara1.ColumnName).OrderBy(meta.ArtDemandLstCache_DemandCtrlPara2.ColumnName)
	data := make([]model.ArtDemandLstCache, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLstCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.ArtDemandLstCache_DemandCtrlPara1.ColumnName + "," +meta.ArtDemandLstCache_DemandCtrlPara2.ColumnName
	//if orderByFields != nil {
	//	for _, field := range orderByFields {
	//		orderBy += ", " + field.ColumnName
	//	}
	//}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArtDemandLstCache, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.Update
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) Update(entities *[]model.ArtDemandLstCache) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/ArtDemandLstCacheDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArtDemandLstCacheDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.ArtDemandLstCache, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.ArtDemandLstCache_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.ArtDemandLstCache_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
