// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/log"
	common "LAPP_LF_MOM_BACKEND/models/base"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : PackOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : PackOrder的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type PackOrderDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewPackOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个PackOrderDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : PackOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewPackOrderDAOImplement(session *xorm.Session, plantNr int, userid string) *PackOrderDAOImplement {
	return &PackOrderDAOImplement{session, &meta.PackOrder, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.InsertOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) InsertOne(entity *model.PackOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) DeleteOne(packOrderId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, packOrderId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.SelectOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectOne(packOrderId string) (*model.PackOrder, error) {
	var data model.PackOrder
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, packOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) UpdateOne(entity *model.PackOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.Insert
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Insert(entities *[]model.PackOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.Delete
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Delete(entities *[]model.PackOrder) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.Select
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.PackOrder, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.PackOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.PackOrder, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.PackOrder_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.PackOrder, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.Update
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) Update(entities *[]model.PackOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.PackOrder, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.PackOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.PackOrder_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/PackOrderDAO.SelectActivePackOrder
 *
 ******************************************************************************/
func (impl *PackOrderDAOImplement) SelectActivePackOrder(artId string) ([]model.PackOrder,error) {
	data := make([]model.PackOrder,0)
	//查询是否有符合开口的包装单
	err := impl.session.Table(impl.meta.TableName).Select("LOG_PackOrder.*").Distinct("LOG_PackOrder.PackOrderId").Join("INNER","LOG_PackOrderItemlst","LOG_PackOrderItemlst.PlantNr = LOG_PackOrder.PlantNr and LOG_PackOrderItemlst.PackOrderId = LOG_PackOrder.PackOrderId").Where("LOG_PackOrderItemlst.PlantNr = ? and LOG_PackOrderItemlst.MaterialId = ? and LOG_PackOrder.Status = ?",impl.plantNr,artId,common.PACK_STATUS_RELEASED).Find(&data)
	if err != nil {
		return nil,grmi.NewDataBaseError(err)
	}
	return data,nil
}