// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/log"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : VendorArtLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : VendorArtLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type VendorArtLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewVendorArtLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个VendorArtLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : VendorArtLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewVendorArtLstDAOImplement(session *xorm.Session, plantNr int, userid string) *VendorArtLstDAOImplement {
	return &VendorArtLstDAOImplement{session, &meta.VendorArtLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) InsertOne(entity *model.VendorArtLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) DeleteOne(vendorId string, artId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, vendorId, artId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) SelectOne(vendorId string, artId string) (*model.VendorArtLst, error) {
	var data model.VendorArtLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, vendorId, artId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) UpdateOne(entity *model.VendorArtLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.Insert
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) Insert(entities *[]model.VendorArtLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.Delete
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) Delete(entities *[]model.VendorArtLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorArtLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.Select
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.VendorArtLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorArtLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.VendorArtLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.VendorArtLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorArtLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.VendorArtLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.VendorArtLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.Update
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) Update(entities *[]model.VendorArtLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.VendorArtLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorArtLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.VendorArtLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.DeleteByVendor
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) DeleteByVendor(vendors []string) error {
	_, err := impl.session.Table(meta.VendorArtLst.TableName).Where("PlantNr = ?", impl.plantNr).In("VendorId", vendors).Delete(meta.VendorArtLst.Indicator)
	return err
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorArtLstDAO.GetMaxPos
 *
 ******************************************************************************/
func (impl *VendorArtLstDAOImplement) GetMaxPos(vendorId string) (pos int, err error) {
	data := make([]model.VendorArtLst, 0, 1)
	err = impl.session.Table(meta.VendorArtLst.TableName).Where("PlantNr = ? and VendorId = ?", impl.plantNr, vendorId).Desc("Pos").Limit(1, 0).Find(&data)
	if err != nil {
		return
	}
	if len(data) == 0 {
		return 0, nil
	}
	return data[0].Pos, nil
}
