// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/log"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : VendorUserLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : VendorUserLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
type VendorUserLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewVendorUserLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个VendorUserLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : VendorUserLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 12:11:47
 *
 ******************************************************************************/
func NewVendorUserLstDAOImplement(session *xorm.Session, plantNr int, userid string) *VendorUserLstDAOImplement {
	return &VendorUserLstDAOImplement{session, &meta.VendorUserLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) InsertOne(entity *model.VendorUserLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) DeleteOne(vendorId string, userId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, vendorId, userId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) SelectOne(vendorId string, userId string) (*model.VendorUserLst, error) {
	var data model.VendorUserLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, vendorId, userId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) UpdateOne(entity *model.VendorUserLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.Insert
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) Insert(entities *[]model.VendorUserLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.Delete
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) Delete(entities *[]model.VendorUserLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorUserLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.Select
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.VendorUserLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorUserLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.VendorUserLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.VendorUserLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorUserLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.VendorUserLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.VendorUserLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.Update
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) Update(entities *[]model.VendorUserLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.VendorUserLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.VendorUserLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.VendorUserLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.DeleteByVendor
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) DeleteByVendor(vendors []string) error {
	_, err := impl.session.Table(meta.VendorUserLst.TableName).Where("PlantNr = ?", impl.plantNr).In("VendorId", vendors).Delete(meta.VendorUserLst.Indicator)
	return err
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/log/VendorUserLstDAO.GetMaxPos
 *
 ******************************************************************************/
func (impl *VendorUserLstDAOImplement) GetMaxPos(vendorId string) (pos int, err error) {
	data := make([]model.VendorUserLst, 0, 1)
	err = impl.session.Table(meta.VendorUserLst.TableName).Where("PlantNr = ? and VendorId = ?", impl.plantNr, vendorId).Desc("Pos").Limit(1, 0).Find(&data)
	if err != nil {
		return
	}
	if len(data) == 0 {
		return 0, nil
	}
	return data[0].Pos, nil
}
