// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	"LAPP_LF_MOM_BACKEND/dao/om/implments"
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/om"
	"github.com/go-xorm/xorm"
	"time"
)

/******************************************************************************
 *
 * @Interface Name           : WorkOrderDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkOrder的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
type WorkOrderDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条WorkOrder
	 *
	 * @Function Parameters      : 需要插入的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	InsertOne(*model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	DeleteOne(string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectOne(string) (*model.WorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改WorkOrder
	 *
	 * @Function Parameters      : 需要修改的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	UpdateOne(*model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOrderOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改WorkOrder
	 *
	 * @Function Parameters      : 需要修改的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 娄文智
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	UpdateOrderOne(*model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条WorkOrder
	 *
	 * @Function Parameters      : 需要插入的WorkOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Insert(*[]model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条WorkOrder
	 *
	 * @Function Parameters      : 需要删除的WorkOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Delete(*[]model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询WorkOrder
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.WorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询WorkOrder并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条WorkOrder
	 *
	 * @Function Parameters      : 需要修改的WorkOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Update(*[]model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.WorkOrder, ...string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectInfo(string) (model.WorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectLockedTasks
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查找WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectLockedTasks(time.Time, time.Time, string) ([]model.WorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectStartedTasks
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查找WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectStartedTasks(time.Time, time.Time, string) ([]model.WorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectPlannedTasks
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查找WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectPlannedTasks(time.Time, time.Time, string) (datalst []model.WorkOrder, err error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectUnPlannedTasks
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查找WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectUnPlannedTasks(string) (datalst []model.WorkOrder, err error)
	/******************************************************************************
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询WorkOrder
	 *
	 * @Function Parameters      : 物料id
	 *
	 * @Function Parameters      : endDate
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 张鑫
	 *
	 * @Date                     : 2021-04-13
	 *
	 ******************************************************************************/
	SelectByEndDate(string, string, string) ([]model.WorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectByPage
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询WorkOrderJoin
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 张鑫
	 *
	 * @Date                     : 2021-04-27
	 *
	 ******************************************************************************/
	SelectByPage(string, string, string, string, string, string, int, int, int, []string) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectLockWorkOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询最后一条WorkOrder
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 张鑫
	 *
	 * @Date                     : 2021-05-07
	 *
	 ******************************************************************************/
	SelectLockWorkOrder(string) ([]model.WorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectOneJoin
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkOrder 同时连表查询workOrderStatus和workOrderQty
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectOneJoin(string) (*model.VOmWorkorder, error)
	/******************************************************************************
	 *
	 * @Function Name            : DeleteByProjectAndEndDate
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 根据projectId和planEndDate删除workOrder
	 *
	 * @Function Parameters      : projectId
	 *
	 * @Function Parameters      : planEndDate
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-06-08
	 *
	 ******************************************************************************/
	DeleteByProjectAndEndDate(string, string, string) error
	/******************************************************************************
	 *
	 * @Function Name            : ClearOldData
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 清理旧数据
	 *
	 * @Function Parameters      : 截止时间
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-06-22
	 *
	 ******************************************************************************/
	ClearOldData(string) error
}

/******************************************************************************
 *
 * @Function Name            : NewWorkOrderDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkOrderDAO实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkOrderDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func NewWorkOrderDAO(session *xorm.Session, plantNr int, userid string) WorkOrderDAO {
	return implments.NewWorkOrderDAOImplement(session, plantNr, userid)
}
