// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/om"
	model "LAPP_LF_MOM_BACKEND/models/om"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : DemandLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : DemandLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
type DemandLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewDemandLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个DemandLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : DemandLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func NewDemandLstDAOImplement(session *xorm.Session, plantNr int, userid string) *DemandLstDAOImplement {
	return &DemandLstDAOImplement{session, &meta.DemandLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) InsertOne(entity *model.DemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) DeleteOne(fileNr int, pos int, taskNr int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, fileNr, pos, taskNr}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) SelectOne(fileNr int, pos int, taskNr int) (*model.DemandLst, error) {
	var data model.DemandLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, fileNr, pos, taskNr}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) UpdateOne(entity *model.DemandLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.Insert
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) Insert(entities *[]model.DemandLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.Delete
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) Delete(entities *[]model.DemandLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.DemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.Select
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.DemandLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.DemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.DemandLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.DemandLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.DemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.DemandLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.DemandLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.Update
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) Update(entities *[]model.DemandLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.DemandLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.DemandLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.DemandLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.SelectAndOrderBy
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) SelectAndOrderBy(id int, dependOn string) ([]model.DemandLst, error) {
	sql := fmt.Sprintf(`select * from %s where %s = %d order by convert(int,Serial),Seq`, impl.meta.TableName, dependOn, id)
	result := make([]model.DemandLst, 0)
	err := impl.session.Table(impl.meta.TableName).SQL(sql).Find(&result)
	return result, err
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.SelectDistinctPlanEndDate
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) SelectDistinctPlanEndDate(id int, dependOn string) ([]grmi.Date, error) {
	result := make([]grmi.DateTime, 0)
	where := fmt.Sprintf("%s = ? and %s = ?", meta.DemandLst_PlantNr.ColumnName, dependOn)
	err := impl.session.Table(impl.meta.TableName).Where(where, impl.plantNr, id).Distinct(meta.DemandLst_PlanDttm.ColumnName).Find(&result)
	if err != nil {
		return nil, err
	}
	dateMap := make(map[grmi.Date]interface{})
	for _, datetime := range result {
		dateMap[grmi.Date(datetime)] = nil
	}
	data := make([]grmi.Date, 0)
	for date, _ := range dateMap {
		data = append(data, date)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/DemandLstDAO.SelectDistinctConfigKey
 *
 ******************************************************************************/
func (impl *DemandLstDAOImplement) SelectDistinctConfigKey(id int, dependOn string) ([]string, error) {
	result := make([]string, 0)
	where := fmt.Sprintf("%s = ? and %s = ?", meta.DemandLst_PlantNr.ColumnName, dependOn)
	err := impl.session.Table(impl.meta.TableName).Where(where, impl.plantNr, id).Distinct(meta.DemandLst_ConfigKey.ColumnName).Find(&result)
	return result, err
}
