// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/om"
	common "LAPP_LF_MOM_BACKEND/models/base"
	model "LAPP_LF_MOM_BACKEND/models/om"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : SerialOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : SerialOrder的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-20 13:07:32
 *
 ******************************************************************************/
type SerialOrderDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewSerialOrderDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SerialOrderDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : SerialOrderDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-20 13:07:32
 *
 ******************************************************************************/
func NewSerialOrderDAOImplement(session *xorm.Session, plantNr int, userid string) *SerialOrderDAOImplement {
	return &SerialOrderDAOImplement{session, &meta.SerialOrder, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.InsertOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) InsertOne(entity *model.SerialOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) DeleteOne(workOrderId string, serialOrderId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, serialOrderId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.SelectOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectOne(workOrderId string, serialOrderId string) (*model.SerialOrder, error) {
	var data model.SerialOrder
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, serialOrderId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateOne(entity *model.SerialOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.SelectBySerialOrder
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectBySerialOrder(serialOrderId string) (*model.SerialOrder, error) {
	var data model.SerialOrder
	ok, err := impl.session.Table(impl.meta.TableName).Where("PlantNr = ? and SerialOrderId = ?", impl.plantNr, serialOrderId).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateInfo
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateInfo(entity *model.SerialOrder) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).Where("PlantNr = ? and SerialOrderId = ?", impl.plantNr, entity.SerialOrderId).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.Insert
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Insert(entities *[]model.SerialOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.Delete
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Delete(entities *[]model.SerialOrder) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.Select
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.SerialOrder, error) {
	data := make([]model.VOmSerialorder, 0)
	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	session = session.Join("LEFT", meta.SerialOrderStatus.TableName, condition)

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.SerialOrder_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}
	session = session.Asc(meta.SerialOrder_PlanStartTime.ColumnName)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	serialOrderLi := make([]model.SerialOrder, 0, len(data))
	for _, item := range data {
		var serialOrder model.SerialOrder
		serialOrder = item.SerialOrder
		serialOrder.SerialOrderStatus = item.SerialOrderStatus
		serialOrderLi = append(serialOrderLi, serialOrder)
	}
	return serialOrderLi, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.SerialOrder_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.SerialOrder, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.Update
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) Update(entities *[]model.SerialOrder) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.SerialOrder, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.SerialOrder_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.SerialOrder_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.SelectByWorkOrderId
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectByWorkOrderId(workOrderId string, status int) (serialOrderLi []model.SerialOrder, err error) {
	data := make([]model.VOmSerialorder, 0)

	session := impl.session.Table(impl.meta.TableName)
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	where := fmt.Sprintf("%s = ? and %s = ? and %s = ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_WorkOrderId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName)
	//err = session.Join("LEFT", meta.SerialOrderStatus.TableName, condition).Where(where, impl.plantNr, workOrderId, common.WO_STATUS_LOCKED).Asc(meta.SerialOrder_SerialOrderId.ColumnName).Find(&data)
	err = session.Join("LEFT", meta.SerialOrderStatus.TableName, condition).Where(where, impl.plantNr, workOrderId, status).Asc(meta.SerialOrder_SerialOrderId.ColumnName).Find(&data)
	if err != nil {
		return nil, err
	}
	serialOrderLi = make([]model.SerialOrder, 0, len(data))
	for _, item := range data {
		var serialOrder model.SerialOrder
		serialOrder = item.SerialOrder
		serialOrder.SerialOrderStatus = item.SerialOrderStatus
		serialOrderLi = append(serialOrderLi, serialOrder)
	}
	return serialOrderLi, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.SelectInfo
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) SelectInfo(workOrderId string) (data model.SerialOrder, err error) {
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId}).Get(&data)
	if err != nil {
		return data, grmi.NewDataBaseError(err)
	}
	if !ok {
		return data, nil
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/SerialOrderDAO.GetLineWIPQty
 *
 ******************************************************************************/
func (impl *SerialOrderDAOImplement) GetLineWIPQty(lineid string) (wipqty int, err error) {
	var (
		totalrow    int64
		serialOrder model.SerialOrder
	)

	session := impl.session.Table(impl.meta.TableName)
	wipqty = 0
	condition := fmt.Sprintf("%s = %s and %s = %s",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrderStatus_PlantNr.ColumnName,
		meta.SerialOrder_SerialOrderId.ColumnName,
		meta.SerialOrderStatus_SerialOrderId.ColumnName)
	where := fmt.Sprintf("%s = ? and %s = ? and %s >= ? and %s < ?",
		meta.SerialOrder_PlantNr.ColumnName,
		meta.SerialOrder_PlanResourceId.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName,
		meta.SerialOrderStatus_Status.ColumnName)
	if totalrow, err = session.Join("INNER", meta.SerialOrderStatus.TableName,
		condition).Where(where, impl.plantNr, lineid, common.WO_STATUS_RELEASED, common.WO_STATUS_FINISHED).Count(&serialOrder); err != nil {
		return
	}
	wipqty = int(totalrow)
	return
}
