// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/om"
	common "LAPP_LF_MOM_BACKEND/models/base"
	model "LAPP_LF_MOM_BACKEND/models/om"
	"errors"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WorkOrderStatusRecLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkOrderStatusRecLst的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
type WorkOrderStatusRecLstDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	plantNr int
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkOrderStatusRecLstDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkOrderStatusRecLstDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : WorkOrderStatusRecLstDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func NewWorkOrderStatusRecLstDAOImplement(session *xorm.Session, plantNr int, userid string) *WorkOrderStatusRecLstDAOImplement {
	return &WorkOrderStatusRecLstDAOImplement{session, &meta.WorkOrderStatusRecLst, plantNr, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) InsertOne(entity *model.WorkOrderStatusRecLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) DeleteOne(workOrderId string, pos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, pos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) SelectOne(workOrderId string, pos int) (*model.WorkOrderStatusRecLst, error) {
	var data model.WorkOrderStatusRecLst
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{impl.plantNr, workOrderId, pos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) UpdateOne(entity *model.WorkOrderStatusRecLst) error {
	entity.PlantNr = impl.plantNr
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) Insert(entities *[]model.WorkOrderStatusRecLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) Delete(entities *[]model.WorkOrderStatusRecLst) error {
	for _, entity := range *entities {
		entity.PlantNr = impl.plantNr
		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkOrderStatusRecLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.Select
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkOrderStatusRecLst, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkOrderStatusRecLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	session = session.OrderBy(meta.WorkOrderStatusRecLst_PlantNr.ColumnName)
	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkOrderStatusRecLst, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkOrderStatusRecLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	orderBy := " order by " + meta.WorkOrderStatusRecLst_PlantNr.ColumnName
	if orderByFields != nil {
		for _, field := range orderByFields {
			orderBy += ", " + field.ColumnName
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkOrderStatusRecLst, 0, 10)
	if where != "" {
		where = " where " + where
	}
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.Update
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) Update(entities *[]model.WorkOrderStatusRecLst) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]
		entity.PlantNr = impl.plantNr
		entity.LastUser = impl.userid

		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkOrderStatusRecLst, columns ...string) error {

	parameters := []interface{}{impl.plantNr}
	where := fmt.Sprintf("%s = ?", meta.WorkOrderStatusRecLst_PlantNr.ColumnName)

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkOrderStatusRecLst_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAO.SelectByEvent
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) SelectByEvent(event string) (datalst []model.WorkOrderStatusRecLst, err error) {
	session := impl.session.Table(impl.meta.TableName)
	/**主键：****/
	if err = session.Where("PlantNr = ? and OutputEvent = ? and OutputStatus = ?",impl.plantNr, event, common.OUTPUT_TRIGGER_UNHANDLED).OrderBy("CreateTime").Find(&datalst); err != nil {
		return
	}
	return
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAOImplement.GetMaxPos
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) GetMaxPos(workOrderId string) (int, error) {

	parameters := []interface{}{impl.plantNr}
	parameters = append(parameters, workOrderId)
	where := fmt.Sprintf("%s = ?", meta.WorkOrderStatusRecLst_PlantNr.ColumnName)
	where += fmt.Sprintf(" and %s = ? ", meta.WorkOrderStatusRecLst_WorkOrderId.ColumnName)
	session := impl.session.Table(impl.meta.TableName)
	session = session.Where(where, parameters...).Desc(meta.WorkOrderStatusRecLst_Pos.ColumnName).Limit(1)
	data := make([]model.WorkOrderStatusRecLst, 0, 1)
	err := session.Find(&data)
	if err != nil {
		return 0, grmi.NewDataBaseError(err)
	}
	fmt.Println("data:", data)
	if len(data) == 0 {
		return 0, nil
	}
	return  data[0].Pos, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/om/WorkOrderStatusRecLstDAOImplement.GetWorkOrderToMes
 *
 ******************************************************************************/
func (impl *WorkOrderStatusRecLstDAOImplement) GetWorkOrderToMes() ([]model.VOmWorkorderJoinRec, error) {
	where := fmt.Sprintf("%s = ?", meta.WorkOrderStatusRecLst_PlantNr.ColumnName)
	session := impl.session.Table(impl.meta.TableName)
	session = session.Where(where, impl.plantNr)
	statusRecLi := make([]model.WorkOrderStatusRecLst, 0, 100)
	err := session.Where(fmt.Sprintf("%s = ? and %s = ? and %s = ? and %s < ?",
		meta.WorkOrderStatusRecLst_Status.ColumnName,
		meta.WorkOrderStatusRecLst_OutputEvent.ColumnName,
		meta.WorkOrderStatusRecLst_OutputStatus.ColumnName,
		meta.WorkOrderStatusRecLst_OutputErrNum.ColumnName),
		common.WO_STATUS_LOCKED,
		common.BATORD_EVENT_LOCK,
		common.OUTPUT_TRIGGER_UNHANDLED,
		model.MesOutputRetryNum).Asc(meta.WorkOrderStatusRecLst_WorkOrderId.ColumnName).Limit(model.MesOutputNum).Find(&statusRecLi)
	if err != nil {
		return nil, err
	}
	workOrderIds := make([]string, 0, len(statusRecLi))
	statusRecMap := make(map[string]model.WorkOrderStatusRecLst, len(statusRecLi))
	for _, rec := range statusRecLi {
		workOrderIds = append(workOrderIds, rec.WorkOrderId)
		statusRecMap[rec.WorkOrderId] = rec
	}

	data := make([]model.VOmWorkorder, 0, len(workOrderIds))
	workOrderSession := impl.session.Table(meta.WorkOrder.TableName)
	statusCondition := fmt.Sprintf("%s = %s and %s = %s",
		meta.WorkOrder_PlantNr.ColumnName,
		meta.WorkOrderStatus_PlantNr.ColumnName,
		meta.WorkOrder_WorkOrderId.ColumnName,
		meta.WorkOrderStatus_WorkOrderId.ColumnName)
	qtyCondition := fmt.Sprintf("%s = %s and %s = %s",
		meta.WorkOrder_PlantNr.ColumnName,
		meta.WorkOrderQty_PlantNr.ColumnName,
		meta.WorkOrder_WorkOrderId.ColumnName,
		meta.WorkOrderQty_WorkOrderId.ColumnName)
	workOrderSession = workOrderSession.Join("LEFT", meta.WorkOrderStatus.TableName, statusCondition)
	workOrderSession = workOrderSession.Join("LEFT", meta.WorkOrderQty.TableName, qtyCondition)
	workOrderSession = workOrderSession.Where(fmt.Sprintf("%s = ?", meta.WorkOrder_PlantNr.ColumnName), impl.plantNr)
	err = workOrderSession.In(meta.WorkOrder_WorkOrderId.ColumnName, workOrderIds).Asc(meta.WorkOrder_WorkOrderId.ColumnName).Find(&data)
	if err != nil {
		return nil, err
	}
	result := make([]model.VOmWorkorderJoinRec, 0, len(data))
	for _, vomWorkOrder := range data {
		var vomWorkOrderJoinRec model.VOmWorkorderJoinRec
		vomWorkOrderJoinRec.VOmWorkorder = vomWorkOrder
		statusRec, exist := statusRecMap[vomWorkOrder.WorkOrder.WorkOrderId]
		if !exist {
			return nil, errors.New("join status rec failed, workOrderID:" +vomWorkOrder.WorkOrder.WorkOrderId)
		}
		vomWorkOrderJoinRec.StatusRec =  statusRec
		result = append(result, vomWorkOrderJoinRec)
	}
	return result, nil
}