// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pm

import (
	"LAPP_LF_MOM_BACKEND/dao/pm/implments"
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/pm"
	"github.com/go-xorm/xorm"
)

/******************************************************************************
 *
 * @Interface Name           : AssetDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : Asset的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
type AssetDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Asset
	 *
	 * @Function Parameters      : 需要插入的Asset
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	InsertOne(*model.Asset) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Asset
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	DeleteOne(int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Asset
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Asset
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	SelectOne(int) (*model.Asset, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改Asset
	 *
	 * @Function Parameters      : 需要修改的Asset
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	UpdateOne(*model.Asset) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Asset
	 *
	 * @Function Parameters      : 需要插入的Asset列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	Insert(*[]model.Asset) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Asset
	 *
	 * @Function Parameters      : 需要删除的Asset列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	Delete(*[]model.Asset) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除Asset
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Asset
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.Asset, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Asset并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Asset
	 *
	 * @Function Parameters      : 需要修改的Asset列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	Update(*[]model.Asset) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改Asset
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-13 11:00:13
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.Asset, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewAssetDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个AssetDAO实例
 *
 * @Function Parameters      : xorm会话
 *
 * @Function Parameters      : 基本主键
 *
 * @Return Value             : AssetDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func NewAssetDAO(session *xorm.Session, plantNr int, userid string) AssetDAO {
	return implments.NewAssetDAOImplement(session, plantNr, userid)
}
