// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	"LAPP_LF_MOM_BACKEND/dao/wm/implments"
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"github.com/go-xorm/xorm"
)

/******************************************************************************
 *
 * @Interface Name           : WarehouseDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : Warehouse的数据访问对象接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
type WarehouseDAO interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Warehouse
	 *
	 * @Function Parameters      : 需要插入的Warehouse
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	InsertOne(*model.Warehouse) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Warehouse
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	DeleteOne(string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Warehouse
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Warehouse
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	SelectOne(string) (*model.Warehouse, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改Warehouse
	 *
	 * @Function Parameters      : 需要修改的Warehouse
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	UpdateOne(*model.Warehouse) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Warehouse
	 *
	 * @Function Parameters      : 需要插入的Warehouse列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Insert(*[]model.Warehouse) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Warehouse
	 *
	 * @Function Parameters      : 需要删除的Warehouse列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Delete(*[]model.Warehouse) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件删除Warehouse
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	DeleteWhere([]grmi.Predicate) error
	/******************************************************************************
	 *
	 * @Function Name            : Select
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Warehouse
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Select([]grmi.Predicate, []grmi.Field) ([]model.Warehouse, error)
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件查询Warehouse并分页
	 *
	 * @Function Parameters      : 分页信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Function Parameters      : 排序字段
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	SelectAndPaging(*grmi.Paging, []grmi.Predicate, []grmi.Field) (grmi.PagingResult, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Warehouse
	 *
	 * @Function Parameters      : 需要修改的Warehouse列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Update(*[]model.Warehouse) error
	/******************************************************************************
	 *
	 * @Function Name            : UpdateWhere
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 按条件修改Warehouse
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	UpdateWhere([]grmi.Predicate, *model.Warehouse, ...string) error
}

/******************************************************************************
 *
 * @Function Name            : NewWarehouseDAO
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WarehouseDAO实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : WarehouseDAO实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func NewWarehouseDAO(session *xorm.Session, userid string) WarehouseDAO {
	return implments.NewWarehouseDAOImplement(session, userid)
}
