// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/wm"
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : ArticleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Article的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
type ArticleDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewArticleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ArticleDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : ArticleDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func NewArticleDAOImplement(session *xorm.Session, userid string) *ArticleDAOImplement {
	return &ArticleDAOImplement{session, &meta.Article, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.InsertOne
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) InsertOne(entity *model.Article) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) DeleteOne(artId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{artId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.SelectOne
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) SelectOne(artId string) (*model.Article, error) {
	var data model.ArticleWithConfig
	replenishCondition := fmt.Sprintf("%s = %s", meta.Article_ArtId.ColumnName, meta.ArticleReplenish_ArtId.ColumnName)
	pickRateCondition := fmt.Sprintf("%s = %s", meta.Article_ArtId.ColumnName, meta.ArticlePickingRate_ArtId.ColumnName)
	ok, err := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.ArticleReplenish.TableName, replenishCondition).Join("LEFT", meta.ArticlePickingRate.TableName, pickRateCondition).ID(core.PK{artId, artId, artId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	var result model.Article
	result = data.Article
	result.ArticleReplenish = data.ArticleReplenish
	result.ArticlePickingRate = data.ArticlePickingRate
	return &result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) UpdateOne(entity *model.Article) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.Insert
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) Insert(entities *[]model.Article) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.Delete
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) Delete(entities *[]model.Article) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.Select
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Article, error) {

	parameters := []interface{}{}
	where := "1 = 1 "
	replenishCondition := fmt.Sprintf("%s = %s", meta.Article_ArtId.ColumnName, meta.ArticleReplenish_ArtId.ColumnName)
	pickRateCondition := fmt.Sprintf("%s = %s", meta.Article_ArtId.ColumnName, meta.ArticlePickingRate_ArtId.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.ArticleReplenish.TableName, replenishCondition).Join("LEFT", meta.ArticlePickingRate.TableName, pickRateCondition)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.ArticleWithConfig, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	result := make([]model.Article, 0, len(data))
	for _, item := range data {
		var article model.Article
		article = item.Article
		article.ArticleReplenish = item.ArticleReplenish
		article.ArticlePickingRate = item.ArticlePickingRate
		result = append(result, article)
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "
	replenishCondition := fmt.Sprintf("%s = %s", meta.Article_ArtId.ColumnName, meta.ArticleReplenish_ArtId.ColumnName)
	pickRateCondition := fmt.Sprintf("%s = %s", meta.Article_ArtId.ColumnName, meta.ArticlePickingRate_ArtId.ColumnName)
	session := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.ArticleReplenish.TableName, replenishCondition).Join("LEFT", meta.ArticlePickingRate.TableName, pickRateCondition)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	var orderBy string
	if orderByFields != nil {
		orderBy = " order by "
		for index, field := range orderByFields {
			if index == 0 {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.ArticleWithConfig, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	result := make([]model.Article, 0, len(data))
	for _, item := range data {
		var article model.Article
		article = item.Article
		article.ArticleReplenish = item.ArticleReplenish
		article.ArticlePickingRate = item.ArticlePickingRate
		result = append(result, article)
	}
	return grmi.PagingResult{Records: result, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.Update
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) Update(entities *[]model.Article) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.Article, columns ...string) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.Article_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/ArticleDAO.SelectOneWithReplenish
 *
 ******************************************************************************/
func (impl *ArticleDAOImplement) SelectOneWithReplenish(artId string) (*model.ArticleWithReplenish, error) {
	var data model.ArticleWithReplenish
	condition := fmt.Sprintf("%s = %s", meta.Article_ArtId.ColumnName, meta.ArticleReplenish_ArtId.ColumnName)
	ok, err := impl.session.Table(impl.meta.TableName).Join("LEFT", meta.ArticleReplenish.TableName, condition).ID(core.PK{artId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

