// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/wm"
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : InventoryCheckDetailDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : InventoryCheckDetail的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
type InventoryCheckDetailDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewInventoryCheckDetailDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个InventoryCheckDetailDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : InventoryCheckDetailDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func NewInventoryCheckDetailDAOImplement(session *xorm.Session, userid string) *InventoryCheckDetailDAOImplement {
	return &InventoryCheckDetailDAOImplement{session, &meta.InventoryCheckDetail, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.InsertOne
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) InsertOne(entity *model.InventoryCheckDetail) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) DeleteOne(inventoryCheckId string, iCDPos int) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{inventoryCheckId, iCDPos}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.SelectOne
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) SelectOne(inventoryCheckId string, iCDPos int) (*model.InventoryCheckDetail, error) {
	var data model.InventoryCheckDetail
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{inventoryCheckId, iCDPos}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) UpdateOne(entity *model.InventoryCheckDetail) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.Insert
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) Insert(entities *[]model.InventoryCheckDetail) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.Delete
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) Delete(entities *[]model.InventoryCheckDetail) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.Select
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.InventoryCheckDetail, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.InventoryCheckDetail, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	var orderBy string
	if orderByFields != nil {
		orderBy = " order by "
		for index, field := range orderByFields {
			if index == 0 {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.InventoryCheckDetail, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.Update
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) Update(entities *[]model.InventoryCheckDetail) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/InventoryCheckDetailDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *InventoryCheckDetailDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.InventoryCheckDetail, columns ...string) error {

	parameters := []interface{}{}
	where := ""

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.InventoryCheckDetail_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
