// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/wm"
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WarehouseDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Warehouse的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
type WarehouseDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWarehouseDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WarehouseDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : WarehouseDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func NewWarehouseDAOImplement(session *xorm.Session, userid string) *WarehouseDAOImplement {
	return &WarehouseDAOImplement{session, &meta.Warehouse, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) InsertOne(entity *model.Warehouse) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) DeleteOne(warehouseId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{warehouseId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) SelectOne(warehouseId string) (*model.Warehouse, error) {
	var data model.Warehouse
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{warehouseId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) UpdateOne(entity *model.Warehouse) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.Insert
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) Insert(entities *[]model.Warehouse) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.Delete
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) Delete(entities *[]model.Warehouse) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.Select
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.Warehouse, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.Warehouse, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	var orderBy string
	if orderByFields != nil {
		orderBy = " order by "
		for index, field := range orderByFields {
			if index == 0 {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.Warehouse, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.Update
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) Update(entities *[]model.Warehouse) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WarehouseDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WarehouseDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.Warehouse, columns ...string) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.Warehouse_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}
