// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/wm"
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"fmt"
	"github.com/go-xorm/xorm"
	"xorm.io/core"
)

/******************************************************************************
 *
 * @Struct Name              : WorkAreaDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkArea的数据访问对象实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
type WorkAreaDAOImplement struct {
	session *xorm.Session
	meta    *grmi.Entity
	userid  string
}

/******************************************************************************
 *
 * @Function Name            : NewWorkAreaDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkAreaDAOImplement实例
 *
 * @Function Parameters      : xorm会话
 *

 * @Return Value             : WorkAreaDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func NewWorkAreaDAOImplement(session *xorm.Session, userid string) *WorkAreaDAOImplement {
	return &WorkAreaDAOImplement{session, &meta.WorkArea, userid}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.InsertOne
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) InsertOne(entity *model.WorkArea) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Insert(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) DeleteOne(workAreaId string) error {
	_, err := impl.session.Table(impl.meta.TableName).ID(core.PK{workAreaId}).Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}

	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.SelectOne
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) SelectOne(workAreaId string) (*model.WorkArea, error) {
	var data model.WorkArea
	ok, err := impl.session.Table(impl.meta.TableName).ID(core.PK{workAreaId}).Get(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	if !ok {
		return nil, nil
	}
	return &data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) UpdateOne(entity *model.WorkArea) error {

	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.Insert
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) Insert(entities *[]model.WorkArea) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
	}
	_, err := impl.session.Table(impl.meta.TableName).Insert(entities)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.Delete
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) Delete(entities *[]model.WorkArea) error {
	for _, entity := range *entities {

		_, err := impl.session.Table(impl.meta.TableName).ID(entity.GetKey()).Delete(impl.meta.Indicator)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.DeleteWhere
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) DeleteWhere(predicates []grmi.Predicate) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	_, err := session.Delete(impl.meta.Indicator)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.Select
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) Select(predicates []grmi.Predicate, orderByFields []grmi.Field) ([]model.WorkArea, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	if orderByFields != nil {
		for _, field := range orderByFields {
			session = session.OrderBy(field.ColumnName)
		}
	}

	data := make([]model.WorkArea, 0, 10)
	err := session.Find(&data)
	if err != nil {
		return nil, grmi.NewDataBaseError(err)
	}
	return data, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.SelectAndPaging
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) SelectAndPaging(paging *grmi.Paging, predicates []grmi.Predicate, orderByFields []grmi.Field) (grmi.PagingResult, error) {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	count, err := session.Count(impl.meta.Indicator)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}

	var orderBy string
	if orderByFields != nil {
		orderBy = " order by "
		for index, field := range orderByFields {
			if index == 0 {
				orderBy += field.ColumnName
			} else {
				orderBy += ", " + field.ColumnName
			}
		}
	}
	parameters = append(parameters, paging.Offset(), paging.Size)
	data := make([]model.WorkArea, 0, 10)
	where = " where " + where
	err = impl.session.Table(impl.meta.TableName).SQL("select * from "+impl.meta.TableName+where+orderBy+" offset ? row fetch next ? row only", parameters...).Find(&data)
	if err != nil {
		return grmi.EmptyPagingResult, err
	}
	return grmi.PagingResult{Records: data, Count: count, PageNumber: paging.Number, PageSize: paging.Size}, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.Update
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) Update(entities *[]model.WorkArea) error {
	for i := 0; i < len(*entities); i++ {
		entity := &(*entities)[i]

		entity.LastUser = impl.userid
		_, err := impl.session.Table(impl.meta.TableName).Cols(impl.meta.UpdatingMembers...).ID(entity.GetKey()).Update(entity)
		if err != nil {
			return grmi.NewDataBaseError(err)
		}
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.UpdateWhere
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) UpdateWhere(predicates []grmi.Predicate, entity *model.WorkArea, columns ...string) error {

	parameters := []interface{}{}
	where := "1 = 1 "

	session := impl.session.Table(impl.meta.TableName)
	if predicates != nil {
		for _, predicate := range predicates {
			where += predicate.Build()
			parameters = append(parameters, predicate.Values...)
		}
		session = session.Where(where, parameters...)
	} else {
		session = session.Where(where, parameters...)
	}

	columns = append(columns, meta.WorkArea_LastUser.ColumnName)
	entity.LastUser = impl.userid
	_, err := impl.session.Table(impl.meta.TableName).Cols(columns...).Update(entity)
	if err != nil {
		return grmi.NewDataBaseError(err)
	}
	return nil
}


/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/dao/wm/WorkAreaDAO.DeleteWorkAreaLst
 *
 ******************************************************************************/
func (impl *WorkAreaDAOImplement) DeleteWorkAreaLst(selectType string, relId1 string, relId2 string) error {
	var err error
	if selectType == model.WORK_AREA_TYPE_WARE_HOUSE {
		sql := fmt.Sprintf(`select %s from %s where %s = '%s' and %s = '%s'`, meta.WorkArea_WorkAreaId.ColumnName,meta.WorkArea.TableName, meta.WorkArea_WorkAreaType.ColumnName, selectType,meta.WorkArea_RelevanceId.ColumnName, relId1)
		where := fmt.Sprintf(`%s in (%s)`, meta.WorkAreaUserLst_WorkAreaId.ColumnName, sql)
		_, err = impl.session.Table(meta.WorkAreaUserLst.TableName).Where(where).Delete(impl.meta.Indicator)
	} else {
		sql := fmt.Sprintf(`select %s from %s where %s = '%s' and %s = '%s' and %s = '%s'`, meta.WorkArea_WorkAreaId.ColumnName,meta.WorkArea.TableName, meta.WorkArea_WorkAreaType.ColumnName, selectType,meta.WorkArea_RelevanceId.ColumnName, relId1, meta.WorkArea_WACtrlPara3.ColumnName, relId2)
		where := fmt.Sprintf(`%s in (%s)`, meta.WorkAreaUserLst_WorkAreaId.ColumnName, sql)
		_, err = impl.session.Table(meta.WorkAreaUserLst.TableName).Where(where).Delete(impl.meta.Indicator)
	}
	return err
}
