package log

import "LAPP_LF_MOM_BACKEND/grmi"

// 供应商需求明细状态值
const (
	WaitReceivingStatus int = iota // 初始状态
	ReceivedStatus                 // 已接收
	ConfirmedStatus                // 已确认
	AccomplishedStatus             // 已完成
)

// 供应商需求来源
const (
	DemandOrderStatusAccomplish = 1
	DemandChangeStatusTrue      = 1
)

// 条码校验状态
const (
	PackOrder_Fail    = "fail"
	PackOrder_Waiting = "waiting"
	PackOrder_Doing   = "doing"
	PackOrder_Success = "success"
)

/******************************************************************************
 *
 * @Description              : 修改供应商需求明细状态绑定结构体
 *
 * @Author                   : Zhang Xin
 *
 * @Date                     : 2021/3/19

 ******************************************************************************/
type ArtDemandLstStatusChange struct {
	DemandId string `json:"demandId"`
	Pos      int    `json:"pos"`
}

/******************************************************************************
 *
 * @Description              : 修改供应商需求批次状态绑定结构体
 *
 * @Author                   : Zhang Xin
 *
 * @Date                     : 2021/3/19
 *
 ******************************************************************************/
type ArtDemandHeadStatusChange struct {
	ArtId    string `json:"artId"`
	DemandId string `json:"demandId"`
}

/******************************************************************************
 *
 * @Description              : 修改供应商需求明细状态绑定结构体外层切片
 *
 * @Author                   : Zhang Xin
 *
 * @Date                     : 2021/3/19
 *
 ******************************************************************************/
type ArtDemandLstStatusChangeRecords struct {
	Records []ArtDemandLstStatusChange
}

/******************************************************************************
 *
 * @Description              : 修改供应商需求批次状态绑定结构体外层切片
 *
 * @Author                   : Zhang Xin
 *
 * @Date                     : 2021/4/29
 *
 ******************************************************************************/
type ArtDemandHeadStatusChangeRecords struct {
	Records []ArtDemandHeadStatusChange
}

/******************************************************************************
 *
 * @Description              : 通过ArtDemandHead查询ArtDemandLst结构体
 *
 * @Author                   : Zhang Xin
 *
 * @Date                     : 2021/3/23
 *
 ******************************************************************************/
type ArtDemandItem struct {
	ArtId    string
	DemandId string
}

/******************************************************************************
 *
 * @Description              : 批量添加VendorArtLst绑定前端结构体
 *
 * @Author                   : Zhang Xin
 *
 * @Date                     : 2021/3/25
 *
 ******************************************************************************/
type VendorArtLstInsert struct {
	VendorId string         `json:"vendorId"`
	Records  []VendorArtLst `json:"records"`
}

/******************************************************************************
 *
 * @Description              : 批量添加VendorUserLst绑定前端结构体
 *
 * @Author                   : Zhang Xin
 *
 * @Date                     : 2021/3/25
 *
 ******************************************************************************/
type VendorUserLstInsert struct {
	VendorId string          `json:"vendorId"`
	Records  []VendorUserLst `json:"records"`
}

/******************************************************************************
 *
 * @Struct Name              : SyncArtDemandHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArtDemandHead的实体映射
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-10 18:11:08
 *
 ******************************************************************************/
type SyncArtDemandHead struct {
	PlantNr            int           `xorm:"pk int 'PlantNr'" json:"LOG_ArtDemandHead-PlantNr"`
	ArtId              string        `xorm:"pk nvarchar(40) 'ArtId'" json:"LOG_ArtDemandHead-ArtId"`
	DemandId           string        `xorm:"pk nvarchar(40) 'DemandId'" json:"LOG_ArtDemandHead-DemandId"`
	DemandType         string        `xorm:"nvarchar(40) 'DemandType' not null" json:"LOG_ArtDemandHead-DemandType"`
	DemandYear         int           `xorm:"int 'DemandYear' not null" json:"LOG_ArtDemandHead-DemandYear"`
	DemandMonth        int           `xorm:"int 'DemandMonth' not null" json:"LOG_ArtDemandHead-DemandMonth"`
	DemandWeek         int           `xorm:"int 'DemandWeek' not null" json:"LOG_ArtDemandHead-DemandWeek"`
	DemandDate         grmi.Date     `xorm:"date 'DemandDate' not null" json:"LOG_ArtDemandHead-DemandDate"`
	DemandHour         int           `xorm:"int 'DemandHour' not null" json:"LOG_ArtDemandHead-DemandHour"`
	DemandTime         grmi.DateTime `xorm:"datetime 'DemandTime'" json:"LOG_ArtDemandHead-DemandTime"`
	DemandQty          float64       `xorm:"float 'DemandQty' not null" json:"LOG_ArtDemandHead-DemandQty"`
	QtyUomId           string        `xorm:"nvarchar(40) 'QtyUomId' not null" json:"LOG_ArtDemandHead-QtyUomId"`
	Status             int           `xorm:"int 'Status' not null" json:"LOG_ArtDemandHead-Status"`
	DemandSendTime     grmi.DateTime `xorm:"datetime 'DemandSendTime'" json:"LOG_ArtDemandHead-DemandSendTime"`
	DemandRecieveTime  grmi.DateTime `xorm:"datetime 'DemandRecieveTime'" json:"LOG_ArtDemandHead-DemandRecieveTime"`
	DemandConfirmTime  grmi.DateTime `xorm:"datetime 'DemandConfirmTime'" json:"LOG_ArtDemandHead-DemandConfirmTime"`
	DemandCloseTime    grmi.DateTime `xorm:"datetime 'DemandCloseTime'" json:"LOG_ArtDemandHead-DemandCloseTime"`
	DemandDeliveredQty float64       `xorm:"float 'DemandDeliveredQty' not null" json:"LOG_ArtDemandHead-DemandDeliveredQty"`
	DemandCtrlPara1    int           `xorm:"int 'DemandCtrlPara1' not null" json:"LOG_ArtDemandHead-DemandCtrlPara1"`
	DemandCtrlPara2    int           `xorm:"int 'DemandCtrlPara2' not null" json:"LOG_ArtDemandHead-DemandCtrlPara2"`
	DemandCtrlPara3    string        `xorm:"nvarchar(100) 'DemandCtrlPara3' not null" json:"LOG_ArtDemandHead-DemandCtrlPara3"`
	DemandCtrlPara4    string        `xorm:"nvarchar(100) 'DemandCtrlPara4' not null" json:"LOG_ArtDemandHead-DemandCtrlPara4"`
	DemandCtrlTime1    grmi.DateTime `xorm:"datetime 'DemandCtrlTime1'" json:"LOG_ArtDemandHead-DemandCtrlTime1"`
	DemandCtrlTime2    grmi.DateTime `xorm:"datetime 'DemandCtrlTime2'" json:"LOG_ArtDemandHead-DemandCtrlTime2"`
	OrderStatus        int           `xorm:"int 'OrderStatus' not null" json:"LOG_ArtDemandHead-OrderStatus"`
	UnproducedQty      float64       `xorm:"float 'UnproducedQty' not null" json:"LOG_ArtDemandHead-UnproducedQty"`
	OrderType          string        `xorm:"nvarchar(20) 'OrderType' not null" json:"LOG_ArtDemandHead-OrderType"`
	WorkOrderId        string        `xorm:"nvarchar(40) 'WorkOrderId' not null" json:"LOG_ArtDemandHead-WorkOrderId"`
	ProjectId          string        `xorm:"nvarchar(40) 'ProjectId' not null" json:"LOG_ArtDemandHead-ProjectId"`
	DemandStatus       int           `xorm:"int 'DemandStatus' not null" json:"LOG_ArtDemandHead-DemandStatus"`
	DemandCtrlPara5    int           `xorm:"int 'DemandCtrlPara5'" json:"LOG_ArtDemandHead-DemandCtrlPara5"`
	DemandCtrlPara6    int           `xorm:"int 'DemandCtrlPara6'" json:"LOG_ArtDemandHead-DemandCtrlPara6"`
	ChangeStatus       int           `xorm:"int 'ChangeStatus' not null" json:"LOG_ArtDemandHead-ChangeStatus"`
	PlanResourceId     string        `xorm:"nvarchar(40) 'PlanResourceId'" json:"LOG_ArtDemandHead-PlanResourceId"`
	PlanStartDate      grmi.Date     `xorm:"date 'PlanStartDate'" json:"LOG_ArtDemandHead-PlanStartDate"`
	PlanEndDate        grmi.Date     `xorm:"date 'PlanEndDate'" json:"LOG_ArtDemandHead-PlanEndDate"`
	PlanStartTime      grmi.DateTime `xorm:"datetime 'PlanStartTime'" json:"LOG_ArtDemandHead-PlanStartTime"`
	PlanEndTime        grmi.DateTime `xorm:"datetime 'PlanEndTime'" json:"LOG_ArtDemandHead-PlanEndTime"`
	ActStartTime       grmi.DateTime `xorm:"datetime 'ActStartTime'" json:"LOG_ArtDemandHead-ActStartTime"`
	ActEndTime         grmi.DateTime `xorm:"datetime 'ActEndTime'" json:"LOG_ArtDemandHead-ActEndTime"`
	CancelQty          float64       `xorm:"float 'CancelQty' not null" json:"LOG_ArtDemandHead-CancelQty"`
	LastModify         grmi.DateTime `xorm:"datetime 'LastModify' not null" json:"LOG_ArtDemandHead-LastModify"`
	LastUser           string        `xorm:"nvarchar(20) 'LastUser' not null" json:"LOG_ArtDemandHead-LastUser"`
	CreateTime         grmi.DateTime `xorm:"datetime 'CreateTime' not null" json:"LOG_ArtDemandHead-CreateTime"`
}

/******************************************************************************
 *
 * @Struct Name              : SyncArtDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : ArtDemandLst的实体映射
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-10 18:11:08
 *
 ******************************************************************************/
type SyncArtDemandLst struct {
	PlantNr            int           `xorm:"pk int 'PlantNr'" json:"LOG_ArtDemandLst-PlantNr"`
	DemandId           string        `xorm:"pk nvarchar(40) 'DemandId'" json:"LOG_ArtDemandLst-DemandId"`
	Pos                int           `xorm:"pk int 'Pos'" json:"LOG_ArtDemandLst-Pos"`
	ArtId              string        `xorm:"nvarchar(40) 'ArtId' not null" json:"LOG_ArtDemandLst-ArtId"`
	DemandTime         grmi.DateTime `xorm:"datetime2(0) 'DemandTime' not null" json:"LOG_ArtDemandLst-DemandTime"`
	DemandYear         int           `xorm:"int 'DemandYear' not null" json:"LOG_ArtDemandLst-DemandYear"`
	DemandMonth        int           `xorm:"int 'DemandMonth' not null" json:"LOG_ArtDemandLst-DemandMonth"`
	DemandWeek         int           `xorm:"int 'DemandWeek' not null" json:"LOG_ArtDemandLst-DemandWeek"`
	DemandDate         grmi.Date     `xorm:"date 'DemandDate' not null" json:"LOG_ArtDemandLst-DemandDate"`
	DemandHour         int           `xorm:"int 'DemandHour' not null" json:"LOG_ArtDemandLst-DemandHour"`
	DemandQty          float64       `xorm:"float 'DemandQty' not null" json:"LOG_ArtDemandLst-DemandQty"`
	QtyUomId           string        `xorm:"nvarchar(40) 'QtyUomId' not null" json:"LOG_ArtDemandLst-QtyUomId"`
	DemandObjId        string        `xorm:"nvarchar(40) 'DemandObjId' not null" json:"LOG_ArtDemandLst-DemandObjId"`
	DemandType         string        `xorm:"nvarchar(40) 'DemandType' not null" json:"LOG_ArtDemandLst-DemandType"`
	Status             int           `xorm:"int 'Status' not null" json:"LOG_ArtDemandLst-Status"`
	DemandSendTime     grmi.DateTime `xorm:"datetime 'DemandSendTime'" json:"LOG_ArtDemandLst-DemandSendTime"`
	DemandRecieveTime  grmi.DateTime `xorm:"datetime 'DemandRecieveTime'" json:"LOG_ArtDemandLst-DemandRecieveTime"`
	DemandConfirmTime  grmi.DateTime `xorm:"datetime 'DemandConfirmTime'" json:"LOG_ArtDemandLst-DemandConfirmTime"`
	DemandCloseTime    grmi.DateTime `xorm:"datetime 'DemandCloseTime'" json:"LOG_ArtDemandLst-DemandCloseTime"`
	DemandDeliveredQty float64       `xorm:"float 'DemandDeliveredQty' not null" json:"LOG_ArtDemandLst-DemandDeliveredQty"`
	DemandCtrlPara1    int           `xorm:"int 'DemandCtrlPara1' not null" json:"LOG_ArtDemandLst-DemandCtrlPara1"`
	DemandCtrlPara2    int           `xorm:"int 'DemandCtrlPara2' not null" json:"LOG_ArtDemandLst-DemandCtrlPara2"`
	DemandCtrlPara3    string        `xorm:"nvarchar(100) 'DemandCtrlPara3' not null" json:"LOG_ArtDemandLst-DemandCtrlPara3"`
	DemandCtrlPara4    string        `xorm:"nvarchar(100) 'DemandCtrlPara4' not null" json:"LOG_ArtDemandLst-DemandCtrlPara4"`
	DemandCtrlTime1    grmi.DateTime `xorm:"datetime 'DemandCtrlTime1'" json:"LOG_ArtDemandLst-DemandCtrlTime1"`
	DemandCtrlTime2    grmi.DateTime `xorm:"datetime 'DemandCtrlTime2'" json:"LOG_ArtDemandLst-DemandCtrlTime2"`
	OrderStatus        int           `xorm:"int 'OrderStatus' not null" json:"LOG_ArtDemandLst-OrderStatus"`
	UnproducedQty      float64       `xorm:"float 'UnproducedQty' not null" json:"LOG_ArtDemandLst-UnproducedQty"`
	OrderType          string        `xorm:"nvarchar(20) 'OrderType' not null" json:"LOG_ArtDemandLst-OrderType"`
	ProjectId          string        `xorm:"nvarchar(40) 'ProjectId' not null" json:"LOG_ArtDemandLst-ProjectId"`
	DemandStatus       int           `xorm:"int 'DemandStatus' not null" json:"LOG_ArtDemandLst-DemandStatus"`
	PlanResourceId     string        `xorm:"nvarchar(40) 'PlanResourceId'" json:"LOG_ArtDemandLst-PlanResourceId"`
	PlanStartDate      grmi.Date     `xorm:"date 'PlanStartDate'" json:"LOG_ArtDemandLst-PlanStartDate"`
	PlanEndDate        grmi.Date     `xorm:"date 'PlanEndDate'" json:"LOG_ArtDemandLst-PlanEndDate"`
	PlanStartTime      grmi.DateTime `xorm:"datetime 'PlanStartTime'" json:"LOG_ArtDemandLst-PlanStartTime"`
	PlanEndTime        grmi.DateTime `xorm:"datetime 'PlanEndTime'" json:"LOG_ArtDemandLst-PlanEndTime"`
	ActStartTime       grmi.DateTime `xorm:"datetime 'ActStartTime'" json:"LOG_ArtDemandLst-ActStartTime"`
	ActEndTime         grmi.DateTime `xorm:"datetime 'ActEndTime'" json:"LOG_ArtDemandLst-ActEndTime"`
	LastModify         grmi.DateTime `xorm:"datetime 'LastModify' not null" json:"LOG_ArtDemandLst-LastModify"`
	LastUser           string        `xorm:"nvarchar(20) 'LastUser' not null" json:"LOG_ArtDemandLst-LastUser"`
	CreateTime         grmi.DateTime `xorm:"datetime 'CreateTime' not null" json:"LOG_ArtDemandLst-CreateTime"`
}


/******************************************************************************
 *
 * @Struct Name              : SyncArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : SyncArtDemandHeadCache的实体映射
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-15 15:28:12
 *
 ******************************************************************************/
type SyncArtDemandHeadCache struct {
	PlantNr            int           `xorm:"pk int 'PlantNr'" json:"LOG_ArtDemandHeadCache-PlantNr"`
	ArtId              string        `xorm:"pk nvarchar(40) 'ArtId'" json:"LOG_ArtDemandHeadCache-ArtId"`
	DemandId           string        `xorm:"pk nvarchar(40) 'DemandId'" json:"LOG_ArtDemandHeadCache-DemandId"`
	DemandType         string        `xorm:"nvarchar(40) 'DemandType' not null" json:"LOG_ArtDemandHeadCache-DemandType"`
	DemandYear         int           `xorm:"int 'DemandYear' not null" json:"LOG_ArtDemandHeadCache-DemandYear"`
	DemandMonth        int           `xorm:"int 'DemandMonth' not null" json:"LOG_ArtDemandHeadCache-DemandMonth"`
	DemandWeek         int           `xorm:"int 'DemandWeek' not null" json:"LOG_ArtDemandHeadCache-DemandWeek"`
	DemandDate         grmi.Date     `xorm:"date 'DemandDate' not null" json:"LOG_ArtDemandHeadCache-DemandDate"`
	DemandHour         int           `xorm:"int 'DemandHour' not null" json:"LOG_ArtDemandHeadCache-DemandHour"`
	DemandTime         grmi.DateTime `xorm:"datetime 'DemandTime'" json:"LOG_ArtDemandHeadCache-DemandTime"`
	DemandQty          float64       `xorm:"float 'DemandQty' not null" json:"LOG_ArtDemandHeadCache-DemandQty"`
	QtyUomId           string        `xorm:"nvarchar(40) 'QtyUomId' not null" json:"LOG_ArtDemandHeadCache-QtyUomId"`
	Status             int           `xorm:"int 'Status' not null" json:"LOG_ArtDemandHeadCache-Status"`
	DemandSendTime     grmi.DateTime `xorm:"datetime 'DemandSendTime'" json:"LOG_ArtDemandHeadCache-DemandSendTime"`
	DemandRecieveTime  grmi.DateTime `xorm:"datetime 'DemandRecieveTime'" json:"LOG_ArtDemandHeadCache-DemandRecieveTime"`
	DemandConfirmTime  grmi.DateTime `xorm:"datetime 'DemandConfirmTime'" json:"LOG_ArtDemandHeadCache-DemandConfirmTime"`
	DemandCloseTime    grmi.DateTime `xorm:"datetime 'DemandCloseTime'" json:"LOG_ArtDemandHeadCache-DemandCloseTime"`
	DemandDeliveredQty float64       `xorm:"float 'DemandDeliveredQty' not null" json:"LOG_ArtDemandHeadCache-DemandDeliveredQty"`
	DemandCtrlPara1    int           `xorm:"int 'DemandCtrlPara1' not null" json:"LOG_ArtDemandHeadCache-DemandCtrlPara1"`
	DemandCtrlPara2    int           `xorm:"int 'DemandCtrlPara2' not null" json:"LOG_ArtDemandHeadCache-DemandCtrlPara2"`
	DemandCtrlPara3    string        `xorm:"nvarchar(100) 'DemandCtrlPara3' not null" json:"LOG_ArtDemandHeadCache-DemandCtrlPara3"`
	DemandCtrlPara4    string        `xorm:"nvarchar(100) 'DemandCtrlPara4' not null" json:"LOG_ArtDemandHeadCache-DemandCtrlPara4"`
	DemandCtrlTime1    grmi.DateTime `xorm:"datetime 'DemandCtrlTime1'" json:"LOG_ArtDemandHeadCache-DemandCtrlTime1"`
	DemandCtrlTime2    grmi.DateTime `xorm:"datetime 'DemandCtrlTime2'" json:"LOG_ArtDemandHeadCache-DemandCtrlTime2"`
	OrderStatus        int           `xorm:"int 'OrderStatus' not null" json:"LOG_ArtDemandHeadCache-OrderStatus"`
	UnproducedQty      float64       `xorm:"float 'UnproducedQty' not null" json:"LOG_ArtDemandHeadCache-UnproducedQty"`
	OrderType          string        `xorm:"nvarchar(20) 'OrderType' not null" json:"LOG_ArtDemandHeadCache-OrderType"`
	WorkOrderId        string        `xorm:"nvarchar(40) 'WorkOrderId'" json:"LOG_ArtDemandHeadCache-WorkOrderId"`
	ProjectId          string        `xorm:"nvarchar(40) 'ProjectId' not null" json:"LOG_ArtDemandHeadCache-ProjectId"`
	DemandStatus       int           `xorm:"int 'DemandStatus' not null" json:"LOG_ArtDemandHeadCache-DemandStatus"`
	DemandCtrlPara5    int           `xorm:"int 'DemandCtrlPara5'" json:"LOG_ArtDemandHeadCache-DemandCtrlPara5"`
	DemandCtrlPara6    int           `xorm:"int 'DemandCtrlPara6'" json:"LOG_ArtDemandHeadCache-DemandCtrlPara6"`
	ChangeStatus       int           `xorm:"int 'ChangeStatus' not null" json:"LOG_ArtDemandHeadCache-ChangeStatus"`
	PlanResourceId     string        `xorm:"nvarchar(40) 'PlanResourceId'" json:"LOG_ArtDemandHeadCache-PlanResourceId"`
	PlanStartDate      grmi.Date     `xorm:"date 'PlanStartDate'" json:"LOG_ArtDemandHeadCache-PlanStartDate"`
	PlanEndDate        grmi.Date     `xorm:"date 'PlanEndDate'" json:"LOG_ArtDemandHeadCache-PlanEndDate"`
	PlanStartTime      grmi.DateTime `xorm:"datetime 'PlanStartTime'" json:"LOG_ArtDemandHeadCache-PlanStartTime"`
	PlanEndTime        grmi.DateTime `xorm:"datetime 'PlanEndTime'" json:"LOG_ArtDemandHeadCache-PlanEndTime"`
	ActStartTime       grmi.DateTime `xorm:"datetime 'ActStartTime'" json:"LOG_ArtDemandHeadCache-ActStartTime"`
	ActEndTime         grmi.DateTime `xorm:"datetime 'ActEndTime'" json:"LOG_ArtDemandHeadCache-ActEndTime"`
	CancelQty          float64       `xorm:"float 'CancelQty' not null" json:"LOG_ArtDemandHeadCache-CancelQty"`
	LastModify         grmi.DateTime `xorm:"datetime 'LastModify' not null" json:"LOG_ArtDemandHeadCache-LastModify"`
	LastUser           string        `xorm:"nvarchar(20) 'LastUser' not null" json:"LOG_ArtDemandHeadCache-LastUser"`
	CreateTime         grmi.DateTime `xorm:"datetime 'CreateTime' not null" json:"LOG_ArtDemandHeadCache-CreateTime"`
}

/******************************************************************************
 *
 * @Struct Name              : SyncArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : SyncArtDemandLstCache的实体映射
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-11 16:10:25
 *
 ******************************************************************************/
type SyncArtDemandLstCache struct {
	PlantNr            int           `xorm:"pk int 'PlantNr'" json:"LOG_ArtDemandLstCache-PlantNr"`
	DemandId           string        `xorm:"pk nvarchar(40) 'DemandId'" json:"LOG_ArtDemandLstCache-DemandId"`
	Pos                int           `xorm:"pk int 'Pos'" json:"LOG_ArtDemandLstCache-Pos"`
	ArtId              string        `xorm:"nvarchar(40) 'ArtId' not null" json:"LOG_ArtDemandLstCache-ArtId"`
	DemandTime         grmi.DateTime `xorm:"datetime2(7) 'DemandTime' not null" json:"LOG_ArtDemandLstCache-DemandTime"`
	DemandYear         int           `xorm:"int 'DemandYear' not null" json:"LOG_ArtDemandLstCache-DemandYear"`
	DemandMonth        int           `xorm:"int 'DemandMonth' not null" json:"LOG_ArtDemandLstCache-DemandMonth"`
	DemandWeek         int           `xorm:"int 'DemandWeek' not null" json:"LOG_ArtDemandLstCache-DemandWeek"`
	DemandDate         grmi.Date     `xorm:"date 'DemandDate' not null" json:"LOG_ArtDemandLstCache-DemandDate"`
	DemandHour         int           `xorm:"int 'DemandHour' not null" json:"LOG_ArtDemandLstCache-DemandHour"`
	DemandQty          float64       `xorm:"float 'DemandQty' not null" json:"LOG_ArtDemandLstCache-DemandQty"`
	QtyUomId           string        `xorm:"nvarchar(40) 'QtyUomId' not null" json:"LOG_ArtDemandLstCache-QtyUomId"`
	DemandObjId        string        `xorm:"nvarchar(40) 'DemandObjId' not null" json:"LOG_ArtDemandLstCache-DemandObjId"`
	DemandType         string        `xorm:"nvarchar(40) 'DemandType' not null" json:"LOG_ArtDemandLstCache-DemandType"`
	Status             int           `xorm:"int 'Status' not null" json:"LOG_ArtDemandLstCache-Status"`
	DemandSendTime     grmi.DateTime `xorm:"datetime 'DemandSendTime'" json:"LOG_ArtDemandLstCache-DemandSendTime"`
	DemandRecieveTime  grmi.DateTime `xorm:"datetime 'DemandRecieveTime'" json:"LOG_ArtDemandLstCache-DemandRecieveTime"`
	DemandConfirmTime  grmi.DateTime `xorm:"datetime 'DemandConfirmTime'" json:"LOG_ArtDemandLstCache-DemandConfirmTime"`
	DemandCloseTime    grmi.DateTime `xorm:"datetime 'DemandCloseTime'" json:"LOG_ArtDemandLstCache-DemandCloseTime"`
	DemandDeliveredQty float64       `xorm:"float 'DemandDeliveredQty' not null" json:"LOG_ArtDemandLstCache-DemandDeliveredQty"`
	DemandCtrlPara1    int           `xorm:"int 'DemandCtrlPara1' not null" json:"LOG_ArtDemandLstCache-DemandCtrlPara1"`
	DemandCtrlPara2    int           `xorm:"int 'DemandCtrlPara2' not null" json:"LOG_ArtDemandLstCache-DemandCtrlPara2"`
	DemandCtrlPara3    string        `xorm:"nvarchar(100) 'DemandCtrlPara3' not null" json:"LOG_ArtDemandLstCache-DemandCtrlPara3"`
	DemandCtrlPara4    string        `xorm:"nvarchar(100) 'DemandCtrlPara4' not null" json:"LOG_ArtDemandLstCache-DemandCtrlPara4"`
	DemandCtrlTime1    grmi.DateTime `xorm:"datetime 'DemandCtrlTime1'" json:"LOG_ArtDemandLstCache-DemandCtrlTime1"`
	DemandCtrlTime2    grmi.DateTime `xorm:"datetime 'DemandCtrlTime2'" json:"LOG_ArtDemandLstCache-DemandCtrlTime2"`
	OrderStatus        int           `xorm:"int 'OrderStatus' not null" json:"LOG_ArtDemandLstCache-OrderStatus"`
	UnproducedQty      float64       `xorm:"float 'UnproducedQty' not null" json:"LOG_ArtDemandLstCache-UnproducedQty"`
	OrderType          string        `xorm:"nvarchar(20) 'OrderType' not null" json:"LOG_ArtDemandLstCache-OrderType"`
	ProjectId          string        `xorm:"nvarchar(40) 'ProjectId' not null" json:"LOG_ArtDemandLstCache-ProjectId"`
	DemandStatus       int           `xorm:"int 'DemandStatus' not null" json:"LOG_ArtDemandLstCache-DemandStatus"`
	PlanResourceId     string        `xorm:"nvarchar(40) 'PlanResourceId'" json:"LOG_ArtDemandLstCache-PlanResourceId"`
	PlanStartDate      grmi.Date     `xorm:"date 'PlanStartDate'" json:"LOG_ArtDemandLstCache-PlanStartDate"`
	PlanEndDate        grmi.Date     `xorm:"date 'PlanEndDate'" json:"LOG_ArtDemandLstCache-PlanEndDate"`
	PlanStartTime      grmi.DateTime `xorm:"datetime 'PlanStartTime'" json:"LOG_ArtDemandLstCache-PlanStartTime"`
	PlanEndTime        grmi.DateTime `xorm:"datetime 'PlanEndTime'" json:"LOG_ArtDemandLstCache-PlanEndTime"`
	ActStartTime       grmi.DateTime `xorm:"datetime 'ActStartTime'" json:"LOG_ArtDemandLstCache-ActStartTime"`
	ActEndTime         grmi.DateTime `xorm:"datetime 'ActEndTime'" json:"LOG_ArtDemandLstCache-ActEndTime"`
	LastModify         grmi.DateTime `xorm:"datetime 'LastModify' not null" json:"LOG_ArtDemandLstCache-LastModify"`
	LastUser           string        `xorm:"nvarchar(20) 'LastUser' not null" json:"LOG_ArtDemandLstCache-LastUser"`
	CreateTime         grmi.DateTime `xorm:"datetime 'CreateTime' not null" json:"LOG_ArtDemandLstCache-CreateTime"`
}

/******************************************************************************
 *
 * @Struct Name              : CreatePackOrderInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 根据条码，校验创建包装
 *
 * @Author                   : 娄文智
 *
 * @Date                     : 2021-06-02 18:11:08
 *
 ******************************************************************************/
type CreatePackOrderInfo struct {
	InfoType string         `json:"InfoType"`
	Message  string         `json:"Message"`
	Items    []PackTemplate `json:"Items"`
}
