package api

import (
	model "LAPP_LF_MOM_BACKEND/models/api"
	"LAPP_LF_MOM_BACKEND/services/api/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)


/******************************************************************************
 *
 * @Interface Name           : ScrewService
 *-----------------------------------------------------------------------------
 *
 * @Description              : Screw的服务接口
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-05-14
 *
 ******************************************************************************/
type ScrewService interface {
	/******************************************************************************
	 *
	 * @Function Name            : Receive
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 接收一条screw数据
	 *
	 * @Function Parameters      : screw指针
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-05-14
	 *
	 ******************************************************************************/
	Receive(defect *model.Screw) error
	/******************************************************************************
	 *
	 * @Function Name            : NewestScrew
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 获取最新的screw
	 *
	 * @Return Value             : 最新的screw
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-05-14
	 *
	 ******************************************************************************/
	GetNewestScrew(usertab *models.Usertab, stn string) (model.ScrewWithData, error)
	/******************************************************************************
	 *
	 * @Function Name            : GetScrewLi
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 获取screw list
	 *
	 * @Return Value             : screw list
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-05-14
	 *
	 ******************************************************************************/
	GetScrewLi(usertab *models.Usertab, stn string) ([]model.ScrewWithData, error)
}
/******************************************************************************
 *
 * @Function Name            : NewScrewService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个NewScrewService
 *
 * @Return Value             : NewScrewService实例
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-05-14
 *
 ******************************************************************************/
func NewScrewService() ScrewService {
	return implments.NewScrewServiceImplement()
}

