// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/services/base/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Interface Name           : ProcessService
 *-----------------------------------------------------------------------------
 *
 * @Description              : Process的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 13:55:54
 *
 ******************************************************************************/
type ProcessService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Process
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Process
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.Process) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Process
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, int, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Process
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Process
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, int, string) (*model.Process, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条Process
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Process
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.Process) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Process
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Process列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.Process) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Process
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的Process列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.Process) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询Process
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Process
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Process列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-07-27 13:55:54
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.Process) error
}

/******************************************************************************
 *
 * @Function Name            : NewProcessService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ProcessService
 *
 * @Return Value             : ProcessService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 13:55:54
 *
 ******************************************************************************/
func NewProcessService() ProcessService {
	return implments.NewProcessServiceImplement()
}
