// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/services/base/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
*
* @Interface Name           : UomService
*-----------------------------------------------------------------------------
*
* @Description              : Uom的服务接口
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-18 23:20:31
*
******************************************************************************/
type UomService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条Uom
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Uom
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.Uom) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的Uom
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的Uom
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的Uom
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, string) (*model.Uom, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条Uom
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Uom
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.Uom) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条Uom
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的Uom列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.Uom) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条Uom
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的Uom列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.Uom) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询Uom
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条Uom
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的Uom列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.Uom) error
}

/******************************************************************************
 *
 * @Function Name            : NewUomService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个UomService
 *
 * @Return Value             : UomService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 23:20:31
 *
 ******************************************************************************/
func NewUomService() UomService {
	return implments.NewUomServiceImplement()
}
