// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/services/base/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
*
* @Interface Name           : WorkCalendarService
*-----------------------------------------------------------------------------
*
* @Description              : WorkCalendar的服务接口
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-18 23:20:31
*
******************************************************************************/
type WorkCalendarService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条WorkCalendar
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WorkCalendar
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.WorkCalendar) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的WorkCalendar
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkCalendar
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkCalendar
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, int) (*model.WorkCalendar, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条WorkCalendar
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WorkCalendar
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.WorkCalendar) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条WorkCalendar
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WorkCalendar列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.WorkCalendar) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条WorkCalendar
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的WorkCalendar列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.WorkCalendar) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询WorkCalendar
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条WorkCalendar
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WorkCalendar列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.WorkCalendar) error
}

/******************************************************************************
 *
 * @Function Name            : NewWorkCalendarService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkCalendarService
 *
 * @Return Value             : WorkCalendarService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 23:20:31
 *
 ******************************************************************************/
func NewWorkCalendarService() WorkCalendarService {
	return implments.NewWorkCalendarServiceImplement()
}
