// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/services/base/implments"
	"LAPP_LF_MOM_BACKEND/services/schedule"
	"LAPP_LF_MOM_BACKEND/web/models"
	"time"
)

/******************************************************************************
 *
 * @Interface Name           : WorkLineService
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkLine的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-07 16:20:28
 *
 ******************************************************************************/
type WorkLineService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条WorkLine
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WorkLine
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.WorkLine) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的WorkLine
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkLine
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkLine
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, string) (*model.WorkLine, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条WorkLine
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WorkLine
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.WorkLine) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条WorkLine
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WorkLine列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.WorkLine) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条WorkLine
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的WorkLine列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.WorkLine) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询WorkLine
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条WorkLine
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WorkLine列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.WorkLine) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectJoinWorkPlace
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 联查WorkLine和工位的关系
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	SelectJoinWorkPlace(*models.Usertab) ([]model.WorkLine,error)
	/******************************************************************************
	 *
	 * @Function Name            : WorkLineTree
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查出所有的Workline
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 娄文智
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	WorkLineTree(user *models.Usertab) (model.WorkLineArr, error)
	/******************************************************************************
	 *
	 * @Function Name            : WorkLineScheduler
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 生产调度排程（一键排程）
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 娄文智
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	WorkLineScheduler(user *models.Usertab,worklinetype string,startDate time.Time,endDate time.Time) (schedule.SchedulerSrv, error)
	/******************************************************************************
	 *
	 * @Function Name            : WorkLineRepairSchedule
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 生产调度排程（人工调度）
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 娄文智
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	WorkLineRepairSchedule(user *models.Usertab,data schedule.SchedulerSrv) (schedule.SchedulerSrv, error)
	/******************************************************************************
	 *
	 * @Function Name            : WorkLineSchedulerManPower
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 生产调度排程（人工调度）
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 娄文智
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	WorkLineSchedulerManPower(user *models.Usertab,worklinetype string,startDate time.Time,endDate time.Time) (schedule.SchedulerSrv, error)
	/******************************************************************************
	 *
	 * @Function Name            : WorkLineSchedulerManualr
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 生产调度排程（人工调度）
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 娄文智
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	WorkLineSchedulerManualr(user *models.Usertab,data schedule.SchedulerSrv) (schedule.SchedulerSrv, error)
	/******************************************************************************
	 *
	 * @Function Name            : SaveWorkLineScheduler
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 保存排程结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 娄文智
	 *
	 * @Date                     : 2021-03-24 09:53:49
	 *
	 ******************************************************************************/
	SaveWorkLineScheduler(user *models.Usertab,data schedule.SchedulerData) (error)
}

/******************************************************************************
 *
 * @Function Name            : NewWorkLineService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkLineService
 *
 * @Return Value             : WorkLineService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 23:20:31
 *
 ******************************************************************************/
func NewWorkLineService() WorkLineService {
	return implments.NewWorkLineServiceImplement()
}
