// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_LF_MOM_BACKEND/dao/base"
	"LAPP_LF_MOM_BACKEND/db"
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Description              : CostCenter的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfCostCenter = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.CostCenter_CostCenterId.UrlParameterName: grmi.NewConditionItem(meta.CostCenter_CostCenterId, grmi.Equal, true),
		meta.CostCenter_Descr.UrlParameterName:        grmi.NewConditionItem(meta.CostCenter_Descr, grmi.Equal, false),
		meta.CostCenter_HourRate.UrlParameterName:     grmi.NewConditionItem(meta.CostCenter_HourRate, grmi.Equal, false),
		meta.CostCenter_CCCVal1.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCCVal1, grmi.Equal, false),
		meta.CostCenter_CCCVal2.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCCVal2, grmi.Equal, false),
		meta.CostCenter_CCIVal1.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCIVal1, grmi.Equal, false),
		meta.CostCenter_CCIVal2.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCIVal2, grmi.Equal, false),
		meta.CostCenter_CCFVal1.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCFVal1, grmi.Equal, false),
		meta.CostCenter_CCFVal2.UrlParameterName:      grmi.NewConditionItem(meta.CostCenter_CCFVal2, grmi.Equal, false),
		meta.CostCenter_LastModify.UrlParameterName:   grmi.NewConditionItem(meta.CostCenter_LastModify, grmi.Approximate, false),
		meta.CostCenter_LastUser.UrlParameterName:     grmi.NewConditionItem(meta.CostCenter_LastUser, grmi.Equal, false),
		meta.CostCenter_CreateTime.UrlParameterName:   grmi.NewConditionItem(meta.CostCenter_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : CostCenter的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfCostCenterAndPaging = grmi.NewCondition(
	DefaultConditionOfCostCenter.Items,
	grmi.NewPaging(),
)

/******************************************************************************
*
* @Struct Name              : CostCenterServiceImplement
*-----------------------------------------------------------------------------
*
* @Description              : CostCenter的服务实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-23 10:43:27
*
******************************************************************************/
type CostCenterServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewCostCenterDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个CostCenterDAOImplement实例
 *
 * @Return Value             : CostCenterDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
func NewCostCenterServiceImplement() *CostCenterServiceImplement {
	return &CostCenterServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.InsertOne
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) InsertOne(user *models.Usertab, entity *model.CostCenter) error {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "InsertOneCostCenter", "插入一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.CostCenterId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.DeleteOne
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) DeleteOne(user *models.Usertab, costCenterId string) error {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "DeleteOneCostCenter", "删除一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(costCenterId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(costCenterId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.SelectOne
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) SelectOne(user *models.Usertab, costCenterId string) (*model.CostCenter, error) {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "SelectOneCostCenter", "查询一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(costCenterId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.UpdateOne
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) UpdateOne(user *models.Usertab, entity *model.CostCenter) error {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "UpdateOneCostCenter", "修改一个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.CostCenterId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.Insert
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) Insert(user *models.Usertab, entities *[]model.CostCenter) error {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "InsertCostCenter", "插入多个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.CostCenterId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.Delete
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) Delete(user *models.Usertab, entities *[]model.CostCenter) error {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "DeleteCostCenter", "删除多个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.CostCenterId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.Select
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "SelectCostCenter", "查询CostCenter")

	condition := DefaultConditionOfCostCenterAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/CostCenterService.Update
 *
 ******************************************************************************/
func (impl *CostCenterServiceImplement) Update(user *models.Usertab, entities *[]model.CostCenter) error {

	grmi.Log(user, "/services/base/implments/CostCenter.service.impl.go", "UpdateCostCenter", "修改多个CostCenter")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewCostCenterDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.CostCenterId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
