// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_LF_MOM_BACKEND/dao/base"
	"LAPP_LF_MOM_BACKEND/db"
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Description              : Role的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
var DefaultConditionOfRole = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.Role_RoleId.UrlParameterName:     grmi.NewConditionItem(meta.Role_RoleId, grmi.Equal, true),
		meta.Role_RoleName.UrlParameterName:   grmi.NewConditionItem(meta.Role_RoleName, grmi.Equal, false),
		meta.Role_RoleSort.UrlParameterName:   grmi.NewConditionItem(meta.Role_RoleSort, grmi.Equal, false),
		meta.Role_Status.UrlParameterName:     grmi.NewConditionItem(meta.Role_Status, grmi.Equal, false),
		meta.Role_Remark.UrlParameterName:     grmi.NewConditionItem(meta.Role_Remark, grmi.Equal, false),
		meta.Role_RoleKey.UrlParameterName:    grmi.NewConditionItem(meta.Role_RoleKey, grmi.Equal, false),
		meta.Role_DataScope.UrlParameterName:  grmi.NewConditionItem(meta.Role_DataScope, grmi.Equal, false),
		meta.Role_LastModify.UrlParameterName: grmi.NewConditionItem(meta.Role_LastModify, grmi.Approximate, false),
		meta.Role_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.Role_LastUser, grmi.Equal, false),
		meta.Role_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.Role_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : Role的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
var DefaultConditionOfRoleAndPaging = grmi.NewCondition(
	DefaultConditionOfRole.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : RoleServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : Role的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
type RoleServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewRoleDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个RoleDAOImplement实例
 *
 * @Return Value             : RoleDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func NewRoleServiceImplement() *RoleServiceImplement {
	return &RoleServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.InsertOne
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) InsertOne(user *models.Usertab, entity *model.Role) error {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "InsertOneRole", "插入一个Role")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleDAO(session, user.Userid)
	record, err := dao.SelectOne(entity.RoleId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.DeleteOne
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) DeleteOne(user *models.Usertab, roleId int) error {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "DeleteOneRole", "删除一个Role")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleDAO(session, user.Userid)
	record, err := dao.SelectOne(roleId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(roleId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.SelectOne
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) SelectOne(user *models.Usertab, roleId int) (*model.Role, error) {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "SelectOneRole", "查询一个Role")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleDAO(session, user.Userid)
	result, err := dao.SelectOne(roleId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.UpdateOne
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) UpdateOne(user *models.Usertab, entity *model.Role) error {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "UpdateOneRole", "修改一个Role")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleDAO(session, user.Userid)
	record, err := dao.SelectOne(entity.RoleId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.Insert
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) Insert(user *models.Usertab, entities *[]model.Role) error {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "InsertRole", "插入多个Role")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleDAO(session, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RoleId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.Delete
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) Delete(user *models.Usertab, entities *[]model.Role) error {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "DeleteRole", "删除多个Role")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleDAO(session, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RoleId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.Select
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "SelectRole", "查询Role")

	condition := DefaultConditionOfRoleAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewRoleDAO(session, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleService.Update
 *
 ******************************************************************************/
func (impl *RoleServiceImplement) Update(user *models.Usertab, entities *[]model.Role) error {

	grmi.Log(user, "/services/base/implments/Role.service.impl.go", "UpdateRole", "修改多个Role")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleDAO(session, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RoleId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
