// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_LF_MOM_BACKEND/dao/base"
	"LAPP_LF_MOM_BACKEND/db"
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Description              : RoleMenu的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
var DefaultConditionOfRoleMenu = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.RoleMenu_RoleId.UrlParameterName:     grmi.NewConditionItem(meta.RoleMenu_RoleId, grmi.Equal, true),
		meta.RoleMenu_MenuId.UrlParameterName:     grmi.NewConditionItem(meta.RoleMenu_MenuId, grmi.Equal, true),
		meta.RoleMenu_RoleName.UrlParameterName:   grmi.NewConditionItem(meta.RoleMenu_RoleName, grmi.Equal, false),
		meta.RoleMenu_LastModify.UrlParameterName: grmi.NewConditionItem(meta.RoleMenu_LastModify, grmi.Approximate, false),
		meta.RoleMenu_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.RoleMenu_LastUser, grmi.Equal, false),
		meta.RoleMenu_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.RoleMenu_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : RoleMenu的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
var DefaultConditionOfRoleMenuAndPaging = grmi.NewCondition(
	DefaultConditionOfRoleMenu.Items,
	grmi.NewPaging(),
)

/******************************************************************************
 *
 * @Struct Name              : RoleMenuServiceImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : RoleMenu的服务实现
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
type RoleMenuServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewRoleMenuDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个RoleMenuDAOImplement实例
 *
 * @Return Value             : RoleMenuDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func NewRoleMenuServiceImplement() *RoleMenuServiceImplement {
	return &RoleMenuServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.InsertOne
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) InsertOne(user *models.Usertab, entity *model.RoleMenu) error {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "InsertOneRoleMenu", "插入一个RoleMenu")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleMenuDAO(session, user.Userid)
	record, err := dao.SelectOne(entity.RoleId, entity.MenuId)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.DeleteOne
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) DeleteOne(user *models.Usertab, roleId int, menuId int) error {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "DeleteOneRoleMenu", "删除一个RoleMenu")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleMenuDAO(session, user.Userid)
	record, err := dao.SelectOne(roleId, menuId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(roleId, menuId)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.SelectOne
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) SelectOne(user *models.Usertab, roleId int, menuId int) (*model.RoleMenu, error) {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "SelectOneRoleMenu", "查询一个RoleMenu")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleMenuDAO(session, user.Userid)
	result, err := dao.SelectOne(roleId, menuId)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.UpdateOne
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) UpdateOne(user *models.Usertab, entity *model.RoleMenu) error {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "UpdateOneRoleMenu", "修改一个RoleMenu")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleMenuDAO(session, user.Userid)
	record, err := dao.SelectOne(entity.RoleId, entity.MenuId)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.Insert
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) Insert(user *models.Usertab, entities *[]model.RoleMenu) error {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "InsertRoleMenu", "插入多个RoleMenu")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleMenuDAO(session, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RoleId, entity.MenuId)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.Delete
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) Delete(user *models.Usertab, entities *[]model.RoleMenu) error {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "DeleteRoleMenu", "删除多个RoleMenu")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleMenuDAO(session, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RoleId, entity.MenuId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.Select
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "SelectRoleMenu", "查询RoleMenu")

	condition := DefaultConditionOfRoleMenuAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewRoleMenuDAO(session, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/RoleMenuService.Update
 *
 ******************************************************************************/
func (impl *RoleMenuServiceImplement) Update(user *models.Usertab, entities *[]model.RoleMenu) error {

	grmi.Log(user, "/services/base/implments/RoleMenu.service.impl.go", "UpdateRoleMenu", "修改多个RoleMenu")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewRoleMenuDAO(session, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.RoleId, entity.MenuId)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
