// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package implments

import (
	dal "LAPP_LF_MOM_BACKEND/dao/base"
	"LAPP_LF_MOM_BACKEND/db"
	"LAPP_LF_MOM_BACKEND/grmi"
	meta "LAPP_LF_MOM_BACKEND/meta/base"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Description              : WorkLineSpecialTime的默认查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfWorkLineSpecialTime = grmi.NewCondition(
	map[string]grmi.ConditionItem{
		meta.WorkLineSpecialTime_WorkLineid.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialTime_WorkLineid, grmi.Equal, true),
		meta.WorkLineSpecialTime_BegTime.UrlParameterName:    grmi.NewConditionItem(meta.WorkLineSpecialTime_BegTime, grmi.Approximate, true),
		meta.WorkLineSpecialTime_AddMinus.UrlParameterName:   grmi.NewConditionItem(meta.WorkLineSpecialTime_AddMinus, grmi.Equal, false),
		meta.WorkLineSpecialTime_EndTime.UrlParameterName:    grmi.NewConditionItem(meta.WorkLineSpecialTime_EndTime, grmi.Approximate, false),
		meta.WorkLineSpecialTime_TimeObjId.UrlParameterName:  grmi.NewConditionItem(meta.WorkLineSpecialTime_TimeObjId, grmi.Equal, false),
		meta.WorkLineSpecialTime_LastModify.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialTime_LastModify, grmi.Approximate, false),
		meta.WorkLineSpecialTime_LastUser.UrlParameterName:   grmi.NewConditionItem(meta.WorkLineSpecialTime_LastUser, grmi.Equal, false),
		meta.WorkLineSpecialTime_CreateTime.UrlParameterName: grmi.NewConditionItem(meta.WorkLineSpecialTime_CreateTime, grmi.Approximate, false),
	},
	nil,
)

/******************************************************************************
 *
 * @Description              : WorkLineSpecialTime的默认分页查询条件
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
var DefaultConditionOfWorkLineSpecialTimeAndPaging = grmi.NewCondition(
	DefaultConditionOfWorkLineSpecialTime.Items,
	grmi.NewPaging(),
)

/******************************************************************************
*
* @Struct Name              : WorkLineSpecialTimeServiceImplement
*-----------------------------------------------------------------------------
*
* @Description              : WorkLineSpecialTime的服务实现
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-23 10:43:27
*
******************************************************************************/
type WorkLineSpecialTimeServiceImplement struct {
}

/******************************************************************************
 *
 * @Function Name            : NewWorkLineSpecialTimeDAOImplement
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkLineSpecialTimeDAOImplement实例
 *
 * @Return Value             : WorkLineSpecialTimeDAOImplement实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-23 10:43:27
 *
 ******************************************************************************/
func NewWorkLineSpecialTimeServiceImplement() *WorkLineSpecialTimeServiceImplement {
	return &WorkLineSpecialTimeServiceImplement{}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.InsertOne
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) InsertOne(user *models.Usertab, entity *model.WorkLineSpecialTime) error {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "InsertOneWorkLineSpecialTime", "插入一个WorkLineSpecialTime")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid, entity.BegTime)
	if err != nil {
		return err
	}
	if record != nil {
		return grmi.NewBusinessError("已经存在相同主键的记录!")
	}
	err = dao.InsertOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.DeleteOne
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) DeleteOne(user *models.Usertab, workLineid string, begTime grmi.DateTime) error {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "DeleteOneWorkLineSpecialTime", "删除一个WorkLineSpecialTime")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(workLineid, begTime)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.DeleteOne(workLineid, begTime)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.SelectOne
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) SelectOne(user *models.Usertab, workLineid string, begTime grmi.DateTime) (*model.WorkLineSpecialTime, error) {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "SelectOneWorkLineSpecialTime", "查询一个WorkLineSpecialTime")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)
	result, err := dao.SelectOne(workLineid, begTime)
	if err != nil {
		return nil, err
	}
	return result, nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.UpdateOne
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) UpdateOne(user *models.Usertab, entity *model.WorkLineSpecialTime) error {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "UpdateOneWorkLineSpecialTime", "修改一个WorkLineSpecialTime")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)
	record, err := dao.SelectOne(entity.WorkLineid, entity.BegTime)
	if err != nil {
		return err
	}
	if record == nil {
		return grmi.NewBusinessError("不存在指定记录!")
	}
	err = dao.UpdateOne(entity)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.Insert
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) Insert(user *models.Usertab, entities *[]model.WorkLineSpecialTime) error {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "InsertWorkLineSpecialTime", "插入多个WorkLineSpecialTime")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineid, entity.BegTime)
		if err != nil {
			return err
		}
		if record != nil {
			return grmi.NewBusinessError("已经存在相同主键的记录!")
		}
	}

	err := dao.Insert(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.Delete
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) Delete(user *models.Usertab, entities *[]model.WorkLineSpecialTime) error {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "DeleteWorkLineSpecialTime", "删除多个WorkLineSpecialTime")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineid, entity.BegTime)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Delete(entities)
	if err != nil {
		return err
	}
	return nil
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.Select
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) Select(user *models.Usertab, urlParameters map[string]string) (interface{}, error) {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "SelectWorkLineSpecialTime", "查询WorkLineSpecialTime")

	condition := DefaultConditionOfWorkLineSpecialTimeAndPaging
	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	predicates, err := condition.BuildPredicates(urlParameters)
	if err != nil {
		return nil, err
	}
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)
	if condition.Fill(urlParameters) {
		result, err := dao.SelectAndPaging(condition.Paging, predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	} else {
		result, err := dao.Select(predicates, condition.OrderByFields)
		if err != nil {
			return nil, err
		}
		return result, nil
	}
}

/******************************************************************************
 *
 * @Reference LAPP_LF_MOM_BACKEND/services/base/WorkLineSpecialTimeService.Update
 *
 ******************************************************************************/
func (impl *WorkLineSpecialTimeServiceImplement) Update(user *models.Usertab, entities *[]model.WorkLineSpecialTime) error {

	grmi.Log(user, "/services/base/implments/WorkLineSpecialTime.service.impl.go", "UpdateWorkLineSpecialTime", "修改多个WorkLineSpecialTime")

	engine := db.Eloquent.Master()
	session := engine.NewSession()
	defer session.Close()
	dao := dal.NewWorkLineSpecialTimeDAO(session, user.Pid, user.Userid)

	for _, entity := range *entities {
		record, err := dao.SelectOne(entity.WorkLineid, entity.BegTime)
		if err != nil {
			return err
		}
		if record == nil {
			return grmi.NewBusinessError("不存在指定记录!")
		}
	}

	err := dao.Update(entities)
	if err != nil {
		return err
	}
	return nil
}
