// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/services/om/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Interface Name           : SerialOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : SerialOrder的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-20 13:07:32
 *
 ******************************************************************************/
type SerialOrderService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的SerialOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.SerialOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的SerialOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, string, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的SerialOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的SerialOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, string, string) (*model.SerialOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的SerialOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.SerialOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的SerialOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.SerialOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的SerialOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.SerialOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的SerialOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-20 13:07:32
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.SerialOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : InsertFromWorkOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 通过WorkOrderId插入多条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : WorkOrderIds
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-05-07
	 *
	 ******************************************************************************/
	InsertFromWorkOrder(*models.Usertab, []string) ([]model.LockedResponseWorkOrder, error)
}

/******************************************************************************
 *
 * @Function Name            : NewSerialOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个SerialOrderService
 *
 * @Return Value             : SerialOrderService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-20 13:07:32
 *
 ******************************************************************************/
func NewSerialOrderService() SerialOrderService {
	return implments.NewSerialOrderServiceImplement()
}
