// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/services/om/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Interface Name           : WorkOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : WorkOrder的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
type WorkOrderService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条WorkOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.WorkOrderJoin) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的WorkOrder
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, string) (*model.WorkOrderJoin, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条WorkOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WorkOrder
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.WorkOrderJoin) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条WorkOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的WorkOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条WorkOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的WorkOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询WorkOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条WorkOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的WorkOrder列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-04-19 14:04:47
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.WorkOrder) error
	/******************************************************************************
	 *
	 * @Function Name            : Revocation
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 撤销订单状态
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要撤销的WorkOrderId列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 张鑫
	 *
	 * @Date                     : 2021-04-30
	 *
	 ******************************************************************************/
	Revocation(*models.Usertab, []string) error
	/******************************************************************************
	 *
	 * @Function Name            : CancelWorkOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 取消workOrder中指定数量的serialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : workOrderId
	 *
	 * @Function Parameters      : 取消的数量
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 张鑫
	 *
	 * @Date                     : 2021-06-29
	 *
	 ******************************************************************************/
	CancelWorkOrder(*models.Usertab, string, float64) error
	/******************************************************************************
	 *
	 * @Function Name            : LockWorkOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 通过WorkOrderId插入多条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : WorkOrderIds
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-07-14
	 *
	 ******************************************************************************/
	LockWorkOrder(user *models.Usertab, workOrderIds []string) ([]model.LockedResponseWorkOrder, error)
	/******************************************************************************
	 *
	 * @Function Name            : CreateLockWorkOrder
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 通过WorkOrderId插入多条SerialOrder
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : WorkOrderIds
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : zhangxin
	 *
	 * @Date                     : 2021-07-14
	 *
	 ******************************************************************************/
	CreateLockWorkOrder(user *models.Usertab, data *model.CreateLockWorkOrder) error
}

/******************************************************************************
 *
 * @Function Name            : NewWorkOrderService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个WorkOrderService
 *
 * @Return Value             : WorkOrderService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func NewWorkOrderService() WorkOrderService {
	return implments.NewWorkOrderServiceImplement()
}
