// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package qm

import (
	model "LAPP_LF_MOM_BACKEND/models/qm"
	"LAPP_LF_MOM_BACKEND/services/qm/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
*
* @Interface Name           : DefectRecordService
*-----------------------------------------------------------------------------
*
* @Description              : DefectRecord的服务接口
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-18 23:20:31
*
******************************************************************************/
type DefectRecordService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条DefectRecord
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的DefectRecord
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.DefectRecord) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的DefectRecord
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, int) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的DefectRecord
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的DefectRecord
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, int) (*model.DefectRecord, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条DefectRecord
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的DefectRecord
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.DefectRecord) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条DefectRecord
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的DefectRecord列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, model.SerialOrderRuting) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条DefectRecord
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的DefectRecord列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.DefectRecord) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询DefectRecord
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条DefectRecord
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的DefectRecord列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.DefectRecord) error
	/******************************************************************************
	 *
	 * @Function Name            : Rework
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 返工
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 23:20:31
	 *
	 ******************************************************************************/
	Rework(*models.Usertab, int) error
}

/******************************************************************************
 *
 * @Function Name            : NewDefectRecordService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个DefectRecordService
 *
 * @Return Value             : DefectRecordService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 23:20:31
 *
 ******************************************************************************/
func NewDefectRecordService() DefectRecordService {
	return implments.NewDefectRecordServiceImplement()
}
