// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package qm

import (
	"LAPP_LF_MOM_BACKEND/container"
	model "LAPP_LF_MOM_BACKEND/models/qm"
	"LAPP_LF_MOM_BACKEND/services/qm/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
*
* @Interface Name           : ViewService
*-----------------------------------------------------------------------------
*
* @Description              : View的服务接口
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-03-18 21:50:48
*
******************************************************************************/
type ViewService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条View
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的View
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.View) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的View
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的View
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的View
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, string) (*model.View, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条View
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的View
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.View) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条View
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的View列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.View) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条View
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的View列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.View) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询View
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条View
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的View列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-03-18 21:50:48
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.View) error
	/******************************************************************************
	 *
	 * @Function Name            : ViewsOfArticle
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 获取与指定Article关联的视图
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 序列订单OrderId
	 *
	 * @Return Value             : 与指定Article关联的视图
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : chenglei.wei@le-it.com.cn
	 *
	 * @Date                     : 2021-03-18
	 *
	 ******************************************************************************/
	ViewsOfArticle(*container.RequestContext, string) ([]model.View, error)
}

/******************************************************************************
 *
 * @Function Name            : NewViewService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个ViewService
 *
 * @Return Value             : ViewService
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 21:50:48
 *
 ******************************************************************************/
func NewViewService() ViewService {
	return implments.NewViewServiceImplement()
}
