// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/services/wm/implments"
	"LAPP_LF_MOM_BACKEND/web/models"
)

/******************************************************************************
 *
 * @Interface Name           : InventoryBookService
 *-----------------------------------------------------------------------------
 *
 * @Description              : InventoryBook的服务接口
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
type InventoryBookService interface {
	/******************************************************************************
	 *
	 * @Function Name            : InsertOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入一条InventoryBook
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的InventoryBook
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	InsertOne(*models.Usertab, *model.InventoryBook) error
	/******************************************************************************
	 *
	 * @Function Name            : DeleteOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除指定键的InventoryBook
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	DeleteOne(*models.Usertab, string, string, string) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查找指定键的InventoryBook
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Function Parameters      : 主键
	 *
	 * @Return Value             : 查找到的InventoryBook
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	SelectOne(*models.Usertab, string, string, string) (*model.InventoryBook, error)
	/******************************************************************************
	 *
	 * @Function Name            : UpdateOne
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改一条InventoryBook
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的InventoryBook
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	UpdateOne(*models.Usertab, *model.InventoryBook) error
	/******************************************************************************
	 *
	 * @Function Name            : Insert
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 插入多条InventoryBook
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要插入的InventoryBook列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Insert(*models.Usertab, *[]model.InventoryBook) error
	/******************************************************************************
	 *
	 * @Function Name            : Delete
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 删除多条InventoryBook
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要删除的InventoryBook列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Delete(*models.Usertab, *[]model.InventoryBook) error
	/******************************************************************************
	 *
	 * @Function Name            : SelectAndPaging
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 查询InventoryBook
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询参数
	 *
	 * @Return Value             : 查询结果
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Select(*models.Usertab, map[string]string) (interface{}, error)
	/******************************************************************************
	 *
	 * @Function Name            : Update
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 修改多条InventoryBook
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 需要修改的InventoryBook列表
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 代码生成器创建
	 *
	 * @Date                     : 2021-06-29 10:57:04
	 *
	 ******************************************************************************/
	Update(*models.Usertab, *[]model.InventoryBook) error
	/******************************************************************************
	 *
	 * @Function Name            : ExportExcel
	 *-----------------------------------------------------------------------------
	 *
	 * @Description              : 导出excel
	 *
	 * @Function Parameters      : 当前访问人员信息
	 *
	 * @Function Parameters      : 查询条件
	 *
	 * @Return Value             : 生成的excel文件地址
	 *
	 * @Return Value             : 执行时发生的错误
	 *
	 * @Author                   : 徐腾飞
	 *
	 * @Date                     : 2021-07-19
	 *
	 ******************************************************************************/
	ExportExcel(*models.Usertab, map[string]string) (interface{}, error)
}

/******************************************************************************
 *
 * @Function Name            : NewInventoryBookService
 *-----------------------------------------------------------------------------
 *
 * @Description              : 创建一个InventoryBookService
 *
 * @Return Value             : InventoryBookService实例
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func NewInventoryBookService() InventoryBookService {
	return implments.NewInventoryBookServiceImplement()
}
