// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package api

import (
	model "LAPP_LF_MOM_BACKEND/models/api"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterOneA30Mes(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.A30Mes) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.A30Mes)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterIDOfA30Mes(party router.Party, httpMethod string, path string, method func(*models.Usertab) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		err = method(user)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterInsertOneA30Mes(party router.Party, path string, method func(*models.Usertab, *model.A30Mes) error) {

	RegisterOneA30Mes(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterDeleteOneA30Mes(party router.Party, path string, method func(*models.Usertab) error) {

	RegisterIDOfA30Mes(party, "DELETE", path+"", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterSelectOneA30Mes(party router.Party, path string, method func(*models.Usertab) (*model.A30Mes, error)) {

	party.Get(path+"", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterUpdateOneA30Mes(party router.Party, path string, method func(*models.Usertab, *model.A30Mes) error) {

	RegisterOneA30Mes(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterMultiA30Mes(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.A30Mes) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.A30Mes, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterInsertA30Mes(party router.Party, path string, method func(*models.Usertab, *[]model.A30Mes) error) {

	RegisterMultiA30Mes(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterDeleteA30Mes(party router.Party, path string, method func(*models.Usertab, *[]model.A30Mes) error) {

	RegisterMultiA30Mes(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterSelectA30Mes(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateA30Mes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条A30Mes的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-11 17:10:11
 *
 ******************************************************************************/
func RegisterUpdateA30Mes(party router.Party, path string, method func(*models.Usertab, *[]model.A30Mes) error) {

	RegisterMultiA30Mes(party, "PUT", path, method)
}
