// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterOneArtQtyAllocate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArtQtyAllocate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtQtyAllocate)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterIDOfArtQtyAllocate(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		attriCode, err := ctx.Params().GetInt("attriCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")
		subObject := ctx.Params().GetString("subObject")

		err = method(user, attriCode, workLineId, subObject)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterInsertOneArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, *model.ArtQtyAllocate) error) {

	RegisterOneArtQtyAllocate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterDeleteOneArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, int, string, string) error) {

	RegisterIDOfArtQtyAllocate(party, "DELETE", path+"/{attriCode:int}/{workLineId:string}/{subObject:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterSelectOneArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, int, string, string) (*model.ArtQtyAllocate, error)) {

	party.Get(path+"/{attriCode:int}/{workLineId:string}/{subObject:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		attriCode, err := ctx.Params().GetInt("attriCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")
		subObject := ctx.Params().GetString("subObject")
		result, err := method(user, attriCode, workLineId, subObject)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterUpdateOneArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, *model.ArtQtyAllocate) error) {

	RegisterOneArtQtyAllocate(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterMultiArtQtyAllocate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArtQtyAllocate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArtQtyAllocate, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterInsertArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, *[]model.ArtQtyAllocate) error) {

	RegisterMultiArtQtyAllocate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterDeleteArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, *[]model.ArtQtyAllocate) error) {

	RegisterMultiArtQtyAllocate(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterSelectArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArtQtyAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArtQtyAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterUpdateArtQtyAllocate(party router.Party, path string, method func(*models.Usertab, *[]model.ArtQtyAllocate) error) {

	RegisterMultiArtQtyAllocate(party, "PUT", path, method)
}
