// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterOneArtWorkLineLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArtWorkLineLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtWorkLineLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterIDOfArtWorkLineLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		workLineId := ctx.Params().GetString("workLineId")

		err = method(user, artId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterInsertOneArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, *model.ArtWorkLineLst) error) {

	RegisterOneArtWorkLineLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterDeleteOneArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfArtWorkLineLst(party, "DELETE", path+"/{artId:string}/{workLineId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterSelectOneArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, string, string) (*model.ArtWorkLineLst, error)) {

	party.Get(path+"/{artId:string}/{workLineId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		workLineId := ctx.Params().GetString("workLineId")
		result, err := method(user, artId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterUpdateOneArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, *model.ArtWorkLineLst) error) {

	RegisterOneArtWorkLineLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterMultiArtWorkLineLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArtWorkLineLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArtWorkLineLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterInsertArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtWorkLineLst) error) {

	RegisterMultiArtWorkLineLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterDeleteArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtWorkLineLst) error) {

	RegisterMultiArtWorkLineLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterSelectArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterUpdateArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArtWorkLineLst) error) {

	RegisterMultiArtWorkLineLst(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterSaveArtWorkLineLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个保存ArtWorkLineLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-08-23 15:03:00
 *
 ******************************************************************************/
func RegisterSaveArtWorkLineLst(party router.Party, path string, method func(*models.Usertab, *model.ArtWorkLineData) error) {

	party.Post(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var entity model.ArtWorkLineData
		if err := ctx.ReadJSON(&entity); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		err := method(user, &entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}