// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterOneArticleAtcodLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArticleAtcodLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArticleAtcodLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterIDOfArticleAtcodLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int, string, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		version, err := ctx.Params().GetInt("version")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		projectId := ctx.Params().GetString("projectId")
		attrCode, err := ctx.Params().GetInt("attrCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		attrValue := ctx.Params().GetString("attrValue")

		err = method(user, artId, version, projectId, attrCode, attrValue)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterInsertOneArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, *model.ArticleAtcodLst) error) {

	RegisterOneArticleAtcodLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterDeleteOneArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, string, int, string, int, string) error) {

	RegisterIDOfArticleAtcodLst(party, "DELETE", path+"/{artId:string}/{version:int}/{projectId:string}/{attrCode:int}/{attrValue:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterSelectOneArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, string, int, string, int, string) (*model.ArticleAtcodLst, error)) {

	party.Get(path+"/{artId:string}/{version:int}/{projectId:string}/{attrCode:int}/{attrValue:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		version, err := ctx.Params().GetInt("version")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		projectId := ctx.Params().GetString("projectId")
		attrCode, err := ctx.Params().GetInt("attrCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		attrValue := ctx.Params().GetString("attrValue")
		result, err := method(user, artId, version, projectId, attrCode, attrValue)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterUpdateOneArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, *model.ArticleAtcodLst) error) {

	RegisterOneArticleAtcodLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterMultiArticleAtcodLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArticleAtcodLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArticleAtcodLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterInsertArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArticleAtcodLst) error) {

	RegisterMultiArticleAtcodLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterDeleteArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArticleAtcodLst) error) {

	RegisterMultiArticleAtcodLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterSelectArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArticleAtcodLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArticleAtcodLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 09:34:38
 *
 ******************************************************************************/
func RegisterUpdateArticleAtcodLst(party router.Party, path string, method func(*models.Usertab, *[]model.ArticleAtcodLst) error) {

	RegisterMultiArticleAtcodLst(party, "PUT", path, method)
}
