// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterOneAttributeGroup(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.AttributeGroup) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.AttributeGroup)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterIDOfAttributeGroup(party router.Party, httpMethod string, path string, method func(*models.Usertab, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		attrGrpCode, err := ctx.Params().GetInt("attrGrpCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, attrGrpCode)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertOneAttributeGroup(party router.Party, path string, method func(*models.Usertab, *model.AttributeGroup) error) {

	RegisterOneAttributeGroup(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteOneAttributeGroup(party router.Party, path string, method func(*models.Usertab, int) error) {

	RegisterIDOfAttributeGroup(party, "DELETE", path+"/{attrGrpCode:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectOneAttributeGroup(party router.Party, path string, method func(*models.Usertab, int) (*model.AttributeGroup, error)) {

	party.Get(path+"/{attrGrpCode:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		attrGrpCode, err := ctx.Params().GetInt("attrGrpCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, attrGrpCode)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateOneAttributeGroup(party router.Party, path string, method func(*models.Usertab, *model.AttributeGroup) error) {

	RegisterOneAttributeGroup(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterMultiAttributeGroup(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.AttributeGroup) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.AttributeGroup, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertAttributeGroup(party router.Party, path string, method func(*models.Usertab, *[]model.AttributeGroup) error) {

	RegisterMultiAttributeGroup(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteAttributeGroup(party router.Party, path string, method func(*models.Usertab, *[]model.AttributeGroup) error) {

	RegisterMultiAttributeGroup(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectAttributeGroup(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateAttributeGroup
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条AttributeGroup的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateAttributeGroup(party router.Party, path string, method func(*models.Usertab, *[]model.AttributeGroup) error) {

	RegisterMultiAttributeGroup(party, "PUT", path, method)
}
