// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterOneGuideRuleInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.GuideRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.GuideRuleInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterIDOfGuideRuleInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, operationId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterInsertOneGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, *model.GuideRuleInfo) error) {

	RegisterOneGuideRuleInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterDeleteOneGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, int) error) {

	RegisterIDOfGuideRuleInfo(party, "DELETE", path+"/{operationId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterSelectOneGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, int) (*model.GuideRuleInfo, error)) {

	party.Get(path+"/{operationId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, operationId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterUpdateOneGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, *model.GuideRuleInfo) error) {

	RegisterOneGuideRuleInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterMultiGuideRuleInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.GuideRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.GuideRuleInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterInsertGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, *model.GuideRuleInfoData) error) {

	RegisterInsertGuideRuleInfoHandler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterDeleteGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, *[]model.GuideRuleInfo) error) {

	RegisterMultiGuideRuleInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterSelectGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterUpdateGuideRuleInfo(party router.Party, path string, method func(*models.Usertab, *[]model.GuideRuleInfo) error) {

	RegisterMultiGuideRuleInfo(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterMultiGuideRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条GuideRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-12 10:43:48
 *
 ******************************************************************************/
func RegisterInsertGuideRuleInfoHandler(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.GuideRuleInfoData) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var entities model.GuideRuleInfoData
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
