// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterOneOPCBasicComInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.OPCBasicComInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.OPCBasicComInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterIDOfOPCBasicComInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, operationId, workPlaceNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterInsertOneOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, *model.OPCBasicComInfo) error) {

	RegisterOneOPCBasicComInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterDeleteOneOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, int, int) error) {

	RegisterIDOfOPCBasicComInfo(party, "DELETE", path+"/{operationId:int}/{workPlaceNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterSelectOneOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, int, int) (*model.OPCBasicComInfo, error)) {

	party.Get(path+"/{operationId:int}/{workPlaceNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, operationId, workPlaceNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterUpdateOneOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, *model.OPCBasicComInfo) error) {

	RegisterOneOPCBasicComInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterMultiOPCBasicComInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.OPCBasicComInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.OPCBasicComInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterInsertOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, *[]model.OPCBasicComInfo) error) {

	RegisterMultiOPCBasicComInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterDeleteOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, *[]model.OPCBasicComInfo) error) {

	RegisterMultiOPCBasicComInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterSelectOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterUpdateOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, *[]model.OPCBasicComInfo) error) {

	RegisterMultiOPCBasicComInfo(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterSaveOneOPCBasicComInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个保存单条OPCBasicComInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-08-18
 *
 ******************************************************************************/
func RegisterSaveOneOPCBasicComInfo(party router.Party, path string, method func(*models.Usertab, *model.OPCBasicComInfo) error) {

	RegisterOneOPCBasicComInfo(party, "POST", path, method)
}