// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterOneOPCMonitorComDetailRule(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.OPCMonitorComDetailRule) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.OPCMonitorComDetailRule)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterIDOfOPCMonitorComDetailRule(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int, int, int, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		monitorPalletInPlace, err := ctx.Params().GetInt("monitorPalletInPlace")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		monitorManualRelease, err := ctx.Params().GetInt("monitorManualRelease")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		monitorProblemPieceRelease, err := ctx.Params().GetInt("monitorProblemPieceRelease")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		ruleId, err := ctx.Params().GetInt("ruleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		detailId, err := ctx.Params().GetInt("detailId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, workPlaceNr, monitorPalletInPlace, monitorManualRelease, monitorProblemPieceRelease, ruleId, detailId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterInsertOneOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, *model.OPCMonitorComDetailRule) error) {

	RegisterOneOPCMonitorComDetailRule(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterDeleteOneOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, int, int, int, int, int, int) error) {

	RegisterIDOfOPCMonitorComDetailRule(party, "DELETE", path+"/{workPlaceNr:int}/{monitorPalletInPlace:int}/{monitorManualRelease:int}/{monitorProblemPieceRelease:int}/{ruleId:int}/{detailId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterSelectOneOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, int, int, int, int, int, int) (*model.OPCMonitorComDetailRule, error)) {

	party.Get(path+"/{workPlaceNr:int}/{monitorPalletInPlace:int}/{monitorManualRelease:int}/{monitorProblemPieceRelease:int}/{ruleId:int}/{detailId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		monitorPalletInPlace, err := ctx.Params().GetInt("monitorPalletInPlace")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		monitorManualRelease, err := ctx.Params().GetInt("monitorManualRelease")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		monitorProblemPieceRelease, err := ctx.Params().GetInt("monitorProblemPieceRelease")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		ruleId, err := ctx.Params().GetInt("ruleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		detailId, err := ctx.Params().GetInt("detailId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, workPlaceNr, monitorPalletInPlace, monitorManualRelease, monitorProblemPieceRelease, ruleId, detailId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterUpdateOneOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, *model.OPCMonitorComDetailRule) error) {

	RegisterOneOPCMonitorComDetailRule(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterMultiOPCMonitorComDetailRule(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.OPCMonitorComDetailRule) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.OPCMonitorComDetailRule, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterInsertOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, *[]model.OPCMonitorComDetailRule) error) {

	RegisterMultiOPCMonitorComDetailRule(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterDeleteOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, *[]model.OPCMonitorComDetailRule) error) {

	RegisterMultiOPCMonitorComDetailRule(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterSelectOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOPCMonitorComDetailRule
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条OPCMonitorComDetailRule的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-22 15:49:36
 *
 ******************************************************************************/
func RegisterUpdateOPCMonitorComDetailRule(party router.Party, path string, method func(*models.Usertab, *[]model.OPCMonitorComDetailRule) error) {

	RegisterMultiOPCMonitorComDetailRule(party, "PUT", path, method)
}
