// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterOnePersonLoginHistory(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.PersonLoginHistory) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PersonLoginHistory)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterIDOfPersonLoginHistory(party router.Party, httpMethod string, path string, method func(*models.Usertab, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		recNr, err := ctx.Params().GetInt("recNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, recNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterInsertOnePersonLoginHistory(party router.Party, path string, method func(*models.Usertab, *model.PersonLoginHistory) error) {

	RegisterOnePersonLoginHistory(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterDeleteOnePersonLoginHistory(party router.Party, path string, method func(*models.Usertab, int) error) {

	RegisterIDOfPersonLoginHistory(party, "DELETE", path+"/{recNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterSelectOnePersonLoginHistory(party router.Party, path string, method func(*models.Usertab, int) (*model.PersonLoginHistory, error)) {

	party.Get(path+"/{recNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		recNr, err := ctx.Params().GetInt("recNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, recNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterUpdateOnePersonLoginHistory(party router.Party, path string, method func(*models.Usertab, *model.PersonLoginHistory) error) {

	RegisterOnePersonLoginHistory(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterMultiPersonLoginHistory(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.PersonLoginHistory) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PersonLoginHistory, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterInsertPersonLoginHistory(party router.Party, path string, method func(*models.Usertab, *[]model.PersonLoginHistory) error) {

	RegisterMultiPersonLoginHistory(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterDeletePersonLoginHistory(party router.Party, path string, method func(*models.Usertab, *[]model.PersonLoginHistory) error) {

	RegisterMultiPersonLoginHistory(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterSelectPersonLoginHistory(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePersonLoginHistory
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PersonLoginHistory的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-25 14:20:56
 *
 ******************************************************************************/
func RegisterUpdatePersonLoginHistory(party router.Party, path string, method func(*models.Usertab, *[]model.PersonLoginHistory) error) {

	RegisterMultiPersonLoginHistory(party, "PUT", path, method)
}
