// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterOnePrintRuleInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.PrintRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PrintRuleInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterIDOfPrintRuleInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, operationId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterInsertOnePrintRuleInfo(party router.Party, path string, method func(*models.Usertab, *model.PrintRuleInfo) error) {

	RegisterOnePrintRuleInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterDeleteOnePrintRuleInfo(party router.Party, path string, method func(*models.Usertab, int) error) {

	RegisterIDOfPrintRuleInfo(party, "DELETE", path+"/{operationId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterSelectOnePrintRuleInfo(party router.Party, path string, method func(*models.Usertab, int) (*model.PrintRuleInfo, error)) {

	party.Get(path+"/{operationId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, operationId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterUpdateOnePrintRuleInfo(party router.Party, path string, method func(*models.Usertab, *model.PrintRuleInfo) error) {

	RegisterOnePrintRuleInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterMultiPrintRuleInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.PrintRuleInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PrintRuleInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterInsertPrintRuleInfo(party router.Party, path string, method func(*models.Usertab, *[]model.PrintRuleInfo) error) {

	RegisterMultiPrintRuleInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterDeletePrintRuleInfo(party router.Party, path string, method func(*models.Usertab, *[]model.PrintRuleInfo) error) {

	RegisterMultiPrintRuleInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterSelectPrintRuleInfo(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePrintRuleInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PrintRuleInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-16 15:09:09
 *
 ******************************************************************************/
func RegisterUpdatePrintRuleInfo(party router.Party, path string, method func(*models.Usertab, *[]model.PrintRuleInfo) error) {

	RegisterMultiPrintRuleInfo(party, "PUT", path, method)
}
