// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterOnePrinterTemplate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.PrinterTemplate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PrinterTemplate)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterIDOfPrinterTemplate(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		templateId := ctx.Params().GetString("templateId")

		err = method(user, templateId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterInsertOnePrinterTemplate(party router.Party, path string, method func(*models.Usertab, *model.PrinterTemplate) error) {

	RegisterOnePrinterTemplate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterDeleteOnePrinterTemplate(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfPrinterTemplate(party, "DELETE", path+"/{templateId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterSelectOnePrinterTemplate(party router.Party, path string, method func(*models.Usertab, string) (*model.PrinterTemplate, error)) {

	party.Get(path+"/{templateId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		templateId := ctx.Params().GetString("templateId")
		result, err := method(user, templateId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterUpdateOnePrinterTemplate(party router.Party, path string, method func(*models.Usertab, *model.PrinterTemplate) error) {

	RegisterOnePrinterTemplate(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterMultiPrinterTemplate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.PrinterTemplate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PrinterTemplate, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterInsertPrinterTemplate(party router.Party, path string, method func(*models.Usertab, *[]model.PrinterTemplate) error) {

	RegisterMultiPrinterTemplate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterDeletePrinterTemplate(party router.Party, path string, method func(*models.Usertab, *[]model.PrinterTemplate) error) {

	RegisterMultiPrinterTemplate(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterSelectPrinterTemplate(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePrinterTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PrinterTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterUpdatePrinterTemplate(party router.Party, path string, method func(*models.Usertab, *[]model.PrinterTemplate) error) {

	RegisterMultiPrinterTemplate(party, "PUT", path, method)
}
