// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterOnePrinterTemplateLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.PrinterTemplateLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PrinterTemplateLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterIDOfPrinterTemplateLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		templateId, err := ctx.Params().GetInt("templateId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, templateId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterInsertOnePrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, *model.PrinterTemplateLst) error) {

	RegisterOnePrinterTemplateLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterDeleteOnePrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, int, int) error) {

	RegisterIDOfPrinterTemplateLst(party, "DELETE", path+"/{templateId:int}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterSelectOnePrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, string, int) (*model.PrinterTemplateLst, error)) {

	party.Get(path+"/{templateId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		templateId := ctx.Params().GetString("templateId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, templateId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterUpdateOnePrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, *model.PrinterTemplateLst) error) {

	RegisterOnePrinterTemplateLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterMultiPrinterTemplateLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.PrinterTemplateLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PrinterTemplateLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterInsertPrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, *[]model.PrinterTemplateLst) error) {

	RegisterMultiPrinterTemplateLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterDeletePrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, *[]model.PrinterTemplateLst) error) {

	RegisterMultiPrinterTemplateLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterSelectPrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePrinterTemplateLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PrinterTemplateLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-20 16:59:51
 *
 ******************************************************************************/
func RegisterUpdatePrinterTemplateLst(party router.Party, path string, method func(*models.Usertab, *[]model.PrinterTemplateLst) error) {

	RegisterMultiPrinterTemplateLst(party, "PUT", path, method)
}
