// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterOneProcessWorkPlaceLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ProcessWorkPlaceLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ProcessWorkPlaceLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterIDOfProcessWorkPlaceLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		pO, err := ctx.Params().GetInt("pO")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")

		err = method(user, pO, workPlaceNr, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterInsertOneProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, *model.ProcessWorkPlaceLst) error) {

	RegisterOneProcessWorkPlaceLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterDeleteOneProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, int, int, string) error) {

	RegisterIDOfProcessWorkPlaceLst(party, "DELETE", path+"/{pO:int}/{workPlaceNr:int}/{workLineId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterSelectOneProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, int, int, string) (*model.ProcessWorkPlaceLst, error)) {

	party.Get(path+"/{pO:int}/{workPlaceNr:int}/{workLineId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		pO, err := ctx.Params().GetInt("pO")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")
		result, err := method(user, pO, workPlaceNr, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterUpdateOneProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, *model.ProcessWorkPlaceLst) error) {

	RegisterOneProcessWorkPlaceLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterMultiProcessWorkPlaceLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ProcessWorkPlaceLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ProcessWorkPlaceLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterInsertProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, model.ProcessWPInsert) error) {

	RegisterInsertProcessWorkPlaceLstHandler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterDeleteProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, *[]model.ProcessWorkPlaceLst) error) {

	RegisterMultiProcessWorkPlaceLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterSelectProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateProcessWorkPlaceLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterUpdateProcessWorkPlaceLst(party router.Party, path string, method func(*models.Usertab, *[]model.ProcessWorkPlaceLst) error) {

	RegisterMultiProcessWorkPlaceLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertProcessWorkPlaceLstHandler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ProcessWorkPlaceLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-28 10:57:29
 *
 ******************************************************************************/
func RegisterInsertProcessWorkPlaceLstHandler(party router.Party, httpMethod string, path string, method func(*models.Usertab, model.ProcessWPInsert) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var entities model.ProcessWPInsert
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}