// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterOneRoleRel(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.RoleRel) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.RoleRel)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterIDOfRoleRel(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		roleId, err := ctx.Params().GetInt("roleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineid := ctx.Params().GetString("workLineid")

		err = method(user, roleId, workLineid)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterInsertOneRoleRel(party router.Party, path string, method func(*models.Usertab, *model.RoleRel) error) {

	RegisterOneRoleRel(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterDeleteOneRoleRel(party router.Party, path string, method func(*models.Usertab, int, string) error) {

	RegisterIDOfRoleRel(party, "DELETE", path+"/{roleId:int}/{workLineid:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterSelectOneRoleRel(party router.Party, path string, method func(*models.Usertab, int, string) (*model.RoleRel, error)) {

	party.Get(path+"/{roleId:int}/{workLineid:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		roleId, err := ctx.Params().GetInt("roleId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineid := ctx.Params().GetString("workLineid")
		result, err := method(user, roleId, workLineid)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterUpdateOneRoleRel(party router.Party, path string, method func(*models.Usertab, *model.RoleRel) error) {

	RegisterOneRoleRel(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterMultiRoleRel(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.RoleRel) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var entities []model.RoleRel
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterInsertRoleRel(party router.Party, path string, method func(*models.Usertab, *model.RoleRelInsert) error) {

	RegisterMultiInsertRoleRel(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterDeleteRoleRel(party router.Party, path string, method func(*models.Usertab, *[]model.RoleRel) error) {

	RegisterMultiRoleRel(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterSelectRoleRel(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterUpdateRoleRel(party router.Party, path string, method func(*models.Usertab, *[]model.RoleRel) error) {

	RegisterMultiRoleRel(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterMultiInsertRoleRel
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条RoleRel的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 10:36:05
 *
 ******************************************************************************/
func RegisterMultiInsertRoleRel(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.RoleRelInsert) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var entities model.RoleRelInsert
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}