// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterOneSpecArtShareAllocate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.SpecArtShareAllocate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.SpecArtShareAllocate)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterIDOfSpecArtShareAllocate(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		attriCode, err := ctx.Params().GetInt("attriCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")
		subObject := ctx.Params().GetString("subObject")

		err = method(user, attriCode, workLineId, subObject)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterInsertOneSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, *model.SpecArtShareAllocate) error) {

	RegisterOneSpecArtShareAllocate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterDeleteOneSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, int, string, string) error) {

	RegisterIDOfSpecArtShareAllocate(party, "DELETE", path+"/{attriCode:int}/{workLineId:string}/{subObject:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterSelectOneSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, int, string, string) (*model.SpecArtShareAllocate, error)) {

	party.Get(path+"/{attriCode:int}/{workLineId:string}/{subObject:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		attriCode, err := ctx.Params().GetInt("attriCode")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workLineId := ctx.Params().GetString("workLineId")
		subObject := ctx.Params().GetString("subObject")
		result, err := method(user, attriCode, workLineId, subObject)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterUpdateOneSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, *model.SpecArtShareAllocate) error) {

	RegisterOneSpecArtShareAllocate(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterMultiSpecArtShareAllocate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.SpecArtShareAllocate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.SpecArtShareAllocate, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterInsertSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, *[]model.SpecArtShareAllocate) error) {

	RegisterMultiSpecArtShareAllocate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterDeleteSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, *[]model.SpecArtShareAllocate) error) {

	RegisterMultiSpecArtShareAllocate(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterSelectSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateSpecArtShareAllocate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条SpecArtShareAllocate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-14 14:51:48
 *
 ******************************************************************************/
func RegisterUpdateSpecArtShareAllocate(party router.Party, path string, method func(*models.Usertab, *[]model.SpecArtShareAllocate) error) {

	RegisterMultiSpecArtShareAllocate(party, "PUT", path, method)
}
