// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterOneStepType(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.StepType) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.StepType)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterIDOfStepType(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		stepTypeName := ctx.Params().GetString("stepTypeName")

		err = method(user, stepTypeName)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertOneStepType(party router.Party, path string, method func(*models.Usertab, *model.StepType) error) {

	RegisterOneStepType(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteOneStepType(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfStepType(party, "DELETE", path+"/{stepTypeName:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectOneStepType(party router.Party, path string, method func(*models.Usertab, string) (*model.StepType, error)) {

	party.Get(path+"/{stepTypeName:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		stepTypeName := ctx.Params().GetString("stepTypeName")
		result, err := method(user, stepTypeName)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateOneStepType(party router.Party, path string, method func(*models.Usertab, *model.StepType) error) {

	RegisterOneStepType(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterMultiStepType(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.StepType) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.StepType, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertStepType(party router.Party, path string, method func(*models.Usertab, *[]model.StepType) error) {

	RegisterMultiStepType(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteStepType(party router.Party, path string, method func(*models.Usertab, *[]model.StepType) error) {

	RegisterMultiStepType(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectStepType(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateStepType
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条StepType的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateStepType(party router.Party, path string, method func(*models.Usertab, *[]model.StepType) error) {

	RegisterMultiStepType(party, "PUT", path, method)
}
