// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterOneStepTypeRelLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.StepTypeRelLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.StepTypeRelLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterIDOfStepTypeRelLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		stepTypeName := ctx.Params().GetString("stepTypeName")
		pID := ctx.Params().GetString("pID")

		err = method(user, stepTypeName, pID)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertOneStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, *model.StepTypeRelLst) error) {

	RegisterOneStepTypeRelLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteOneStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfStepTypeRelLst(party, "DELETE", path+"/{stepTypeName:string}/{pID:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectOneStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, string, string) (*model.StepTypeRelLst, error)) {

	party.Get(path+"/{stepTypeName:string}/{pID:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		stepTypeName := ctx.Params().GetString("stepTypeName")
		pID := ctx.Params().GetString("pID")
		result, err := method(user, stepTypeName, pID)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateOneStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, *model.StepTypeRelLst) error) {

	RegisterOneStepTypeRelLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterMultiStepTypeRelLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.StepTypeRelLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.StepTypeRelLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterInsertStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, *[]model.StepTypeRelLst) error) {

	RegisterMultiStepTypeRelLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterDeleteStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, *[]model.StepTypeRelLst) error) {

	RegisterMultiStepTypeRelLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterSelectStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateStepTypeRelLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条StepTypeRelLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-06 16:25:16
 *
 ******************************************************************************/
func RegisterUpdateStepTypeRelLst(party router.Party, path string, method func(*models.Usertab, *[]model.StepTypeRelLst) error) {

	RegisterMultiStepTypeRelLst(party, "PUT", path, method)
}
