// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterOneTabColName(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.TabColName) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.TabColName)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterIDOfTabColName(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		tabName := ctx.Params().GetString("tabName")
		colName := ctx.Params().GetString("colName")

		err = method(user, tabName, colName)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterInsertOneTabColName(party router.Party, path string, method func(*models.Usertab, *model.TabColName) error) {

	RegisterOneTabColName(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterDeleteOneTabColName(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfTabColName(party, "DELETE", path+"/{tabName:string}/{colName:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterSelectOneTabColName(party router.Party, path string, method func(*models.Usertab, string, string) (*model.TabColName, error)) {

	party.Get(path+"/{tabName:string}/{colName:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		tabName := ctx.Params().GetString("tabName")
		colName := ctx.Params().GetString("colName")
		result, err := method(user, tabName, colName)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterUpdateOneTabColName(party router.Party, path string, method func(*models.Usertab, *model.TabColName) error) {

	RegisterOneTabColName(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterMultiTabColName(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.TabColName) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.TabColName, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterInsertTabColName(party router.Party, path string, method func(*models.Usertab, *[]model.TabColName) error) {

	RegisterMultiTabColName(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterDeleteTabColName(party router.Party, path string, method func(*models.Usertab, *[]model.TabColName) error) {

	RegisterMultiTabColName(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterSelectTabColName(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateTabColName
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条TabColName的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 15:04:54
 *
 ******************************************************************************/
func RegisterUpdateTabColName(party router.Party, path string, method func(*models.Usertab, *[]model.TabColName) error) {

	RegisterMultiTabColName(party, "PUT", path, method)
}
