// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterOneTightenWrenchInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.TightenWrenchInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.TightenWrenchInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterIDOfTightenWrenchInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, operationId, workPlaceNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterInsertOneTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, *model.TightenWrenchInfo) error) {

	RegisterOneTightenWrenchInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterDeleteOneTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, int, int) error) {

	RegisterIDOfTightenWrenchInfo(party, "DELETE", path+"/{operationId:int}/{workPlaceNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterSelectOneTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, int, int) (*model.TightenWrenchInfo, error)) {

	party.Get(path+"/{operationId:int}/{workPlaceNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		operationId, err := ctx.Params().GetInt("operationId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workPlaceNr, err := ctx.Params().GetInt("workPlaceNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, operationId, workPlaceNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterUpdateOneTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, *model.TightenWrenchInfo) error) {

	RegisterOneTightenWrenchInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterMultiTightenWrenchInfo(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.TightenWrenchInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.TightenWrenchInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterInsertTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, *[]model.TightenWrenchInfo) error) {

	RegisterMultiTightenWrenchInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterDeleteTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, *[]model.TightenWrenchInfo) error) {

	RegisterMultiTightenWrenchInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterSelectTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-13 16:59:07
 *
 ******************************************************************************/
func RegisterUpdateTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, *[]model.TightenWrenchInfo) error) {

	RegisterMultiTightenWrenchInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSaveOneTightenWrenchInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个保存单条TightenWrenchInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-08-18
 *
 ******************************************************************************/
func RegisterSaveOneTightenWrenchInfo(party router.Party, path string, method func(*models.Usertab, *model.TightenWrenchInfo) error) {

	RegisterOneTightenWrenchInfo(party, "POST", path, method)
}