// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"time"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterOneWorkCalendarLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.WorkCalendarLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.WorkCalendarLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterIDOfWorkCalendarLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, grmi.Date) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workCalendarNr, err := ctx.Params().GetInt("workCalendarNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workDateOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("workDate"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workDate := grmi.Date(workDateOrigin)

		err = method(user, workCalendarNr, workDate)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterInsertOneWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, *model.WorkCalendarLst) error) {

	RegisterOneWorkCalendarLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterDeleteOneWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, int, grmi.Date) error) {

	RegisterIDOfWorkCalendarLst(party, "DELETE", path+"/{workCalendarNr:int}/{workDate:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterSelectOneWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, int, grmi.Date) (*model.WorkCalendarLst, error)) {

	party.Get(path+"/{workCalendarNr:int}/{workDate:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workCalendarNr, err := ctx.Params().GetInt("workCalendarNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workDateOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("workDate"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		workDate := grmi.Date(workDateOrigin)
		result, err := method(user, workCalendarNr, workDate)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterUpdateOneWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, *model.WorkCalendarLst) error) {

	RegisterOneWorkCalendarLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterMultiWorkCalendarLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.WorkCalendarLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.WorkCalendarLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterInsertWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, *model.WorkCalendarLstInsertReq) error) {

	RegisterMultiInsertWorkCalendarLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterDeleteWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, *[]model.WorkCalendarLst) error) {

	RegisterMultiWorkCalendarLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterSelectWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-16 10:03:06
 *
 ******************************************************************************/
func RegisterUpdateWorkCalendarLst(party router.Party, path string, method func(*models.Usertab, *[]model.WorkCalendarLst) error) {

	RegisterMultiWorkCalendarLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiInsertWorkCalendarLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理插入多条WorkCalendarLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-04-15
 *
 ******************************************************************************/
func RegisterMultiInsertWorkCalendarLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.WorkCalendarLstInsertReq) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var entities model.WorkCalendarLstInsertReq
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
