// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	"LAPP_LF_MOM_BACKEND/grmi"
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
	"time"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterOneWorkLineSpecialTime(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.WorkLineSpecialTime) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.WorkLineSpecialTime)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterIDOfWorkLineSpecialTime(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, grmi.DateTime) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workLineid := ctx.Params().GetString("workLineid")
		begTimeOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("begTime"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
		}
		begTime := grmi.DateTime(begTimeOrigin)

		err = method(user, workLineid, begTime)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertOneWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, *model.WorkLineSpecialTime) error) {

	RegisterOneWorkLineSpecialTime(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteOneWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, string, grmi.DateTime) error) {

	RegisterIDOfWorkLineSpecialTime(party, "DELETE", path+"/{workLineid:string}/{begTime:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectOneWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, string, grmi.DateTime) (*model.WorkLineSpecialTime, error)) {

	party.Get(path+"/{workLineid:string}/{begTime:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workLineid := ctx.Params().GetString("workLineid")
		begTimeOrigin, err := time.Parse(grmi.URLDateTimeFormat, ctx.Params().GetString("begTime"))
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
		}
		begTime := grmi.DateTime(begTimeOrigin)
		result, err := method(user, workLineid, begTime)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateOneWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, *model.WorkLineSpecialTime) error) {

	RegisterOneWorkLineSpecialTime(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterMultiWorkLineSpecialTime(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.WorkLineSpecialTime) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.WorkLineSpecialTime, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, *[]model.WorkLineSpecialTime) error) {

	RegisterMultiWorkLineSpecialTime(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, *[]model.WorkLineSpecialTime) error) {

	RegisterMultiWorkLineSpecialTime(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateWorkLineSpecialTime
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条WorkLineSpecialTime的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateWorkLineSpecialTime(party router.Party, path string, method func(*models.Usertab, *[]model.WorkLineSpecialTime) error) {

	RegisterMultiWorkLineSpecialTime(party, "PUT", path, method)
}
