// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package base

import (
	model "LAPP_LF_MOM_BACKEND/models/base"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterOneWorkLineWorkShiftLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.WorkLineWorkShiftLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.WorkLineWorkShiftLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterIDOfWorkLineWorkShiftLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workLineId := ctx.Params().GetString("workLineId")
		workDay := ctx.Params().GetString("workDay")
		workShiftNr, err := ctx.Params().GetInt("workShiftNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, workLineId, workDay, workShiftNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterInsertOneWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, *model.WorkLineWorkShiftLst) error) {

	RegisterOneWorkLineWorkShiftLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterDeleteOneWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, string, string, int) error) {

	RegisterIDOfWorkLineWorkShiftLst(party, "DELETE", path+"/{workLineId:string}/{workDay:string}/{workShiftNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterSelectOneWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, string, string, int) (*model.WorkLineWorkShiftLst, error)) {

	party.Get(path+"/{workLineId:string}/{workDay:string}/{workShiftNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workLineId := ctx.Params().GetString("workLineId")
		workDay := ctx.Params().GetString("workDay")
		workShiftNr, err := ctx.Params().GetInt("workShiftNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, workLineId, workDay, workShiftNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterUpdateOneWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, *model.WorkLineWorkShiftLst) error) {

	RegisterOneWorkLineWorkShiftLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterMultiWorkLineWorkShiftLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.WorkLineWorkShiftLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.WorkLineWorkShiftLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterInsertWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, *[]model.WorkLineWorkShiftLst) error) {

	RegisterMultiWorkLineWorkShiftLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterDeleteWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, *[]model.WorkLineWorkShiftLst) error) {

	RegisterMultiWorkLineWorkShiftLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterSelectWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateWorkLineWorkShiftLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条WorkLineWorkShiftLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-22 16:03:30
 *
 ******************************************************************************/
func RegisterUpdateWorkLineWorkShiftLst(party router.Party, path string, method func(*models.Usertab, *[]model.WorkLineWorkShiftLst) error) {

	RegisterMultiWorkLineWorkShiftLst(party, "PUT", path, method)
}
