// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	model "LAPP_LF_MOM_BACKEND/models/log"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterOneArtDemandHeadCache(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArtDemandHeadCache) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtDemandHeadCache)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterIDOfArtDemandHeadCache(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		demandId := ctx.Params().GetString("demandId")

		err = method(user, artId, demandId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterInsertOneArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandHeadCache) error) {

	RegisterOneArtDemandHeadCache(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterDeleteOneArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfArtDemandHeadCache(party, "DELETE", path+"/{artId:string}/{demandId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterSelectOneArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, string, string) (*model.ArtDemandHeadCache, error)) {

	party.Get(path+"/{artId:string}/{demandId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		demandId := ctx.Params().GetString("demandId")
		result, err := method(user, artId, demandId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterUpdateOneArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandHeadCache) error) {

	RegisterOneArtDemandHeadCache(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterMultiArtDemandHeadCache(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArtDemandHeadCache) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArtDemandHeadCache, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterInsertArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandHeadCache) error) {

	RegisterMultiArtDemandHeadCache(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterDeleteArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandHeadCache) error) {

	RegisterMultiArtDemandHeadCache(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterSelectArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArtDemandHeadCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArtDemandHeadCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterUpdateArtDemandHeadCache(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandHeadCache) error) {

	RegisterMultiArtDemandHeadCache(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterExportArtDemandHeadCacheList
 *-----------------------------------------------------------------------------
 *
 * @Description              : 导出供应商需求明细报表
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-03-19
 *
 ******************************************************************************/
func RegisterExportArtDemandHeadCacheList(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}