// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	common "LAPP_LF_MOM_BACKEND/models/base"
	model "LAPP_LF_MOM_BACKEND/models/log"
	"LAPP_LF_MOM_BACKEND/utils"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterOneArtDemandLstCache(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArtDemandLstCache) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArtDemandLstCache)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterIDOfArtDemandLstCache(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		demandId := ctx.Params().GetString("demandId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, demandId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterInsertOneArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandLstCache) error) {

	RegisterOneArtDemandLstCache(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterDeleteOneArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, string, int) error) {

	RegisterIDOfArtDemandLstCache(party, "DELETE", path+"/{demandId:string}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterSelectOneArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, string, int) (*model.ArtDemandLstCache, error)) {

	party.Get(path+"/{demandId:string}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		demandId := ctx.Params().GetString("demandId")
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, demandId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterUpdateOneArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, *model.ArtDemandLstCache) error) {

	RegisterOneArtDemandLstCache(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterMultiArtDemandLstCache(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArtDemandLstCache) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArtDemandLstCache, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterInsertArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLstCache) error) {

	RegisterMultiArtDemandLstCache(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterDeleteArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLstCache) error) {

	RegisterMultiArtDemandLstCache(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterSelectArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArtDemandLstCache
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArtDemandLstCache的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-09 14:00:44
 *
 ******************************************************************************/
func RegisterUpdateArtDemandLstCache(party router.Party, path string, method func(*models.Usertab, *[]model.ArtDemandLstCache) error) {

	RegisterMultiArtDemandLstCache(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterSyncHronousData
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理多条RegisterUploadMustPic的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSyncHronousDataCache(party router.Party, httpMethod string, path string, method func(int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		plant := ctx.FormValue("plantNr")
		plantNr := utils.ValueToInt(plant,0)
		if utils.ValueIsEmpty(plantNr){
			plantNr = common.PlantNr
		}
		var err error = nil
		//获取通过iris.WithPostMaxMemory获取的最大上传值大小。
		maxSize := ctx.Application().ConfigurationReadOnly().GetPostMaxMemory()
		err = ctx.Request().ParseMultipartForm(maxSize)
		if err != nil {
			ctx.StatusCode(iris.StatusInternalServerError)
			ctx.WriteString(err.Error())
			return
		}

		file, info, err := ctx.FormFile("file")
		if err != nil {
			ctx.StatusCode(iris.StatusInternalServerError)
			ctx.HTML("Error while uploading: <b>" + err.Error() + "</b>")
			return
		}
		defer file.Close()
		if info.Size > maxSize {
			ctx.StatusCode(iris.StatusRequestEntityTooLarge)
			return
		}
		guid := utils.MakeOrderSn("SyncCache")
		savePath := "web/public/uploadxlsx/" + guid + ".xlsx"

		// 上传文件至指定目录
		err = utils.SaveUploadedFile(info, savePath)
		if err != nil {
			return
		}

		err = method(plantNr, savePath)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), "fail")
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, "success")
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSyncHronousData
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterInsertSyncHronousDataCache(party router.Party, path string, method func(int, string) error) {

	RegisterSyncHronousDataCache(party, "POST", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterExportArtDemandLstCacheList
 *-----------------------------------------------------------------------------
 *
 * @Description              : 导出供应商需求明细报表
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-07-06
 *
 ******************************************************************************/
func RegisterExportArtDemandLstCacheList(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}