// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	model "LAPP_LF_MOM_BACKEND/models/log"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOnePackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterOnePackTemplate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.PackTemplate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.PackTemplate)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfPackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterIDOfPackTemplate(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		packTemplateId := ctx.Params().GetString("packTemplateId")

		err = method(user, packTemplateId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOnePackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertOnePackTemplate(party router.Party, path string, method func(*models.Usertab, *model.PackTemplate) error) {

	RegisterOnePackTemplate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOnePackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteOnePackTemplate(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfPackTemplate(party, "DELETE", path+"/{packTemplateId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOnePackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectOnePackTemplate(party router.Party, path string, method func(*models.Usertab, string) (*model.PackTemplate, error)) {

	party.Get(path+"/{packTemplateId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		packTemplateId := ctx.Params().GetString("packTemplateId")
		result, err := method(user, packTemplateId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOnePackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateOnePackTemplate(party router.Party, path string, method func(*models.Usertab, *model.PackTemplate) error) {

	RegisterOnePackTemplate(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiPackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterMultiPackTemplate(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.PackTemplate) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.PackTemplate, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertPackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertPackTemplate(party router.Party, path string, method func(*models.Usertab, *[]model.PackTemplate) error) {

	RegisterMultiPackTemplate(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeletePackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeletePackTemplate(party router.Party, path string, method func(*models.Usertab, *[]model.PackTemplate) error) {

	RegisterMultiPackTemplate(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectPackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectPackTemplate(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdatePackTemplate
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条PackTemplate的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdatePackTemplate(party router.Party, path string, method func(*models.Usertab, *[]model.PackTemplate) error) {

	RegisterMultiPackTemplate(party, "PUT", path, method)
}
