// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	model "LAPP_LF_MOM_BACKEND/models/log"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterOneVendorArtLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.VendorArtLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.VendorArtLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterIDOfVendorArtLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		vendorId := ctx.Params().GetString("vendorId")
		artId := ctx.Params().GetString("artId")

		err = method(user, vendorId, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterInsertOneVendorArtLst(party router.Party, path string, method func(*models.Usertab, *model.VendorArtLst) error) {

	RegisterOneVendorArtLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterDeleteOneVendorArtLst(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfVendorArtLst(party, "DELETE", path+"/{vendorId:string}/{artId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterSelectOneVendorArtLst(party router.Party, path string, method func(*models.Usertab, string, string) (*model.VendorArtLst, error)) {

	party.Get(path+"/{vendorId:string}/{artId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		vendorId := ctx.Params().GetString("vendorId")
		artId := ctx.Params().GetString("artId")
		result, err := method(user, vendorId, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterUpdateOneVendorArtLst(party router.Party, path string, method func(*models.Usertab, *model.VendorArtLst) error) {

	RegisterOneVendorArtLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterMultiVendorArtLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.VendorArtLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.VendorArtLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterInsertVendorArtLst(party router.Party, path string, method func(*models.Usertab, *model.VendorArtLstInsert) error) {

	RegisterInsertVendorArtLstHandler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterDeleteVendorArtLst(party router.Party, path string, method func(*models.Usertab, *[]model.VendorArtLst) error) {

	RegisterMultiVendorArtLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterSelectVendorArtLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateVendorArtLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterUpdateVendorArtLst(party router.Party, path string, method func(*models.Usertab, *[]model.VendorArtLst) error) {

	RegisterMultiVendorArtLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertVendorArtLstHandler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个添加多条VendorArtLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-03-25
 *
 ******************************************************************************/
func RegisterInsertVendorArtLstHandler(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.VendorArtLstInsert) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}
		var req model.VendorArtLstInsert
		err := ctx.ReadJSON(&req)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &req)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

