// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package log

import (
	model "LAPP_LF_MOM_BACKEND/models/log"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterOneVendorUserLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.VendorUserLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.VendorUserLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterIDOfVendorUserLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		vendorId := ctx.Params().GetString("vendorId")
		userId := ctx.Params().GetString("userId")

		err = method(user, vendorId, userId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterInsertOneVendorUserLst(party router.Party, path string, method func(*models.Usertab, *model.VendorUserLst) error) {

	RegisterOneVendorUserLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterDeleteOneVendorUserLst(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfVendorUserLst(party, "DELETE", path+"/{vendorId:string}/{userId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterSelectOneVendorUserLst(party router.Party, path string, method func(*models.Usertab, string, string) (*model.VendorUserLst, error)) {

	party.Get(path+"/{vendorId:string}/{userId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		vendorId := ctx.Params().GetString("vendorId")
		userId := ctx.Params().GetString("userId")
		result, err := method(user, vendorId, userId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterUpdateOneVendorUserLst(party router.Party, path string, method func(*models.Usertab, *model.VendorUserLst) error) {

	RegisterOneVendorUserLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterMultiVendorUserLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.VendorUserLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.VendorUserLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterInsertVendorUserLst(party router.Party, path string, method func(*models.Usertab, *model.VendorUserLstInsert) error) {

	RegisterInsertVendorUserLstHandler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterDeleteVendorUserLst(party router.Party, path string, method func(*models.Usertab, *[]model.VendorUserLst) error) {

	RegisterMultiVendorUserLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterSelectVendorUserLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateVendorUserLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-25 10:13:02
 *
 ******************************************************************************/
func RegisterUpdateVendorUserLst(party router.Party, path string, method func(*models.Usertab, *[]model.VendorUserLst) error) {

	RegisterMultiVendorUserLst(party, "PUT", path, method)
}
/******************************************************************************
 *
 * @Function Name            : RegisterInsertVendorUserLstHandler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个添加多条VendorUserLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-03-25
 *
 ******************************************************************************/
func RegisterInsertVendorUserLstHandler(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.VendorUserLstInsert) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var req model.VendorUserLstInsert
		err := ctx.ReadJSON(&req)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &req)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}