// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package me

import (
	model "LAPP_LF_MOM_BACKEND/models/me"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterOneBomLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.BomLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.BomLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterIDOfBomLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		bomId := ctx.Params().GetString("bomId")
		fmatNr := ctx.Params().GetString("fmatNr")
		cmatNr := ctx.Params().GetString("cmatNr")

		err = method(user, bomId, fmatNr, cmatNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterInsertOneBomLst(party router.Party, path string, method func(*models.Usertab, *model.BomLst) error) {

	RegisterOneBomLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterDeleteOneBomLst(party router.Party, path string, method func(*models.Usertab, string, string, string) error) {

	RegisterIDOfBomLst(party, "DELETE", path+"/{bomId:string}/{fmatNr:string}/{cmatNr:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterSelectOneBomLst(party router.Party, path string, method func(*models.Usertab, string, string, string) (*model.BomLst, error)) {

	party.Get(path+"/{bomId:string}/{fmatNr:string}/{cmatNr:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		bomId := ctx.Params().GetString("bomId")
		fmatNr := ctx.Params().GetString("fmatNr")
		cmatNr := ctx.Params().GetString("cmatNr")
		result, err := method(user, bomId, fmatNr, cmatNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterUpdateOneBomLst(party router.Party, path string, method func(*models.Usertab, *model.BomLst) error) {

	RegisterOneBomLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterMultiBomLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.BomLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.BomLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterInsertBomLst(party router.Party, path string, method func(*models.Usertab, *[]model.BomLst) error) {

	RegisterMultiBomLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterDeleteBomLst(party router.Party, path string, method func(*models.Usertab, *[]model.BomLst) error) {

	RegisterMultiBomLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterSelectBomLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateBomLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条BomLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-09 14:13:50
 *
 ******************************************************************************/
func RegisterUpdateBomLst(party router.Party, path string, method func(*models.Usertab, *[]model.BomLst) error) {

	RegisterMultiBomLst(party, "PUT", path, method)
}
