// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package me

import (
	model "LAPP_LF_MOM_BACKEND/models/me"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterOneSetupMatrix(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.SetupMatrix) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.SetupMatrix)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterIDOfSetupMatrix(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		fromArtId := ctx.Params().GetString("fromArtId")
		toArtId := ctx.Params().GetString("toArtId")
		workLineId := ctx.Params().GetString("workLineId")

		err = method(user, fromArtId, toArtId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterInsertOneSetupMatrix(party router.Party, path string, method func(*models.Usertab, *model.SetupMatrix) error) {

	RegisterOneSetupMatrix(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterDeleteOneSetupMatrix(party router.Party, path string, method func(*models.Usertab, string, string, string) error) {

	RegisterIDOfSetupMatrix(party, "DELETE", path+"/{fromArtId:string}/{toArtId:string}/{workLineId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterSelectOneSetupMatrix(party router.Party, path string, method func(*models.Usertab, string, string, string) (*model.SetupMatrix, error)) {

	party.Get(path+"/{fromArtId:string}/{toArtId:string}/{workLineId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		fromArtId := ctx.Params().GetString("fromArtId")
		toArtId := ctx.Params().GetString("toArtId")
		workLineId := ctx.Params().GetString("workLineId")
		result, err := method(user, fromArtId, toArtId, workLineId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterUpdateOneSetupMatrix(party router.Party, path string, method func(*models.Usertab, *model.SetupMatrix) error) {

	RegisterOneSetupMatrix(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterMultiSetupMatrix(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.SetupMatrix) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.SetupMatrix, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterInsertSetupMatrix(party router.Party, path string, method func(*models.Usertab, *[]model.SetupMatrix) error) {

	RegisterMultiSetupMatrix(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterDeleteSetupMatrix(party router.Party, path string, method func(*models.Usertab, *[]model.SetupMatrix) error) {

	RegisterMultiSetupMatrix(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterSelectSetupMatrix(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateSetupMatrix
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条SetupMatrix的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-14 08:56:34
 *
 ******************************************************************************/
func RegisterUpdateSetupMatrix(party router.Party, path string, method func(*models.Usertab, *[]model.SetupMatrix) error) {

	RegisterMultiSetupMatrix(party, "PUT", path, method)
}
