// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package ods

import (
	model "LAPP_LF_MOM_BACKEND/models/ods"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterOneStationOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.StationOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.StationOrder)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterIDOfStationOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		station := ctx.Params().GetString("station")

		err = method(user, station)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterInsertOneStationOrder(party router.Party, path string, method func(*models.Usertab, *model.StationOrder) error) {

	RegisterOneStationOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterDeleteOneStationOrder(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfStationOrder(party, "DELETE", path+"/{station:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterSelectOneStationOrder(party router.Party, path string, method func(*models.Usertab, string) (*model.StationOrder, error)) {

	party.Get(path+"/{station:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		station := ctx.Params().GetString("station")
		result, err := method(user, station)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterUpdateOneStationOrder(party router.Party, path string, method func(*models.Usertab, *model.StationOrder) error) {

	RegisterOneStationOrder(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterMultiStationOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.StationOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.StationOrder, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterInsertStationOrder(party router.Party, path string, method func(*models.Usertab, *[]model.StationOrder) error) {

	RegisterMultiStationOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterDeleteStationOrder(party router.Party, path string, method func(*models.Usertab, *[]model.StationOrder) error) {

	RegisterMultiStationOrder(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterSelectStationOrder(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateStationOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条StationOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-18 11:12:43
 *
 ******************************************************************************/
func RegisterUpdateStationOrder(party router.Party, path string, method func(*models.Usertab, *[]model.StationOrder) error) {

	RegisterMultiStationOrder(party, "PUT", path, method)
}
