// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterOneDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.DemandLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.DemandLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterIDOfDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		fileNr, err := ctx.Params().GetInt("fileNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		taskNr, err := ctx.Params().GetInt("taskNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, fileNr, pos, taskNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterInsertOneDemandLst(party router.Party, path string, method func(*models.Usertab, *model.DemandLst) error) {

	RegisterOneDemandLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterDeleteOneDemandLst(party router.Party, path string, method func(*models.Usertab, int, int, int) error) {

	RegisterIDOfDemandLst(party, "DELETE", path+"/{fileNr:int}/{pos:int}/{taskNr:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterSelectOneDemandLst(party router.Party, path string, method func(*models.Usertab, int, int, int) (*model.DemandLst, error)) {

	party.Get(path+"/{fileNr:int}/{pos:int}/{taskNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		fileNr, err := ctx.Params().GetInt("fileNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		taskNr, err := ctx.Params().GetInt("taskNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, fileNr, pos, taskNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterUpdateOneDemandLst(party router.Party, path string, method func(*models.Usertab, *model.DemandLst) error) {

	RegisterOneDemandLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterMultiDemandLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.DemandLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.DemandLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterInsertDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.DemandLst) error) {

	RegisterMultiDemandLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterDeleteDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.DemandLst) error) {

	RegisterMultiDemandLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterSelectDemandLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateDemandLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条DemandLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-27 17:06:45
 *
 ******************************************************************************/
func RegisterUpdateDemandLst(party router.Party, path string, method func(*models.Usertab, *[]model.DemandLst) error) {

	RegisterMultiDemandLst(party, "PUT", path, method)
}
