// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterOneSerialOrderOPDetail(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.SerialOrderOPDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.SerialOrderOPDetail)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterIDOfSerialOrderOPDetail(party router.Party, httpMethod string, path string, method func(*models.Usertab, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		detailId, err := ctx.Params().GetInt("detailId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, detailId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterInsertOneSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderOPDetail) error) {

	RegisterOneSerialOrderOPDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterDeleteOneSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, int) error) {

	RegisterIDOfSerialOrderOPDetail(party, "DELETE", path+"/{detailId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterSelectOneSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, int) (*model.SerialOrderOPDetail, error)) {

	party.Get(path+"/{detailId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		detailId, err := ctx.Params().GetInt("detailId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, detailId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterUpdateOneSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderOPDetail) error) {

	RegisterOneSerialOrderOPDetail(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterMultiSerialOrderOPDetail(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.SerialOrderOPDetail) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.SerialOrderOPDetail, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterInsertSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderOPDetail) error) {

	RegisterMultiSerialOrderOPDetail(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterDeleteSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderOPDetail) error) {

	RegisterMultiSerialOrderOPDetail(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterSelectSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateSerialOrderOPDetail
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条SerialOrderOPDetail的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-08-11 10:00:53
 *
 ******************************************************************************/
func RegisterUpdateSerialOrderOPDetail(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderOPDetail) error) {

	RegisterMultiSerialOrderOPDetail(party, "PUT", path, method)
}
