// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterOneSerialOrderPOStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.SerialOrderPOStatusRecLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.SerialOrderPOStatusRecLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterIDOfSerialOrderPOStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		serialOrderId := ctx.Params().GetString("serialOrderId")
		pO, err := ctx.Params().GetInt("pO")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, serialOrderId, pO, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterInsertOneSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderPOStatusRecLst) error) {

	RegisterOneSerialOrderPOStatusRecLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterDeleteOneSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, string, int, int) error) {

	RegisterIDOfSerialOrderPOStatusRecLst(party, "DELETE", path+"/{serialOrderId:string}/{pO:int}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterSelectOneSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, string, int, int) (*model.SerialOrderPOStatusRecLst, error)) {

	party.Get(path+"/{serialOrderId:string}/{pO:int}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		serialOrderId := ctx.Params().GetString("serialOrderId")
		pO, err := ctx.Params().GetInt("pO")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, serialOrderId, pO, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterUpdateOneSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, *model.SerialOrderPOStatusRecLst) error) {

	RegisterOneSerialOrderPOStatusRecLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterMultiSerialOrderPOStatusRecLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.SerialOrderPOStatusRecLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.SerialOrderPOStatusRecLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterInsertSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderPOStatusRecLst) error) {

	RegisterMultiSerialOrderPOStatusRecLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterDeleteSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderPOStatusRecLst) error) {

	RegisterMultiSerialOrderPOStatusRecLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterSelectSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateSerialOrderPOStatusRecLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条SerialOrderPOStatusRecLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-29 17:19:37
 *
 ******************************************************************************/
func RegisterUpdateSerialOrderPOStatusRecLst(party router.Party, path string, method func(*models.Usertab, *[]model.SerialOrderPOStatusRecLst) error) {

	RegisterMultiSerialOrderPOStatusRecLst(party, "PUT", path, method)
}
