// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package om

import (
	model "LAPP_LF_MOM_BACKEND/models/om"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"errors"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterOneWorkOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.WorkOrderJoin) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.WorkOrderJoin)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterIDOfWorkOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		workOrderId := ctx.Params().GetString("workOrderId")

		err = method(user, workOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterInsertOneWorkOrder(party router.Party, path string, method func(*models.Usertab, *model.WorkOrderJoin) error) {

	RegisterOneWorkOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterDeleteOneWorkOrder(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfWorkOrder(party, "DELETE", path+"/{workOrderId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterSelectOneWorkOrder(party router.Party, path string, method func(*models.Usertab, string) (*model.WorkOrderJoin, error)) {

	party.Get(path+"/{workOrderId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		workOrderId := ctx.Params().GetString("workOrderId")
		result, err := method(user, workOrderId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterUpdateOneWorkOrder(party router.Party, path string, method func(*models.Usertab, *model.WorkOrderJoin) error) {

	RegisterOneWorkOrder(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterMultiWorkOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.WorkOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.WorkOrder, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterInsertWorkOrder(party router.Party, path string, method func(*models.Usertab, *[]model.WorkOrder) error) {

	RegisterMultiWorkOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterDeleteWorkOrder(party router.Party, path string, method func(*models.Usertab, *[]model.WorkOrder) error) {

	RegisterMultiWorkOrder(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterSelectWorkOrder(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-19 14:04:47
 *
 ******************************************************************************/
func RegisterUpdateWorkOrder(party router.Party, path string, method func(*models.Usertab, *[]model.WorkOrder) error) {

	RegisterMultiWorkOrder(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterRevocationWorkOrderHandler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个撤销WorkOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-04-30
 *
 ******************************************************************************/
func RegisterRevocationWorkOrderHandler(party router.Party, httpMethod string, path string, method func(*models.Usertab, []string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		var entities []string
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(&entities)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		}
		if len(entities) == 0 {
			supports.Error(ctx, iris.StatusBadRequest, "未获取到workOrderId", nil)
			return
		}
		err = method(user, entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterRevocationWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个撤销多条WorkOrderStatus的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-04-3-0
 *
 ******************************************************************************/
func RegisterRevocationWorkOrder(party router.Party, path string, method func(*models.Usertab, []string) error) {

	RegisterRevocationWorkOrderHandler(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterCancelWorkOrderHandler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个取消workOrder指定数量的的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-06-29
 *
 ******************************************************************************/
func RegisterCancelWorkOrderHandler(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, float64) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		var entities model.CancelWorkOrder
		if err = ctx.ReadJSON(&entities); err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		if entities.WorkOrderId == "" {
			supports.Error(ctx, iris.StatusBadRequest, errors.New("未获取到workOrderId").Error(), nil)
			return
		}
		if entities.Qty == 0 {
			supports.Error(ctx, iris.StatusBadRequest, errors.New("未获取到有效的qty").Error(), nil)
			return
		}
		err = method(user, entities.WorkOrderId, entities.Qty)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterCancelWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个取消workOrder指定数量的的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-06-29
 *
 ******************************************************************************/
func RegisterCancelWorkOrder(party router.Party, path string, method func(*models.Usertab, string, float64) error) {

	RegisterCancelWorkOrderHandler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterCreateWorkOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个创建WorkOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-08-03
 *
 ******************************************************************************/
func RegisterCreateWorkOrder(party router.Party, path string, method func(*models.Usertab, *model.CreateLockWorkOrder) error) {

	party.Handle("POST", path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.CreateLockWorkOrder)
		err = ctx.ReadJSON(entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if entity.ArtId == "" || entity.Qty == 0 {
			supports.Error(ctx, iris.StatusBadRequest, "创建订单参数错误", nil)
			return
		}
		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
