// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pdc

import (
	model "LAPP_LF_MOM_BACKEND/models/pdc"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterOneScrewDown(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ScrewDown) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ScrewDown)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterIDOfScrewDown(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int, bool) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		screwPos, err := ctx.Params().GetInt("screwPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := ctx.Params().GetBool("result")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, artId, screwPos, result)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterInsertOneScrewDown(party router.Party, path string, method func(*models.Usertab, *model.ScrewDown) error) {

	RegisterOneScrewDown(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterDeleteOneScrewDown(party router.Party, path string, method func(*models.Usertab, string, int, bool) error) {

	RegisterIDOfScrewDown(party, "DELETE", path+"/{artId:string}/{screwPos:int}/{result:bool}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterSelectOneScrewDown(party router.Party, path string, method func(*models.Usertab, string, int, bool) (*model.ScrewDown, error)) {

	party.Get(path+"/{artId:string}/{screwPos:int}/{result:bool}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		screwPos, err := ctx.Params().GetInt("screwPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := ctx.Params().GetBool("result")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		selectResult, err := method(user, artId, screwPos, result)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if selectResult == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterUpdateOneScrewDown(party router.Party, path string, method func(*models.Usertab, *model.ScrewDown) error) {

	RegisterOneScrewDown(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterMultiScrewDown(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ScrewDown) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ScrewDown, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterInsertScrewDown(party router.Party, path string, method func(*models.Usertab, *[]model.ScrewDown) error) {

	RegisterMultiScrewDown(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterDeleteScrewDown(party router.Party, path string, method func(*models.Usertab, *[]model.ScrewDown) error) {

	RegisterMultiScrewDown(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterSelectScrewDown(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-05-24 10:49:50
 *
 ******************************************************************************/
func RegisterUpdateScrewDown(party router.Party, path string, method func(*models.Usertab, *[]model.ScrewDown) error) {

	RegisterMultiScrewDown(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterSaveScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-05-28
 *
 ******************************************************************************/
func RegisterSaveScrewDown(party router.Party, httpMethod string, path string, method func(*models.Usertab, model.ScrewDownSave) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var saveScrewData model.ScrewDownSave
		err := ctx.ReadJSON(&saveScrewData)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, saveScrewData)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}


/******************************************************************************
 *
 * @Function Name            : RegisterSaveScrewDownHandler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个save多条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-05-28
 *
 ******************************************************************************/
func RegisterSaveScrewDownHandler(party router.Party, path string, method func(*models.Usertab, model.ScrewDownSave) error) {

	RegisterSaveScrewDown(party, "POST", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneScrewDown
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ScrewDown的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-05-28
 *
 ******************************************************************************/
func RegisterDeleteScrewDownByArtIdHandler(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterDeleteScrewDownByArtId(party, "DELETE", path+"/{artId:string}", method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterDeleteScrewDownByArtId
 *-----------------------------------------------------------------------------
 *
 * @Description              : 通过artId进行删除screw data
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : zhangxin
 *
 * @Date                     : 2021-05-28
 *
 ******************************************************************************/
func RegisterDeleteScrewDownByArtId(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")
		if artId == "" {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		err = method(user, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}