// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pm

import (
	model "LAPP_LF_MOM_BACKEND/models/pm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterOneAssetKpi(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.AssetKpi) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.AssetKpi)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterIDOfAssetKpi(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		assetNr, err := ctx.Params().GetInt("assetNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		kpi := ctx.Params().GetString("kpi")

		err = method(user, assetNr, kpi)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterInsertOneAssetKpi(party router.Party, path string, method func(*models.Usertab, *model.AssetKpi) error) {

	RegisterOneAssetKpi(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterDeleteOneAssetKpi(party router.Party, path string, method func(*models.Usertab, int, string) error) {

	RegisterIDOfAssetKpi(party, "DELETE", path+"/{assetNr:int}/{kpi:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterSelectOneAssetKpi(party router.Party, path string, method func(*models.Usertab, int, string) (*model.AssetKpi, error)) {

	party.Get(path+"/{assetNr:int}/{kpi:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		assetNr, err := ctx.Params().GetInt("assetNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		kpi := ctx.Params().GetString("kpi")
		result, err := method(user, assetNr, kpi)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterUpdateOneAssetKpi(party router.Party, path string, method func(*models.Usertab, *model.AssetKpi) error) {

	RegisterOneAssetKpi(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterMultiAssetKpi(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.AssetKpi) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.AssetKpi, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterInsertAssetKpi(party router.Party, path string, method func(*models.Usertab, *[]model.AssetKpi) error) {

	RegisterMultiAssetKpi(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterDeleteAssetKpi(party router.Party, path string, method func(*models.Usertab, *[]model.AssetKpi) error) {

	RegisterMultiAssetKpi(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterSelectAssetKpi(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateAssetKpi
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条AssetKpi的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterUpdateAssetKpi(party router.Party, path string, method func(*models.Usertab, *[]model.AssetKpi) error) {

	RegisterMultiAssetKpi(party, "PUT", path, method)
}
