// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pm

import (
	model "LAPP_LF_MOM_BACKEND/models/pm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterOneAttributeValst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.AttributeValst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.AttributeValst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterIDOfAttributeValst(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		attrNr, err := ctx.Params().GetInt("attrNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, attrNr, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterInsertOneAttributeValst(party router.Party, path string, method func(*models.Usertab, *model.AttributeValst) error) {

	RegisterOneAttributeValst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterDeleteOneAttributeValst(party router.Party, path string, method func(*models.Usertab, int, int) error) {

	RegisterIDOfAttributeValst(party, "DELETE", path+"/{attrNr:int}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterSelectOneAttributeValst(party router.Party, path string, method func(*models.Usertab, int, int) (*model.AttributeValst, error)) {

	party.Get(path+"/{attrNr:int}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		attrNr, err := ctx.Params().GetInt("attrNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, attrNr, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterUpdateOneAttributeValst(party router.Party, path string, method func(*models.Usertab, *model.AttributeValst) error) {

	RegisterOneAttributeValst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterMultiAttributeValst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.AttributeValst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.AttributeValst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterInsertAttributeValst(party router.Party, path string, method func(*models.Usertab, *[]model.AttributeValst) error) {

	RegisterMultiAttributeValst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterDeleteAttributeValst(party router.Party, path string, method func(*models.Usertab, *[]model.AttributeValst) error) {

	RegisterMultiAttributeValst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterSelectAttributeValst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateAttributeValst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条AttributeValst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-04-13 11:00:13
 *
 ******************************************************************************/
func RegisterUpdateAttributeValst(party router.Party, path string, method func(*models.Usertab, *[]model.AttributeValst) error) {

	RegisterMultiAttributeValst(party, "PUT", path, method)
}
