// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package pm

import (
	model "LAPP_LF_MOM_BACKEND/models/pm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"encoding/json"
	"fmt"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterOneUserAssetLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.UserAssetLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.UserAssetLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterIDOfUserAssetLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		userId := ctx.Params().GetString("userId")
		assetId, err := ctx.Params().GetInt("assetId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, userId, assetId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterInsertOneUserAssetLst(party router.Party, path string, method func(*models.Usertab, *model.UserAssetLst) error) {

	RegisterOneUserAssetLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterDeleteOneUserAssetLst(party router.Party, path string, method func(*models.Usertab, string, int) error) {

	RegisterIDOfUserAssetLst(party, "DELETE", path+"/{userId:string}/{assetId:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterSelectOneUserAssetLst(party router.Party, path string, method func(*models.Usertab, string, int) (*model.UserAssetLst, error)) {

	party.Get(path+"/{userId:string}/{assetId:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		userId := ctx.Params().GetString("userId")
		assetId, err := ctx.Params().GetInt("assetId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, userId, assetId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterUpdateOneUserAssetLst(party router.Party, path string, method func(*models.Usertab, *model.UserAssetLst) error) {

	RegisterOneUserAssetLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterMultiUserAssetLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.UserAssetLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.UserAssetLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterInsertUserAssetLst(party router.Party, path string, method func(*models.Usertab, *model.UserAssetLstInsert) error) {

	RegisterInsertUserAssetLstHandler(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterDeleteUserAssetLst(party router.Party, path string, method func(*models.Usertab, *[]model.UserAssetLst) error) {

	RegisterMultiUserAssetLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterSelectUserAssetLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateUserAssetLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:50:49
 *
 ******************************************************************************/
func RegisterUpdateUserAssetLst(party router.Party, path string, method func(*models.Usertab, *[]model.UserAssetLst) error) {

	RegisterMultiUserAssetLst(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterInsertUserAssetLstHandler
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个添加多条UserAssetLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 张鑫
 *
 * @Date                     : 2021-04-08
 *
 ******************************************************************************/
func RegisterInsertUserAssetLstHandler(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.UserAssetLstInsert) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var entities model.UserAssetLstInsert
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		data, _ := json.Marshal(entities)
		fmt.Println("entities:", string(data))
		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}
