// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package qm

import (
	model "LAPP_LF_MOM_BACKEND/models/qm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterOneReclinerReclst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ReclinerReclst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ReclinerReclst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterIDOfReclinerReclst(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		recNr, err := ctx.Params().GetInt("recNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		line := ctx.Params().GetString("line")

		err = method(user, recNr, line)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterInsertOneReclinerReclst(party router.Party, path string, method func(*models.Usertab, *model.ReclinerReclst) error) {

	RegisterOneReclinerReclst(party, "POST", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterAddPrinterInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterAddPrinterInfo(party router.Party, path string, method func(*models.Usertab, *model.ReclinerReclst) error) {

	RegisterOneReclinerReclst(party, "POST", path, method)
}
/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterDeleteOneReclinerReclst(party router.Party, path string, method func(*models.Usertab, int, string) error) {

	RegisterIDOfReclinerReclst(party, "DELETE", path+"/{recNr:int}/{line:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterSelectOneReclinerReclst(party router.Party, path string, method func(*models.Usertab, int) (*model.ReclinerReclst, error)) {

	party.Get(path+"/{recNr:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		recNr, err := ctx.Params().GetInt("recNr")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, recNr)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterUpdateOneReclinerReclst(party router.Party, path string, method func(*models.Usertab, *model.ReclinerReclst) error) {

	RegisterOneReclinerReclst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterMultiReclinerReclst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ReclinerReclst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ReclinerReclst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterInsertReclinerReclst(party router.Party, path string, method func(*models.Usertab, *[]model.ReclinerReclst) error) {

	RegisterMultiReclinerReclst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterDeleteReclinerReclst(party router.Party, path string, method func(*models.Usertab, *[]model.ReclinerReclst) error) {

	RegisterMultiReclinerReclst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterSelectReclinerReclst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateReclinerReclst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ReclinerReclst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-12 14:05:20
 *
 ******************************************************************************/
func RegisterUpdateReclinerReclst(party router.Party, path string, method func(*models.Usertab, *[]model.ReclinerReclst) error) {

	RegisterMultiReclinerReclst(party, "PUT", path, method)
}
