// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package qm

import (
	model "LAPP_LF_MOM_BACKEND/models/qm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterOneViewDefectGrplst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ViewDefectGrplst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ViewDefectGrplst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterIDOfViewDefectGrplst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		viewId := ctx.Params().GetString("viewId")
		defectGrpId := ctx.Params().GetString("defectGrpId")

		err = method(user, viewId, defectGrpId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertOneViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, *model.ViewDefectGrplst) error) {

	RegisterOneViewDefectGrplst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteOneViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfViewDefectGrplst(party, "DELETE", path+"/{viewId:string}/{defectGrpId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectOneViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, string, string) (*model.ViewDefectGrplst, error)) {

	party.Get(path+"/{viewId:string}/{defectGrpId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		viewId := ctx.Params().GetString("viewId")
		defectGrpId := ctx.Params().GetString("defectGrpId")
		result, err := method(user, viewId, defectGrpId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateOneViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, *model.ViewDefectGrplst) error) {

	RegisterOneViewDefectGrplst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterMultiViewDefectGrplst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ViewDefectGrplst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ViewDefectGrplst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterInsertViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, *[]model.ViewDefectGrplst) error) {

	RegisterMultiViewDefectGrplst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterDeleteViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, *[]model.ViewDefectGrplst) error) {

	RegisterMultiViewDefectGrplst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterSelectViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateViewDefectGrplst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ViewDefectGrplst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-03-18 22:49:12
 *
 ******************************************************************************/
func RegisterUpdateViewDefectGrplst(party router.Party, path string, method func(*models.Usertab, *[]model.ViewDefectGrplst) error) {

	RegisterMultiViewDefectGrplst(party, "PUT", path, method)
}
