// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package report

import (
	model "LAPP_LF_MOM_BACKEND/models/report"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterOneArcDisplayInfo(party router.Party, httpMethod string, path string, method func(*model.ArcDisplayInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {

		var err error = nil

		entity := new(model.ArcDisplayInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterIDOfArcDisplayInfo(party router.Party, httpMethod string, path string, method func(int, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {

		var err error = nil
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		descCN := ctx.Params().GetString("descCN")

		err = method(pos, descCN)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterInsertOneArcDisplayInfo(party router.Party, path string, method func(*model.ArcDisplayInfo) error) {

	RegisterOneArcDisplayInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterDeleteOneArcDisplayInfo(party router.Party, path string, method func(int, string) error) {

	RegisterIDOfArcDisplayInfo(party, "DELETE", path+"/{pos:int}/{descCN:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterSelectOneArcDisplayInfo(party router.Party, path string, method func(int, string) (*model.ArcDisplayInfo, error)) {

	party.Get(path+"/{pos:int}/{descCN:string}", func(ctx iris.Context) {

		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		descCN := ctx.Params().GetString("descCN")
		result, err := method(pos, descCN)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterUpdateOneArcDisplayInfo(party router.Party, path string, method func(*model.ArcDisplayInfo) error) {

	RegisterOneArcDisplayInfo(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterMultiArcDisplayInfo(party router.Party, httpMethod string, path string, method func(*[]model.ArcDisplayInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		entities := make([]model.ArcDisplayInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterInsertArcDisplayInfo(party router.Party, path string, method func(*[]model.ArcDisplayInfo) error) {

	RegisterMultiArcDisplayInfo(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterDeleteArcDisplayInfo(party router.Party, path string, method func(*[]model.ArcDisplayInfo) error) {

	RegisterMultiArcDisplayInfo(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterSelectArcDisplayInfo(party router.Party, path string, method func(map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {

		result, err := method(ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArcDisplayInfo
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArcDisplayInfo的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-21 11:39:48
 *
 ******************************************************************************/
func RegisterUpdateArcDisplayInfo(party router.Party, path string, method func(*[]model.ArcDisplayInfo) error) {

	RegisterMultiArcDisplayInfo(party, "PUT", path, method)
}
