// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package report

import (
	model "LAPP_LF_MOM_BACKEND/models/report"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterOneDisplayParam(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.DisplayParam) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.DisplayParam)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterIDOfDisplayParam(party router.Party, httpMethod string, path string, method func(*models.Usertab, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		displayId, err := ctx.Params().GetInt("displayId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, displayId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterInsertOneDisplayParam(party router.Party, path string, method func(*models.Usertab, *model.DisplayParam) error) {

	RegisterOneDisplayParam(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterDeleteOneDisplayParam(party router.Party, path string, method func(*models.Usertab, int, int) error) {

	RegisterIDOfDisplayParam(party, "DELETE", path+"/{displayId:int}/{pos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterSelectOneDisplayParam(party router.Party, path string, method func(*models.Usertab, int, int) (*model.DisplayParam, error)) {

	party.Get(path+"/{displayId:int}/{pos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		displayId, err := ctx.Params().GetInt("displayId")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		pos, err := ctx.Params().GetInt("pos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, displayId, pos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterUpdateOneDisplayParam(party router.Party, path string, method func(*models.Usertab, *model.DisplayParam) error) {

	RegisterOneDisplayParam(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterMultiDisplayParam(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.DisplayParam) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.DisplayParam, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterInsertDisplayParam(party router.Party, path string, method func(*models.Usertab, *[]model.DisplayParam) error) {

	RegisterMultiDisplayParam(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterDeleteDisplayParam(party router.Party, path string, method func(*models.Usertab, *[]model.DisplayParam) error) {

	RegisterMultiDisplayParam(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterSelectDisplayParam(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateDisplayParam
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条DisplayParam的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-24 15:31:29
 *
 ******************************************************************************/
func RegisterUpdateDisplayParam(party router.Party, path string, method func(*models.Usertab, *[]model.DisplayParam) error) {

	RegisterMultiDisplayParam(party, "PUT", path, method)
}
