// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package report

import (
	model "LAPP_LF_MOM_BACKEND/models/report"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
*
* @Function Name            : RegisterOneFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个处理单条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : HTTP方法
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterOneFilterDataInfo(party router.Party, httpMethod string, path string, method func(*model.FilterDataInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {

		var err error = nil

		entity := new(model.FilterDataInfo)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
*
* @Function Name            : RegisterIDOfFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个通过主键处理单条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : HTTP方法
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterIDOfFilterDataInfo(party router.Party, httpMethod string, path string, method func() error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {

		var err error = nil

		err = method()
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
*
* @Function Name            : RegisterInsertOneFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个插入单条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterInsertOneFilterDataInfo(party router.Party, path string, method func(*model.FilterDataInfo) error) {

	RegisterOneFilterDataInfo(party, "POST", path, method)
}

/******************************************************************************
*
* @Function Name            : RegisterDeleteOneFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个删除单条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterDeleteOneFilterDataInfo(party router.Party, path string, method func() error) {

	RegisterIDOfFilterDataInfo(party, "DELETE", path+"", method)
}

/******************************************************************************
*
* @Function Name            : RegisterSelectOneFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个查找单条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterSelectOneFilterDataInfo(party router.Party, path string, method func() (*model.FilterDataInfo, error)) {

	party.Get(path+"", func(ctx iris.Context) {
		result, err := method()
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
*
* @Function Name            : RegisterUpdateOneFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个修改单条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterUpdateOneFilterDataInfo(party router.Party, path string, method func(*model.FilterDataInfo) error) {

	RegisterOneFilterDataInfo(party, "PUT", path, method)
}

/******************************************************************************
*
* @Function Name            : RegisterMultiFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个处理多条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : HTTP方法
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterMultiFilterDataInfo(party router.Party, httpMethod string, path string, method func(*[]model.FilterDataInfo) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		entities := make([]model.FilterDataInfo, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
*
* @Function Name            : RegisterInsertFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个插入多条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterInsertFilterDataInfo(party router.Party, path string, method func(*[]model.FilterDataInfo) error) {

	RegisterMultiFilterDataInfo(party, "POST", path, method)
}

/******************************************************************************
*
* @Function Name            : RegisterDeleteFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个删除多条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterDeleteFilterDataInfo(party router.Party, path string, method func(*[]model.FilterDataInfo) error) {

	RegisterMultiFilterDataInfo(party, "DELETE", path, method)
}

/******************************************************************************
*
* @Function Name            : RegisterSelectFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个查询FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterSelectFilterDataInfo(party router.Party, path string, method func(map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		result, err := method(ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
*
* @Function Name            : RegisterUpdateFilterDataInfo
*-----------------------------------------------------------------------------
*
* @Description              : 为一个修改多条FilterDataInfo的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : 代码生成器创建
*
* @Date                     : 2021-06-21 09:55:32
*
******************************************************************************/
func RegisterUpdateFilterDataInfo(party router.Party, path string, method func(*[]model.FilterDataInfo) error) {

	RegisterMultiFilterDataInfo(party, "PUT", path, method)
}


/******************************************************************************
*
* @Function Name            : RegisterGetArcDisplayData
*-----------------------------------------------------------------------------
*
* @Description              : 为一个获取弧焊机展示统计数据的方法注册路由
*
* @Function Parameters      : 路由分组
*
* @Function Parameters      : 路径
*
* @Function Parameters      : 实际处理请求的方法
*
* @Author                   : zhangxin
*
* @Date                     : 2021-06-21
*
******************************************************************************/
func RegisterGetArcDisplayData(party router.Party, path string, method func() ([]model.AWMDisplay, error)) {

	party.Get(path, func(ctx iris.Context) {
		result, err := method()
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}