package controllers

import (
	"LAPP_LF_MOM_BACKEND/utils"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"time"
)

func GetSnrtabList(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Snrtab_controller.go"
	logs.Level = "info"
	logs.Function = "GetSnrtabList"
	logs.Message = "订单流水号查看"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	var data models.Snrtab
	var err error
	var pageSize = 10
	var pageIndex = 1

	if size := ctx.URLParam("pageSize"); size != "" {
		pageSize = utils.ValueToInt(size, 0)
	}

	if index := ctx.URLParam("pageIndex"); index != "" {
		pageIndex = utils.ValueToInt(index, 0)
	}
	data.Finr = user.Pid
	data.Snrid = ctx.URLParam("snrid")
	result, count, err := data.GetPage(pageSize, pageIndex)
	if err != nil {
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	res := make(map[string]interface{})
	res["data"] = result
	res["count"] = count
	res["pageIndex"] = pageIndex
	res["pageSize"] = pageSize
	supports.Ok(ctx, supports.OptionSuccess, res)
}

func GetSnrtab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	var me models.Snrtab
	snrid:= ctx.URLParam("snrid")
	me.Finr = user.Pid
	me.Snrid = snrid
	result, err := me.SelectOne()
	if err !=nil{
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	result.Clipped()
	supports.Ok(ctx, supports.OptionSuccess, result)
}

func InsertSnrtab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Snrtab_controller.go"
	logs.Level = "info"
	logs.Function = "InsertSnrtab"
	logs.Message = "添加生产线"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	data := new(models.Snrtab)
	data.Finr = user.Pid
	data.Lastuser = user.Userid
	data.Credatuz = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	data.Lastmodif = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	data.Lastnrcreate = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	if err := ctx.ReadJSON(data); err != nil {
		logs := new(models.LeitServerLog)
		logs.File = "/controllers/Snrtab_controller.go"
		logs.Level = "debug"
		logs.Function = "InsertSnrtab"
		logs.Message = error.Error(err)
		logs.Operator = user.Userid
		logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
		logs.InsertRecord()
		supports.Error(ctx, iris.StatusBadRequest, "json解析错误", nil)
		return
	}
	err := data.Add()
	if err != nil{
		supports.Error(ctx, iris.StatusBadRequest,"添加失败！error: " + err.Error(), nil)
		return
	}
	supports.Ok(ctx, supports.OptionSuccess, data)
}

func UpdateSnrtab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Snrtab_controller.go"
	logs.Level = "info"
	logs.Function = "UpdateSnrtab"
	logs.Message = "更新订单流水号"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	data := new(models.Snrtab)
	if err := ctx.ReadJSON(data); err != nil {
		supports.Error(ctx, iris.StatusBadRequest, "抱歉未找到相关信息", nil)
		return
	}
	data.Lastuser = user.Userid
	res:= data.Update()
	if !res{
		supports.Error(ctx, iris.StatusBadRequest, "更新失败", nil)
		return
	}

	supports.Ok(ctx, "修改成功", "")
}

func DeleteSnrtab(ctx iris.Context) {
	user, ok := jwts.ParseToken(ctx)
	utils.TrimStruct(user,*user)
	if !ok {
		supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
		return
	}
	//日志
	logs := new(models.LeitServerLog)
	logs.File = "/controllers/Snrtab_controller.go"
	logs.Level = "info"
	logs.Function = "DeleteSnrtab"
	logs.Message = "删除订单流水号"
	logs.Operator = user.Userid
	logs.TimeStamp = utils.TimeFormat(time.Now(),"yyyyMMddHHmmss")
	logs.InsertRecord()
	me:=new(models.Snrtab)
	snrid:= ctx.URLParam("snrid")
	me.Finr = user.Pid
	me.Snrid = snrid
	res := me.Del()
	if !res {
		supports.Error(ctx, iris.StatusBadRequest, "删除失败", nil)
		return
	}
	supports.Ok(ctx, "删除成功", "")
}
