// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterOneArticleReplenish(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ArticleReplenish) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ArticleReplenish)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterIDOfArticleReplenish(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		artId := ctx.Params().GetString("artId")

		err = method(user, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertOneArticleReplenish(party router.Party, path string, method func(*models.Usertab, *model.ArticleReplenish) error) {

	RegisterOneArticleReplenish(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteOneArticleReplenish(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfArticleReplenish(party, "DELETE", path+"/{artId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectOneArticleReplenish(party router.Party, path string, method func(*models.Usertab, string) (*model.ArticleReplenish, error)) {

	party.Get(path+"/{artId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		artId := ctx.Params().GetString("artId")
		result, err := method(user, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateOneArticleReplenish(party router.Party, path string, method func(*models.Usertab, *model.ArticleReplenish) error) {

	RegisterOneArticleReplenish(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterMultiArticleReplenish(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ArticleReplenish) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ArticleReplenish, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertArticleReplenish(party router.Party, path string, method func(*models.Usertab, *[]model.ArticleReplenish) error) {

	RegisterMultiArticleReplenish(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteArticleReplenish(party router.Party, path string, method func(*models.Usertab, *[]model.ArticleReplenish) error) {

	RegisterMultiArticleReplenish(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectArticleReplenish(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateArticleReplenish
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ArticleReplenish的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateArticleReplenish(party router.Party, path string, method func(*models.Usertab, *[]model.ArticleReplenish) error) {

	RegisterMultiArticleReplenish(party, "PUT", path, method)
}
