// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterOneClient(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.Client) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.Client)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterIDOfClient(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		clientId := ctx.Params().GetString("clientId")

		err = method(user, clientId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterInsertOneClient(party router.Party, path string, method func(*models.Usertab, *model.Client) error) {

	RegisterOneClient(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterDeleteOneClient(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfClient(party, "DELETE", path+"/{clientId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterSelectOneClient(party router.Party, path string, method func(*models.Usertab, string) (*model.Client, error)) {

	party.Get(path+"/{clientId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		clientId := ctx.Params().GetString("clientId")
		result, err := method(user, clientId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterUpdateOneClient(party router.Party, path string, method func(*models.Usertab, *model.Client) error) {

	RegisterOneClient(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterMultiClient(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.Client) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.Client, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterInsertClient(party router.Party, path string, method func(*models.Usertab, *[]model.Client) error) {

	RegisterMultiClient(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterDeleteClient(party router.Party, path string, method func(*models.Usertab, *[]model.Client) error) {

	RegisterMultiClient(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterSelectClient(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateClient
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条Client的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-21 11:04:46
 *
 ******************************************************************************/
func RegisterUpdateClient(party router.Party, path string, method func(*models.Usertab, *[]model.Client) error) {

	RegisterMultiClient(party, "PUT", path, method)
}
