// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterOneGoodsIssueHead(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.GoodsIssueHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.GoodsIssueHead)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterIDOfGoodsIssueHead(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		goodsIssueId := ctx.Params().GetString("goodsIssueId")

		err = method(user, goodsIssueId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertOneGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, *model.GoodsIssueHead) error) {

	RegisterOneGoodsIssueHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteOneGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfGoodsIssueHead(party, "DELETE", path+"/{goodsIssueId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectOneGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, string) (*model.GoodsIssueHead, error)) {

	party.Get(path+"/{goodsIssueId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		goodsIssueId := ctx.Params().GetString("goodsIssueId")
		result, err := method(user, goodsIssueId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateOneGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, *model.GoodsIssueHead) error) {

	RegisterOneGoodsIssueHead(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterMultiGoodsIssueHead(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.GoodsIssueHead) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.GoodsIssueHead, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, *[]model.GoodsIssueHead) error) {

	RegisterMultiGoodsIssueHead(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, *[]model.GoodsIssueHead) error) {

	RegisterMultiGoodsIssueHead(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条GoodsIssueHead的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, *[]model.GoodsIssueHead) error) {

	RegisterMultiGoodsIssueHead(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterExportGoodsIssueHead
 *-----------------------------------------------------------------------------
 *
 * @Description              : 导出excel
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 徐腾飞
 *
 * @Date                     : 2021-07-19
 *
 ******************************************************************************/
func RegisterExportGoodsIssueHead(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

