// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterOneInventoryBook(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.InventoryBook) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.InventoryBook)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterIDOfInventoryBook(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		storageBinId := ctx.Params().GetString("storageBinId")
		warehouseId := ctx.Params().GetString("warehouseId")
		artId := ctx.Params().GetString("artId")

		err = method(user, storageBinId, warehouseId, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertOneInventoryBook(party router.Party, path string, method func(*models.Usertab, *model.InventoryBook) error) {

	RegisterOneInventoryBook(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteOneInventoryBook(party router.Party, path string, method func(*models.Usertab, string, string, string) error) {

	RegisterIDOfInventoryBook(party, "DELETE", path+"/{storageBinId:string}/{warehouseId:string}/{artId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectOneInventoryBook(party router.Party, path string, method func(*models.Usertab, string, string, string) (*model.InventoryBook, error)) {

	party.Get(path+"/{storageBinId:string}/{warehouseId:string}/{artId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		storageBinId := ctx.Params().GetString("storageBinId")
		warehouseId := ctx.Params().GetString("warehouseId")
		artId := ctx.Params().GetString("artId")
		result, err := method(user, storageBinId, warehouseId, artId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateOneInventoryBook(party router.Party, path string, method func(*models.Usertab, *model.InventoryBook) error) {

	RegisterOneInventoryBook(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterMultiInventoryBook(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.InventoryBook) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.InventoryBook, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertInventoryBook(party router.Party, path string, method func(*models.Usertab, *[]model.InventoryBook) error) {

	RegisterMultiInventoryBook(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteInventoryBook(party router.Party, path string, method func(*models.Usertab, *[]model.InventoryBook) error) {

	RegisterMultiInventoryBook(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectInventoryBook(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条InventoryBook的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateInventoryBook(party router.Party, path string, method func(*models.Usertab, *[]model.InventoryBook) error) {

	RegisterMultiInventoryBook(party, "PUT", path, method)
}


/******************************************************************************
 *
 * @Function Name            : RegisterExportInventoryBook
 *-----------------------------------------------------------------------------
 *
 * @Description              : 导出excel
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 徐腾飞
 *
 * @Date                     : 2021-07-19
 *
 ******************************************************************************/
func RegisterExportInventoryBook(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

