// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterOneInventoryCheckLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.InventoryCheckLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.InventoryCheckLst)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterIDOfInventoryCheckLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, int, int) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		inventoryCheckId := ctx.Params().GetString("inventoryCheckId")
		iCDPos, err := ctx.Params().GetInt("iCDPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		iCLPos, err := ctx.Params().GetInt("iCLPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, inventoryCheckId, iCDPos, iCLPos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterInsertOneInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, *model.InventoryCheckLst) error) {

	RegisterOneInventoryCheckLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterDeleteOneInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, string, int, int) error) {

	RegisterIDOfInventoryCheckLst(party, "DELETE", path+"/{inventoryCheckId:string}/{iCDPos:int}/{iCLPos:int}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterSelectOneInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, string, int, int) (*model.InventoryCheckLst, error)) {

	party.Get(path+"/{inventoryCheckId:string}/{iCDPos:int}/{iCLPos:int}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		inventoryCheckId := ctx.Params().GetString("inventoryCheckId")
		iCDPos, err := ctx.Params().GetInt("iCDPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		iCLPos, err := ctx.Params().GetInt("iCLPos")
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		result, err := method(user, inventoryCheckId, iCDPos, iCLPos)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterUpdateOneInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, *model.InventoryCheckLst) error) {

	RegisterOneInventoryCheckLst(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterMultiInventoryCheckLst(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.InventoryCheckLst) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.InventoryCheckLst, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterInsertInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, *[]model.InventoryCheckLst) error) {

	RegisterMultiInventoryCheckLst(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterDeleteInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, *[]model.InventoryCheckLst) error) {

	RegisterMultiInventoryCheckLst(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterSelectInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateInventoryCheckLst
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条InventoryCheckLst的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 10:08:33
 *
 ******************************************************************************/
func RegisterUpdateInventoryCheckLst(party router.Party, path string, method func(*models.Usertab, *[]model.InventoryCheckLst) error) {

	RegisterMultiInventoryCheckLst(party, "PUT", path, method)
}
