// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterOneReplenishOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.ReplenishOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.ReplenishOrder)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterIDOfReplenishOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		replenishId := ctx.Params().GetString("replenishId")

		err = method(user, replenishId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterInsertOneReplenishOrder(party router.Party, path string, method func(*models.Usertab, *model.ReplenishOrder) error) {

	RegisterOneReplenishOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterDeleteOneReplenishOrder(party router.Party, path string, method func(*models.Usertab, string) error) {

	RegisterIDOfReplenishOrder(party, "DELETE", path+"/{replenishId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterSelectOneReplenishOrder(party router.Party, path string, method func(*models.Usertab, string) (*model.ReplenishOrder, error)) {

	party.Get(path+"/{replenishId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		replenishId := ctx.Params().GetString("replenishId")
		result, err := method(user, replenishId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterUpdateOneReplenishOrder(party router.Party, path string, method func(*models.Usertab, *model.ReplenishOrder) error) {

	RegisterOneReplenishOrder(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterMultiReplenishOrder(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.ReplenishOrder) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.ReplenishOrder, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterInsertReplenishOrder(party router.Party, path string, method func(*models.Usertab, *[]model.ReplenishOrder) error) {

	RegisterMultiReplenishOrder(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterDeleteReplenishOrder(party router.Party, path string, method func(*models.Usertab, *[]model.ReplenishOrder) error) {

	RegisterMultiReplenishOrder(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterSelectReplenishOrder(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateReplenishOrder
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条ReplenishOrder的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 16:17:08
 *
 ******************************************************************************/
func RegisterUpdateReplenishOrder(party router.Party, path string, method func(*models.Usertab, *[]model.ReplenishOrder) error) {

	RegisterMultiReplenishOrder(party, "PUT", path, method)
}
