// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterOneStorageArea(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.StorageArea) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.StorageArea)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterIDOfStorageArea(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		storageAreaId := ctx.Params().GetString("storageAreaId")
		warehouseId := ctx.Params().GetString("warehouseId")

		err = method(user, storageAreaId, warehouseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertOneStorageArea(party router.Party, path string, method func(*models.Usertab, *model.StorageArea) error) {

	RegisterOneStorageArea(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteOneStorageArea(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfStorageArea(party, "DELETE", path+"/{storageAreaId:string}/{warehouseId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectOneStorageArea(party router.Party, path string, method func(*models.Usertab, string, string) (*model.StorageArea, error)) {

	party.Get(path+"/{storageAreaId:string}/{warehouseId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		storageAreaId := ctx.Params().GetString("storageAreaId")
		warehouseId := ctx.Params().GetString("warehouseId")
		result, err := method(user, storageAreaId, warehouseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateOneStorageArea(party router.Party, path string, method func(*models.Usertab, *model.StorageArea) error) {

	RegisterOneStorageArea(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterMultiStorageArea(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.StorageArea) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.StorageArea, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterInsertStorageArea(party router.Party, path string, method func(*models.Usertab, *[]model.StorageArea) error) {

	RegisterMultiStorageArea(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterDeleteStorageArea(party router.Party, path string, method func(*models.Usertab, *[]model.StorageArea) error) {

	RegisterMultiStorageArea(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterSelectStorageArea(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateStorageArea
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条StorageArea的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-06-29 10:57:04
 *
 ******************************************************************************/
func RegisterUpdateStorageArea(party router.Party, path string, method func(*models.Usertab, *[]model.StorageArea) error) {

	RegisterMultiStorageArea(party, "PUT", path, method)
}
