// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package wm

import (
	model "LAPP_LF_MOM_BACKEND/models/wm"
	"LAPP_LF_MOM_BACKEND/web/middleware/jwts"
	"LAPP_LF_MOM_BACKEND/web/models"
	"LAPP_LF_MOM_BACKEND/web/supports"
	"github.com/kataras/iris/v12"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Function Name            : RegisterOneStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理单条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterOneStorageBin(party router.Party, httpMethod string, path string, method func(*models.Usertab, *model.StorageBin) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil

		entity := new(model.StorageBin)
		if ctx.GetContentLength() > 0 {
			err := ctx.ReadJSON(entity)
			if err != nil {
				supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
				return
			}
		} else {
			entity = nil
		}

		err = method(user, entity)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterIDOfStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个通过主键处理单条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterIDOfStorageBin(party router.Party, httpMethod string, path string, method func(*models.Usertab, string, string) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		var err error = nil
		storageBinId := ctx.Params().GetString("storageBinId")
		warehouseId := ctx.Params().GetString("warehouseId")

		err = method(user, storageBinId, warehouseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertOneStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入单条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterInsertOneStorageBin(party router.Party, path string, method func(*models.Usertab, *model.StorageBin) error) {

	RegisterOneStorageBin(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteOneStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除单条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterDeleteOneStorageBin(party router.Party, path string, method func(*models.Usertab, string, string) error) {

	RegisterIDOfStorageBin(party, "DELETE", path+"/{storageBinId:string}/{warehouseId:string}", method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectOneStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查找单条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterSelectOneStorageBin(party router.Party, path string, method func(*models.Usertab, string, string) (*model.StorageBin, error)) {

	party.Get(path+"/{storageBinId:string}/{warehouseId:string}", func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		storageBinId := ctx.Params().GetString("storageBinId")
		warehouseId := ctx.Params().GetString("warehouseId")
		result, err := method(user, storageBinId, warehouseId)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		if result == nil {
			supports.Error(ctx, iris.StatusNotFound, supports.NotFound, nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateOneStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改单条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterUpdateOneStorageBin(party router.Party, path string, method func(*models.Usertab, *model.StorageBin) error) {

	RegisterOneStorageBin(party, "PUT", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterMultiStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个处理多条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : HTTP方法
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterMultiStorageBin(party router.Party, httpMethod string, path string, method func(*models.Usertab, *[]model.StorageBin) error) {

	party.Handle(httpMethod, path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		entities := make([]model.StorageBin, 0, 10)
		err := ctx.ReadJSON(&entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}

		err = method(user, &entities)
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, nil)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterInsertStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个插入多条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterInsertStorageBin(party router.Party, path string, method func(*models.Usertab, *[]model.StorageBin) error) {

	RegisterMultiStorageBin(party, "POST", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterDeleteStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个删除多条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterDeleteStorageBin(party router.Party, path string, method func(*models.Usertab, *[]model.StorageBin) error) {

	RegisterMultiStorageBin(party, "DELETE", path, method)
}

/******************************************************************************
 *
 * @Function Name            : RegisterSelectStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个查询StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterSelectStorageBin(party router.Party, path string, method func(*models.Usertab, map[string]string) (interface{}, error)) {

	party.Get(path, func(ctx iris.Context) {
		user, ok := jwts.ParseToken(ctx)
		if !ok {
			supports.Error(ctx, iris.StatusBadRequest, supports.ParseParamsFailur, nil)
			return
		}

		result, err := method(user, ctx.URLParams())
		if err != nil {
			supports.Error(ctx, iris.StatusBadRequest, err.Error(), nil)
			return
		}
		supports.Ok(ctx, supports.OptionSuccess, result)
	})
}

/******************************************************************************
 *
 * @Function Name            : RegisterUpdateStorageBin
 *-----------------------------------------------------------------------------
 *
 * @Description              : 为一个修改多条StorageBin的方法注册路由
 *
 * @Function Parameters      : 路由分组
 *
 * @Function Parameters      : 路径
 *
 * @Function Parameters      : 实际处理请求的方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-07-08 11:25:15
 *
 ******************************************************************************/
func RegisterUpdateStorageBin(party router.Party, path string, method func(*models.Usertab, *[]model.StorageBin) error) {

	RegisterMultiStorageBin(party, "PUT", path, method)
}
